@@ -29,6 +29,7 @@ import (
 	"kubevirt.io/kubevirt/cmd/cniplugins/passt-binding/pkg/plugin"
 )
 
+//nolint:gochecknoinits
 func init() {
 	// this ensures that main runs only on main thread (thread group leader).
 	// since namespace ops (unshare, setns) are done for a single thread, we
@@ -37,5 +38,10 @@ func init() {
 }
 
 func main() {
-	skel.PluginMain(plugin.CmdAdd, plugin.CmdCheck, plugin.CmdDel, version.All, bv.BuildString("passt-binding"))
+	cniFuncs := skel.CNIFuncs{
+		Add:   plugin.CmdAdd,
+		Del:   plugin.CmdDel,
+		Check: plugin.CmdCheck,
+	}
+	skel.PluginMainFuncs(cniFuncs, version.All, bv.BuildString("passt-binding"))
 }
