@@ -15,10 +15,10 @@ func New() sysControl {
 	return sysControl{}
 }
 
-func (_ sysControl) IPv4SetPingGroupRange(from, to int) error {
+func (sysControl) IPv4SetPingGroupRange(from, to int) error {
 	return sysCtl.SetSysctl(sysctl.PingGroupRange, fmt.Sprintf("%d %d", from, to))
 }
 
-func (_ sysControl) IPv4SetUnprivilegedPortStart(port int) error {
+func (sysControl) IPv4SetUnprivilegedPortStart(port int) error {
 	return sysCtl.SetSysctl(sysctl.UnprivilegedPortStart, strconv.Itoa(port))
 }
