@@ -23,8 +23,6 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
-	vishnetlink "github.com/vishvananda/netlink"
-
 	vmschema "kubevirt.io/api/core/v1"
 
 	"kubevirt.io/kubevirt/cmd/sidecars/network-passt-binding/domain"
@@ -32,52 +30,71 @@ import (
 	domainschema "kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/api"
 )
 
-type defaultNetLinkStub struct{}
+const (
+	ifaceTypeVhostUser = "vhostuser"
 
-func (nl defaultNetLinkStub) LinkByName(name string) (vishnetlink.Link, error) {
-	return nil, vishnetlink.LinkNotFoundError{}
-}
-
-type netLinkStub struct{}
-
-const ifaceTypeVhostUser = "vhostuser"
-
-func (nl netLinkStub) LinkByName(name string) (vishnetlink.Link, error) {
-	return &vishnetlink.Veth{LinkAttrs: vishnetlink.LinkAttrs{Name: name}}, nil
-}
+	defaultPrimaryPodIfaceName = "eth0"
+)
 
 var _ = Describe("pod network configurator", func() {
 	Context("generate domain spec interface", func() {
 		DescribeTable("should fail to create configurator given",
-			func(ifaces []vmschema.Interface, networks []vmschema.Network) {
-				_, err := domain.NewPasstNetworkConfigurator(ifaces, networks, domain.NetworkConfiguratorOptions{}, &defaultNetLinkStub{})
+			func(ifaces []vmschema.Interface, networks []vmschema.Network, ifaceStatuses []vmschema.VirtualMachineInstanceNetworkInterface) {
+				_, err := domain.NewPasstNetworkConfigurator(
+					ifaces,
+					networks,
+					ifaceStatuses,
+					domain.NetworkConfiguratorOptions{},
+				)
 
 				Expect(err).To(HaveOccurred())
 			},
 			Entry("no pod network",
 				nil,
 				[]vmschema.Network{{Name: "default", NetworkSource: vmschema.NetworkSource{Multus: &vmschema.MultusNetwork{}}}},
+				nil,
 			),
 			Entry("no corresponding iface",
 				[]vmschema.Interface{{Name: "not-default", Binding: &vmschema.PluginBinding{Name: "passt"}}},
 				[]vmschema.Network{*vmschema.DefaultPodNetwork()},
+				nil,
 			),
 			Entry("interface with no passt binding method",
 				[]vmschema.Interface{{Name: "default", InterfaceBindingMethod: vmschema.InterfaceBindingMethod{Bridge: &vmschema.InterfaceBridge{}}}},
 				[]vmschema.Network{*vmschema.DefaultPodNetwork()},
+				[]vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: defaultPrimaryPodIfaceName}},
 			),
 			Entry("interface with no passt binding plugin",
 				[]vmschema.Interface{{Name: "default", Binding: &vmschema.PluginBinding{Name: "no-passt"}}},
 				[]vmschema.Network{*vmschema.DefaultPodNetwork()},
+				[]vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: defaultPrimaryPodIfaceName}},
+			),
+			Entry("Interface with no matching status entry",
+				[]vmschema.Interface{{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"}}},
+				[]vmschema.Network{*vmschema.DefaultPodNetwork()},
+				nil,
+			),
+			Entry("Interface with an empty PodInterfaceName",
+				[]vmschema.Interface{{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"}}},
+				[]vmschema.Network{*vmschema.DefaultPodNetwork()},
+				[]vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: ""}},
 			),
 		)
 
 		It("should fail given interface with invalid PCI address", func() {
-			ifaces := []vmschema.Interface{{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
-				PciAddress: "invalid-pci-address"}}
+			ifaces := []vmschema.Interface{{
+				Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
+				PciAddress: "invalid-pci-address",
+			}}
 			networks := []vmschema.Network{*vmschema.DefaultPodNetwork()}
+			ifaceStatuses := []vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: defaultPrimaryPodIfaceName}}
 
-			testMutator, err := domain.NewPasstNetworkConfigurator(ifaces, networks, domain.NetworkConfiguratorOptions{}, &defaultNetLinkStub{})
+			testMutator, err := domain.NewPasstNetworkConfigurator(
+				ifaces,
+				networks,
+				ifaceStatuses,
+				domain.NetworkConfiguratorOptions{},
+			)
 			Expect(err).ToNot(HaveOccurred())
 
 			_, err = testMutator.Mutate(&domainschema.DomainSpec{})
@@ -88,8 +105,14 @@ var _ = Describe("pod network configurator", func() {
 			func(iface *vmschema.Interface, expectedDomainIface *domainschema.Interface) {
 				ifaces := []vmschema.Interface{*iface}
 				networks := []vmschema.Network{*vmschema.DefaultPodNetwork()}
+				ifaceStatuses := []vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: defaultPrimaryPodIfaceName}}
 
-				testMutator, err := domain.NewPasstNetworkConfigurator(ifaces, networks, domain.NetworkConfiguratorOptions{}, &defaultNetLinkStub{})
+				testMutator, err := domain.NewPasstNetworkConfigurator(
+					ifaces,
+					networks,
+					ifaceStatuses,
+					domain.NetworkConfiguratorOptions{},
+				)
 				Expect(err).ToNot(HaveOccurred())
 
 				mutatedDomSpec, err := testMutator.Mutate(&domainschema.DomainSpec{})
@@ -108,8 +131,10 @@ var _ = Describe("pod network configurator", func() {
 				},
 			),
 			Entry("PCI address",
-				&vmschema.Interface{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
-					PciAddress: "0000:02:02.0"},
+				&vmschema.Interface{
+					Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
+					PciAddress: "0000:02:02.0",
+				},
 				&domainschema.Interface{
 					Alias:       domainschema.NewUserDefinedAlias("default"),
 					Type:        ifaceTypeVhostUser,
@@ -121,8 +146,10 @@ var _ = Describe("pod network configurator", func() {
 				},
 			),
 			Entry("MAC address",
-				&vmschema.Interface{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
-					MacAddress: "02:02:02:02:02:02"},
+				&vmschema.Interface{
+					Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
+					MacAddress: "02:02:02:02:02:02",
+				},
 				&domainschema.Interface{
 					Alias:       domainschema.NewUserDefinedAlias("default"),
 					Type:        ifaceTypeVhostUser,
@@ -134,8 +161,10 @@ var _ = Describe("pod network configurator", func() {
 				},
 			),
 			Entry("ACPI address",
-				&vmschema.Interface{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
-					ACPIIndex: 2},
+				&vmschema.Interface{
+					Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
+					ACPIIndex: 2,
+				},
 				&domainschema.Interface{
 					Alias:       domainschema.NewUserDefinedAlias("default"),
 					Type:        ifaceTypeVhostUser,
@@ -147,7 +176,8 @@ var _ = Describe("pod network configurator", func() {
 				},
 			),
 			Entry("non virtio model",
-				&vmschema.Interface{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
+				&vmschema.Interface{
+					Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
 					Model: "e1000",
 				},
 				&domainschema.Interface{
@@ -160,9 +190,12 @@ var _ = Describe("pod network configurator", func() {
 				},
 			),
 			Entry("tcp ports (should forward tcp ports only)",
-				&vmschema.Interface{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
-					Ports: []vmschema.Port{{Protocol: "TCP", Port: 1}, {Protocol: "TCP", Port: 4}},
-				},
+				newInterface(
+					"default",
+					withPasstBindingPlugin(),
+					withOpenPort("TCP", 1),
+					withOpenPort("TCP", 4),
+				),
 				&domainschema.Interface{
 					Alias:   domainschema.NewUserDefinedAlias("default"),
 					Type:    ifaceTypeVhostUser,
@@ -180,9 +213,12 @@ var _ = Describe("pod network configurator", func() {
 				},
 			),
 			Entry("udp ports (should forward udp ports only)",
-				&vmschema.Interface{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
-					Ports: []vmschema.Port{{Protocol: "UDP", Port: 2}, {Protocol: "UDP", Port: 3}},
-				},
+				newInterface(
+					"default",
+					withPasstBindingPlugin(),
+					withOpenPort("UDP", 2),
+					withOpenPort("UDP", 3),
+				),
 				&domainschema.Interface{
 					Alias:   domainschema.NewUserDefinedAlias("default"),
 					Type:    ifaceTypeVhostUser,
@@ -200,9 +236,14 @@ var _ = Describe("pod network configurator", func() {
 				},
 			),
 			Entry("both tcp and udp ports",
-				&vmschema.Interface{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"},
-					Ports: []vmschema.Port{{Port: 1}, {Protocol: "UdP", Port: 2}, {Protocol: "UDP", Port: 3}, {Protocol: "tcp", Port: 4}},
-				},
+				newInterface(
+					"default",
+					withPasstBindingPlugin(),
+					withOpenPort("", 1),
+					withOpenPort("UDP", 2),
+					withOpenPort("UDP", 3),
+					withOpenPort("TCP", 4),
+				),
 				&domainschema.Interface{
 					Alias:   domainschema.NewUserDefinedAlias("default"),
 					Type:    ifaceTypeVhostUser,
@@ -231,8 +272,9 @@ var _ = Describe("pod network configurator", func() {
 			func(opts *domain.NetworkConfiguratorOptions, expectedDomainIface *domainschema.Interface) {
 				ifaces := []vmschema.Interface{{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"}}}
 				networks := []vmschema.Network{*vmschema.DefaultPodNetwork()}
+				ifaceStatuses := []vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: defaultPrimaryPodIfaceName}}
 
-				testMutator, err := domain.NewPasstNetworkConfigurator(ifaces, networks, *opts, &defaultNetLinkStub{})
+				testMutator, err := domain.NewPasstNetworkConfigurator(ifaces, networks, ifaceStatuses, *opts)
 				Expect(err).ToNot(HaveOccurred())
 
 				mutatedDomSpec, err := testMutator.Mutate(&domainschema.DomainSpec{})
@@ -260,12 +302,18 @@ var _ = Describe("pod network configurator", func() {
 					Model:   &domainschema.Model{Type: "virtio-non-transitional"},
 					PortForward: []domainschema.InterfacePortForward{
 						{Proto: "tcp", Ranges: []domainschema.InterfacePortForwardRange{
-							{Start: 15000, Exclude: "yes"}, {Start: 15001, Exclude: "yes"},
-							{Start: 15004, Exclude: "yes"}, {Start: 15006, Exclude: "yes"},
-							{Start: 15008, Exclude: "yes"}, {Start: 15009, Exclude: "yes"},
-							{Start: 15020, Exclude: "yes"}, {Start: 15021, Exclude: "yes"},
-							{Start: 15053, Exclude: "yes"}, {Start: 15090, Exclude: "yes"},
-						}}},
+							{Start: 15000, Exclude: "yes"},
+							{Start: 15001, Exclude: "yes"},
+							{Start: 15004, Exclude: "yes"},
+							{Start: 15006, Exclude: "yes"},
+							{Start: 15008, Exclude: "yes"},
+							{Start: 15009, Exclude: "yes"},
+							{Start: 15020, Exclude: "yes"},
+							{Start: 15021, Exclude: "yes"},
+							{Start: 15053, Exclude: "yes"},
+							{Start: 15090, Exclude: "yes"},
+						}},
+					},
 				},
 			),
 		)
@@ -280,6 +328,8 @@ var _ = Describe("pod network configurator", func() {
 				{Name: "secondary", InterfaceBindingMethod: vmschema.InterfaceBindingMethod{Bridge: &vmschema.InterfaceBridge{}}},
 			}
 
+			ifaceStatuses := []vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: defaultPrimaryPodIfaceName}}
+
 			expectedDomainIface := &domainschema.Interface{
 				Alias:       domainschema.NewUserDefinedAlias("default"),
 				Type:        ifaceTypeVhostUser,
@@ -289,13 +339,20 @@ var _ = Describe("pod network configurator", func() {
 				Model:       &domainschema.Model{Type: "virtio-non-transitional"},
 			}
 
-			testMutator, err := domain.NewPasstNetworkConfigurator(ifaces, networks, domain.NetworkConfiguratorOptions{}, &defaultNetLinkStub{})
+			testMutator, err := domain.NewPasstNetworkConfigurator(
+				ifaces,
+				networks,
+				ifaceStatuses,
+				domain.NetworkConfiguratorOptions{},
+			)
 			Expect(err).ToNot(HaveOccurred())
 
 			existingIface := &domainschema.Interface{Alias: domainschema.NewUserDefinedAlias("existing-iface")}
 			testDomSpec := &domainschema.DomainSpec{
 				Devices: domainschema.Devices{
-					Interfaces: []domainschema.Interface{*existingIface}}}
+					Interfaces: []domainschema.Interface{*existingIface},
+				},
+			}
 
 			mutatedDomSpec, err := testMutator.Mutate(testDomSpec)
 			Expect(err).ToNot(HaveOccurred())
@@ -305,6 +362,7 @@ var _ = Describe("pod network configurator", func() {
 		It("should set domain interface correctly when executed more than once", func() {
 			networks := []vmschema.Network{*vmschema.DefaultPodNetwork()}
 			ifaces := []vmschema.Interface{{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"}}}
+			ifaceStatuses := []vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: defaultPrimaryPodIfaceName}}
 
 			expectedDomainIface := &domainschema.Interface{
 				Alias:       domainschema.NewUserDefinedAlias("default"),
@@ -315,7 +373,12 @@ var _ = Describe("pod network configurator", func() {
 				Model:       &domainschema.Model{Type: "virtio-non-transitional"},
 			}
 
-			testMutator, err := domain.NewPasstNetworkConfigurator(ifaces, networks, domain.NetworkConfiguratorOptions{}, &defaultNetLinkStub{})
+			testMutator, err := domain.NewPasstNetworkConfigurator(
+				ifaces,
+				networks,
+				ifaceStatuses,
+				domain.NetworkConfiguratorOptions{},
+			)
 			Expect(err).ToNot(HaveOccurred())
 
 			testDomSpec := &domainschema.DomainSpec{}
@@ -329,6 +392,7 @@ var _ = Describe("pod network configurator", func() {
 		It("should set domain interface source link to the optional one if exists", func() {
 			networks := []vmschema.Network{*vmschema.DefaultPodNetwork()}
 			ifaces := []vmschema.Interface{{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"}}}
+			ifaceStatuses := []vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: "ovn-udn1"}}
 
 			expectedDomainIface := &domainschema.Interface{
 				Alias:       domainschema.NewUserDefinedAlias("default"),
@@ -338,7 +402,12 @@ var _ = Describe("pod network configurator", func() {
 				PortForward: []domainschema.InterfacePortForward{{Proto: "tcp"}, {Proto: "udp"}},
 				Model:       &domainschema.Model{Type: "virtio-non-transitional"},
 			}
-			testMutator, err := domain.NewPasstNetworkConfigurator(ifaces, networks, domain.NetworkConfiguratorOptions{}, &netLinkStub{})
+			testMutator, err := domain.NewPasstNetworkConfigurator(
+				ifaces,
+				networks,
+				ifaceStatuses,
+				domain.NetworkConfiguratorOptions{},
+			)
 			Expect(err).ToNot(HaveOccurred())
 
 			testDomSpec := &domainschema.DomainSpec{}
@@ -355,9 +424,15 @@ var _ = Describe("pod network configurator", func() {
 		BeforeEach(func() {
 			networks := []vmschema.Network{*vmschema.DefaultPodNetwork()}
 			ifaces := []vmschema.Interface{{Name: "default", Binding: &vmschema.PluginBinding{Name: "passt"}}}
+			ifaceStatuses := []vmschema.VirtualMachineInstanceNetworkInterface{{Name: "default", PodInterfaceName: defaultPrimaryPodIfaceName}}
 
 			var err error
-			testMutator, err = domain.NewPasstNetworkConfigurator(ifaces, networks, domain.NetworkConfiguratorOptions{}, &netLinkStub{})
+			testMutator, err = domain.NewPasstNetworkConfigurator(
+				ifaces,
+				networks,
+				ifaceStatuses,
+				domain.NetworkConfiguratorOptions{},
+			)
 			Expect(err).ToNot(HaveOccurred())
 		})
 
@@ -398,3 +473,34 @@ var _ = Describe("pod network configurator", func() {
 		})
 	})
 })
+
+type option func(p *vmschema.Interface)
+
+func newInterface(name string, options ...option) *vmschema.Interface {
+	newIface := &vmschema.Interface{
+		Name: name,
+	}
+
+	for _, option := range options {
+		option(newIface)
+	}
+
+	return newIface
+}
+
+func withPasstBindingPlugin() option {
+	return func(iface *vmschema.Interface) {
+		iface.Binding = &vmschema.PluginBinding{
+			Name: "passt",
+		}
+	}
+}
+
+func withOpenPort(protocol string, portNumber int32) option {
+	return func(iface *vmschema.Interface) {
+		iface.Ports = append(iface.Ports, vmschema.Port{
+			Protocol: protocol,
+			Port:     portNumber,
+		})
+	}
+}
