@@ -23,6 +23,7 @@ source hack/common.sh
 source hack/bootstrap.sh
 source hack/config.sh
 
+# Build core images for all architectures
 default_targets="
     virt-operator
     virt-api
@@ -40,9 +41,8 @@ default_targets="
     libguestfs-tools
 "
 
-case ${ARCHITECTURE} in
-"s390x" | "crossbuild-s390x") ;;
-*)
+# Add additional images for non-s390x architectures only
+if [[ "${ARCHITECTURE}" != "s390x" && "${ARCHITECTURE}" != "crossbuild-s390x" ]]; then
     default_targets+="
         conformance
         pr-helper
@@ -60,8 +60,7 @@ case ${ARCHITECTURE} in
         network-passt-binding
         network-passt-binding-cni
     "
-    ;;
-esac
+fi
 
 PUSH_TARGETS=(${PUSH_TARGETS:-${default_targets}})
 
@@ -70,10 +69,7 @@ for tag in ${docker_tag} ${docker_tag_alt}; do
 
         bazel run \
             --config=${ARCHITECTURE} \
-            --define container_prefix=${docker_prefix} \
-            --define image_prefix=${image_prefix} \
-            --define container_tag=${tag} \
-            //:push-${target}
+            //:push-${target} -- --repository ${docker_prefix}/${image_prefix}${target} --tag ${tag}
 
     done
 done
@@ -84,10 +80,7 @@ if [[ $image_prefix_alt ]]; then
 
         bazel run \
             --config=${ARCHITECTURE} \
-            --define container_prefix=${docker_prefix} \
-            --define image_prefix=${image_prefix_alt} \
-            --define container_tag=${docker_tag} \
-            //:push-${target}
+            //:push-${target} -- --repository ${docker_prefix}/${image_prefix_alt}${target} --tag ${docker_tag}
 
     done
 fi
@@ -95,8 +88,8 @@ fi
 rm -rf ${DIGESTS_DIR}/${ARCHITECTURE}
 mkdir -p ${DIGESTS_DIR}/${ARCHITECTURE}
 
-for f in $(find bazel-bin/ -name '*.digest'); do
-    dir=${DIGESTS_DIR}/${ARCHITECTURE}/$(dirname $f)
+for target in ${PUSH_TARGETS[@]}; do
+    dir=${DIGESTS_DIR}/${ARCHITECTURE}/${target}
     mkdir -p ${dir}
-    cp -f ${f} ${dir}/$(basename ${f})
+    touch ${dir}/${target}.image
 done
