@@ -87,6 +87,11 @@ if [[ "$KUBEVIRT_DEPLOY_CDI" != "false" ]] && [[ ${ARCHITECTURE} != *aarch64 ]];
     _ensure_cdi_deployment
 fi
 
+if [ "${KUBEVIRT_DEPLOY_NP}" == "true" ]; then
+    _kubectl apply -f hack/cluster-services-np.yaml
+    _kubectl apply -f ${MANIFESTS_OUT_DIR}/release/kubevirt-network-policies.yaml
+fi
+
 # Deploy kubevirt operator
 _kubectl apply -f ${MANIFESTS_OUT_DIR}/release/kubevirt-operator.yaml
 
