@@ -13,10 +13,9 @@ swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/core/v1/types.go
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/core/v1/schema.go
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/snapshot/v1alpha1/types.go
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/snapshot/v1beta1/types.go
-swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/instancetype/v1alpha1/types.go
-swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/instancetype/v1alpha2/types.go
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/instancetype/v1beta1/types.go
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/pool/v1alpha1/types.go
+swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/pool/v1beta1/types.go
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/migrations/v1alpha1/types.go
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/export/v1alpha1/types.go
 swagger-doc -in ${KUBEVIRT_DIR}/staging/src/kubevirt.io/api/export/v1beta1/types.go
@@ -31,10 +30,9 @@ deepcopy-gen \
     kubevirt.io/api/snapshot/v1beta1 \
     kubevirt.io/api/export/v1alpha1 \
     kubevirt.io/api/export/v1beta1 \
-    kubevirt.io/api/instancetype/v1alpha1 \
-    kubevirt.io/api/instancetype/v1alpha2 \
     kubevirt.io/api/instancetype/v1beta1 \
     kubevirt.io/api/pool/v1alpha1 \
+    kubevirt.io/api/pool/v1beta1 \
     kubevirt.io/api/migrations/v1alpha1 \
     kubevirt.io/api/clone/v1alpha1 \
     kubevirt.io/api/clone/v1beta1 \
@@ -61,11 +59,10 @@ openapi-gen \
     kubevirt.io/api/clone/v1beta1 \
     kubevirt.io/api/export/v1alpha1 \
     kubevirt.io/api/export/v1beta1 \
-    kubevirt.io/api/instancetype/v1alpha1 \
-    kubevirt.io/api/instancetype/v1alpha2 \
     kubevirt.io/api/instancetype/v1beta1 \
     kubevirt.io/api/migrations/v1alpha1 \
     kubevirt.io/api/pool/v1alpha1 \
+    kubevirt.io/api/pool/v1beta1 \
     kubevirt.io/api/snapshot/v1alpha1 \
     kubevirt.io/api/snapshot/v1beta1 \
     kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1
@@ -73,8 +70,6 @@ openapi-gen \
 conversion-gen \
     --go-header-file ${KUBEVIRT_DIR}/hack/boilerplate/boilerplate.go.txt \
     --output-file conversion_generated.go \
-    kubevirt.io/api/instancetype/v1alpha1 \
-    kubevirt.io/api/instancetype/v1alpha2 \
     kubevirt.io/api/instancetype/v1beta1
 
 if cmp ${KUBEVIRT_DIR}/api/api-rule-violations.list ${KUBEVIRT_DIR}/api/api-rule-violations-known.list; then
@@ -88,7 +83,7 @@ fi
 
 client-gen --clientset-name kubevirt \
     --input-base kubevirt.io/api \
-    --input core/v1,export/v1alpha1,export/v1beta1,snapshot/v1alpha1,snapshot/v1beta1,instancetype/v1alpha1,instancetype/v1alpha2,instancetype/v1beta1,pool/v1alpha1,migrations/v1alpha1,clone/v1alpha1,clone/v1beta1 \
+    --input core/v1,export/v1alpha1,export/v1beta1,snapshot/v1alpha1,snapshot/v1beta1,instancetype/v1beta1,pool/v1alpha1,pool/v1beta1,migrations/v1alpha1,clone/v1alpha1,clone/v1beta1 \
     --output-dir ${KUBEVIRT_DIR}/staging/src/kubevirt.io/client-go \
     --output-pkg ${CLIENT_GEN_BASE} \
     --go-header-file ${KUBEVIRT_DIR}/hack/boilerplate/boilerplate.go.txt
@@ -145,12 +140,11 @@ deepcopy-gen \
     GOFLAGS= controller-gen crd paths=../api/export/v1beta1/
 
     #include instancetype
-    GOFLAGS= controller-gen crd paths=../api/instancetype/v1alpha1/
-    GOFLAGS= controller-gen crd paths=../api/instancetype/v1alpha2/
     GOFLAGS= controller-gen crd paths=../api/instancetype/v1beta1/
 
     #include pool
     GOFLAGS= controller-gen crd paths=../api/pool/v1alpha1/
+    GOFLAGS= controller-gen crd paths=../api/pool/v1beta1/
 
     #include migrations
     GOFLAGS= controller-gen crd paths=../api/migrations/v1alpha1/
@@ -192,54 +186,11 @@ rm -f ${KUBEVIRT_DIR}/examples/*
 ResourceDir=${KUBEVIRT_DIR}/manifests/generated
 ${KUBEVIRT_DIR}/tools/resource-generator/resource-generator --type=priorityclass >${ResourceDir}/kubevirt-priority-class.yaml
 ${KUBEVIRT_DIR}/tools/resource-generator/resource-generator --type=kv >${ResourceDir}/kv-resource.yaml
+${KUBEVIRT_DIR}/tools/resource-generator/resource-generator --type=networkpolicies --namespace='{{.Namespace}}' >${ResourceDir}/kubevirt-network-policies.yaml.in
 ${KUBEVIRT_DIR}/tools/resource-generator/resource-generator --type=kv-cr --namespace='{{.Namespace}}' --pullPolicy='{{.ImagePullPolicy}}' \
     --featureGates='{{.FeatureGates}}' --infraReplicas='{{.InfraReplicas}}' >${ResourceDir}/kubevirt-cr.yaml.in
 ${KUBEVIRT_DIR}/tools/resource-generator/resource-generator --type=operator-rbac --namespace='{{.Namespace}}' >${ResourceDir}/rbac-operator.authorization.k8s.yaml.in
 
-# used for Image fields in manifests
-function getVersion() {
-    echo "{{if $1}}@{{$1}}{{else}}:{{.DockerTag}}{{end}}"
-}
-virtapi_version=$(getVersion ".VirtApiSha")
-virtcontroller_version=$(getVersion ".VirtControllerSha")
-virthandler_version=$(getVersion ".VirtHandlerSha")
-virtlauncher_version=$(getVersion ".VirtLauncherSha")
-virtoperator_version=$(getVersion ".VirtOperatorSha")
-virtexportproxy_version=$(getVersion ".VirtExportProxySha")
-virtexportserver_version=$(getVersion ".VirtExportServerSha")
-virtsynchronizationcontroller_version=$(getVersion ".VirtSynchronizationControllerSha")
-
-# used as env var for operator
-function getShasum() {
-    echo "{{if $1}}@{{$1}}{{end}}"
-}
-
-# without the '@' symbole used in 'getShasum'
-function getRawShasum() {
-    echo "{{if $1}}{{$1}}{{end}}"
-}
-virtapi_sha=$(getShasum ".VirtApiSha")
-virtcontroller_sha=$(getShasum ".VirtControllerSha")
-virthandler_sha=$(getShasum ".VirtHandlerSha")
-virtlauncher_sha=$(getShasum ".VirtLauncherSha")
-virtexportproxy_sha=$(getShasum ".VirtExportProxySha")
-virtexportserver_sha=$(getShasum ".VirtExportServerSha")
-virtsynchronizationcontroller_sha=$(getShasum ".VirtSynchronizationControllerSha")
-gs_sha=$(getShasum ".GsSha")
-pr_helper_sha=$(getShasum ".PrHelperSha")
-sidecar_shim_sha=$(getShasum ".SidecarShimSha")
-
-virtapi_rawsha=$(getRawShasum ".VirtApiSha")
-virtcontroller_rawsha=$(getRawShasum ".VirtControllerSha")
-virthandler_rawsha=$(getRawShasum ".VirtHandlerSha")
-virtlauncher_rawsha=$(getRawShasum ".VirtLauncherSha")
-virtexportproxy_rawsha=$(getRawShasum ".VirtExportProxySha")
-virtexportserver_rawsha=$(getRawShasum ".VirtExportServerSha")
-virtsynchronizationcontroller_rawsha=$(getRawShasum ".VirtSynchronizationControllerSha")
-gs_rawsha=$(getRawShasum ".GsSha")
-prhelper_rawsha=$(getRawShasum ".PrHelperSha")
-sidecar_shim_rawsha=$(getRawShasum ".SidecarShimSha")
-
 # The generation code for CSV requires a valid semver to be used.
 # But we're trying to generate a template for a CSV here from code
 # rather than an actual usable CSV. To work around this, we set the
@@ -248,25 +199,15 @@ sidecar_shim_rawsha=$(getRawShasum ".SidecarShimSha")
 _fake_replaces_csv_version="1111.1111.1111"
 _fake_csv_version="2222.2222.2222"
 ${KUBEVIRT_DIR}/tools/csv-generator/csv-generator \
-    --apiSha="$virtapi_rawsha" \
-    --controllerSha="$virtcontroller_rawsha" \
+    --operatorImageVersion="{{.DockerTag}}" \
     --csvCreatedAtTimestamp={{.CreatedAt}} \
     --csvVersion="$_fake_csv_version" \
     --dockerPrefix={{.DockerPrefix}} \
-    --exportProxySha="$virtexportproxy_rawsha" \
-    --exportServerSha="$virtexportserver_rawsha" \
-    --synchronizationControllerSha="$virtsynchronizationcontroller_rawsha" \
-    --gsSha="$gs_rawsha" \
-    --handlerSha="$virthandler_rawsha" \
     --kubevirtLogo={{.KubeVirtLogo}} \
     --kubeVirtVersion={{.DockerTag}} \
-    --launcherSha="$virtlauncher_rawsha" \
     --namespace={{.CSVNamespace}} \
-    --operatorImageVersion="$virtoperator_version" \
-    --prHelperSha="$prhelper_rawsha" \
     --pullPolicy={{.ImagePullPolicy}} \
     --replacesCsvVersion="$_fake_replaces_csv_version" \
-    --sidecarShimSha="$sidecar_shim_rawsha" \
     --verbosity={{.Verbosity}} \
     >${KUBEVIRT_DIR}/manifests/generated/operator-csv.yaml.in
 
@@ -283,3 +224,5 @@ ${KUBEVIRT_DIR}/hack/gen-proto.sh
 mockgen -source pkg/handler-launcher-com/notify/info/info.pb.go -package=info -destination=pkg/handler-launcher-com/notify/info/generated_mock_info.go
 mockgen -source pkg/handler-launcher-com/cmd/info/info.pb.go -package=info -destination=pkg/handler-launcher-com/cmd/info/generated_mock_info.go
 mockgen -source pkg/handler-launcher-com/cmd/v1/cmd.pb.go -package=v1 -destination=pkg/handler-launcher-com/cmd/v1/generated_mock_cmd.go
+
+${KUBEVIRT_DIR}/hack/bazel-race.sh
