@@ -17,7 +17,7 @@ fi
 
 
 KUBEVIRTCI_CLUSTER_PATH=${KUBEVIRTCI_CLUSTER_PATH:-${KUBEVIRTCI_PATH}/cluster}
-KUBEVIRT_PROVIDER=${KUBEVIRT_PROVIDER:-k8s-1.31}
+KUBEVIRT_PROVIDER=${KUBEVIRT_PROVIDER:-k8s-1.34}
 KUBEVIRT_NUM_NODES=${KUBEVIRT_NUM_NODES:-1}
 KUBEVIRT_NUM_NUMA_NODES=${KUBEVIRT_NUM_NUMA_NODES:-1}
 KUBEVIRT_NUM_VCPU=${KUBEVIRT_NUM_VCPU:-6}
@@ -26,6 +26,7 @@ KUBEVIRT_NUM_SECONDARY_NICS=${KUBEVIRT_NUM_SECONDARY_NICS:-0}
 KUBEVIRT_DEPLOY_ISTIO=${KUBEVIRT_DEPLOY_ISTIO:-false}
 KUBEVIRT_PSA=${KUBEVIRT_PSA:-false}
 KUBEVIRT_SINGLE_STACK=${KUBEVIRT_SINGLE_STACK:-false}
+KUBEVIRT_FLANNEL=${KUBEVIRT_FLANNEL:-false}
 KUBEVIRT_NO_ETCD_FSYNC=${KUBEVIRT_NO_ETCD_FSYNC:-false}
 KUBEVIRT_ENABLE_AUDIT=${KUBEVIRT_ENABLE_AUDIT:-false}
 KUBEVIRT_DEPLOY_NFS_CSI=${KUBEVIRT_DEPLOY_NFS_CSI:-false}
@@ -52,4 +53,4 @@ provider_prefix=${KUBEVIRT_PROVIDER}
 job_prefix=${JOB_NAME:-kubevirt}${EXECUTOR_NUMBER}
 
 mkdir -p $KUBEVIRTCI_CONFIG_PATH/$KUBEVIRT_PROVIDER
-KUBEVIRTCI_TAG=2507072117-b751e332
+KUBEVIRTCI_TAG=${KUBEVIRTCI_TAG:-2510241540-9fd40b1c}
