@@ -25,6 +25,7 @@ import (
 	"path"
 	"path/filepath"
 	"regexp"
+	"slices"
 	"strconv"
 	"strings"
 
@@ -39,6 +40,7 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 
 	diskutils "kubevirt.io/kubevirt/pkg/ephemeral-disk-utils"
+	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/util"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 )
@@ -50,6 +52,7 @@ var mountBaseDir = filepath.Join(util.VirtShareDir, "/container-disks")
 type SocketPathGetter func(vmi *v1.VirtualMachineInstance, volumeIndex int) (string, error)
 type KernelBootSocketPathGetter func(vmi *v1.VirtualMachineInstance) (string, error)
 
+const LauncherVolume = "launcher-volume"
 const KernelBootName = "kernel-boot"
 const KernelBootVolumeName = KernelBootName + "-volume"
 
@@ -269,28 +272,7 @@ func generateContainerFromVolume(vmi *v1.VirtualMachineInstance, config *virtcon
 		diskContainerImage = img
 	}
 
-	resources := kubev1.ResourceRequirements{}
-	resources.Requests = make(kubev1.ResourceList)
-	resources.Limits = make(kubev1.ResourceList)
-
-	resources.Requests[kubev1.ResourceCPU] = resource.MustParse("1m")
-	if cpuRequest := config.GetSupportContainerRequest(v1.ContainerDisk, kubev1.ResourceCPU); cpuRequest != nil {
-		resources.Requests[kubev1.ResourceCPU] = *cpuRequest
-	}
-	resources.Requests[kubev1.ResourceMemory] = resource.MustParse("1M")
-	if memRequest := config.GetSupportContainerRequest(v1.ContainerDisk, kubev1.ResourceMemory); memRequest != nil {
-		resources.Requests[kubev1.ResourceMemory] = *memRequest
-	}
-	resources.Requests[kubev1.ResourceEphemeralStorage] = resource.MustParse(ephemeralStorageOverheadSize)
-
-	resources.Limits[kubev1.ResourceCPU] = resource.MustParse("10m")
-	if cpuLimit := config.GetSupportContainerLimit(v1.ContainerDisk, kubev1.ResourceCPU); cpuLimit != nil {
-		resources.Limits[kubev1.ResourceCPU] = *cpuLimit
-	}
-	resources.Limits[kubev1.ResourceMemory] = resource.MustParse("40M")
-	if memLimit := config.GetSupportContainerLimit(v1.ContainerDisk, kubev1.ResourceMemory); memLimit != nil {
-		resources.Limits[kubev1.ResourceMemory] = *memLimit
-	}
+	resources := getMinimalInitContainerDiskResources(vmi, config)
 
 	var mountedDiskName string
 	if isKernelBoot {
@@ -298,11 +280,6 @@ func generateContainerFromVolume(vmi *v1.VirtualMachineInstance, config *virtcon
 	} else {
 		mountedDiskName = "disk_" + strconv.Itoa(volumeIdx)
 	}
-
-	if vmi.IsCPUDedicated() || vmi.WantsToHaveQOSGuaranteed() {
-		resources.Requests[kubev1.ResourceCPU] = resources.Limits[kubev1.ResourceCPU]
-		resources.Requests[kubev1.ResourceMemory] = resources.Limits[kubev1.ResourceMemory]
-	}
 	var args []string
 	var name string
 	if isInit {
@@ -385,7 +362,7 @@ func getContainerDiskSocketBasePath(baseDir, podUID string) string {
 
 // ExtractImageIDsFromSourcePod takes the VMI and its source pod to determine the exact image used by containerdisks and boot container images,
 // which is recorded in the status section of a started pod
-func ExtractImageIDsFromSourcePod(vmi *v1.VirtualMachineInstance, sourcePod *kubev1.Pod) (imageIDs map[string]string, err error) {
+func ExtractImageIDsFromSourcePod(vmi *v1.VirtualMachineInstance, sourcePod *kubev1.Pod, imageVolumeEnabled bool) (imageIDs map[string]string, err error) {
 	imageIDs = map[string]string{}
 	for _, volume := range vmi.Spec.Volumes {
 		if volume.ContainerDisk == nil {
@@ -398,7 +375,29 @@ func ExtractImageIDsFromSourcePod(vmi *v1.VirtualMachineInstance, sourcePod *kub
 		imageIDs[KernelBootVolumeName] = vmi.Spec.Domain.Firmware.KernelBoot.Container.Image
 	}
 
-	for _, status := range sourcePod.Status.ContainerStatuses {
+	containersToCheck := slices.Clone(sourcePod.Status.ContainerStatuses)
+	if imageVolumeEnabled {
+		// When imageVolume is Enabled, there are two cases:
+		// 1. First migration: the Pod was created before the digest was known, so the volumes do not include it.
+		//    We include the initContainerStatuses in containersToCheck so that the loop below can extract the digest
+		//    from the statuses and update imageIDs (similar to how we handle standard containerDisk sidecars When imageVolume is disabled).
+		// 2. Subsequent migrations: the digest is already available in the Pod volumes.
+		//    The init containers no longer exist at this point and are not needed; we take the full image including the digest directly from the volumes.
+		//
+		// TODO: Once the KEP https://github.com/kubernetes/enhancements/issues/5365 is fully implemented and stable
+		// in all Kubernetes versions supported by KubeVirt, this entire init containers logic should be removed,
+		// and the digest can be fetched directly from the Pod volume status.
+		containersToCheck = append(containersToCheck, sourcePod.Status.InitContainerStatuses...)
+		for _, vol := range sourcePod.Spec.Volumes {
+			_, isContainerDiskVolume := imageIDs[vol.Name]
+			if vol.Image == nil || !strings.Contains(vol.Image.Reference, "@sha256:") || !isContainerDiskVolume {
+				continue
+			}
+			imageIDs[vol.Name] = vol.Image.Reference
+		}
+	}
+
+	for _, status := range containersToCheck {
 		if !isImageVolume(status.Name) {
 			continue
 		}
@@ -442,3 +441,63 @@ func toContainerName(volumeName string) string {
 func toVolumeName(containerName string) string {
 	return strings.TrimPrefix(containerName, "volume")
 }
+
+// getMinimalInitContainerDiskResources calculates resource requirements for container disk containers
+// This function is shared between init containers and regular containers
+func getMinimalInitContainerDiskResources(vmi *v1.VirtualMachineInstance, config *virtconfig.ClusterConfig) kubev1.ResourceRequirements {
+	resources := kubev1.ResourceRequirements{}
+	resources.Requests = make(kubev1.ResourceList)
+	resources.Limits = make(kubev1.ResourceList)
+
+	resources.Requests[kubev1.ResourceCPU] = resource.MustParse("1m")
+	if cpuRequest := config.GetSupportContainerRequest(v1.ContainerDisk, kubev1.ResourceCPU); cpuRequest != nil {
+		resources.Requests[kubev1.ResourceCPU] = *cpuRequest
+	}
+	resources.Requests[kubev1.ResourceMemory] = resource.MustParse("1M")
+	if memRequest := config.GetSupportContainerRequest(v1.ContainerDisk, kubev1.ResourceMemory); memRequest != nil {
+		resources.Requests[kubev1.ResourceMemory] = *memRequest
+	}
+	resources.Requests[kubev1.ResourceEphemeralStorage] = resource.MustParse(ephemeralStorageOverheadSize)
+
+	resources.Limits[kubev1.ResourceCPU] = resource.MustParse("10m")
+	if cpuLimit := config.GetSupportContainerLimit(v1.ContainerDisk, kubev1.ResourceCPU); cpuLimit != nil {
+		resources.Limits[kubev1.ResourceCPU] = *cpuLimit
+	}
+	resources.Limits[kubev1.ResourceMemory] = resource.MustParse("40M")
+	if memLimit := config.GetSupportContainerLimit(v1.ContainerDisk, kubev1.ResourceMemory); memLimit != nil {
+		resources.Limits[kubev1.ResourceMemory] = *memLimit
+	}
+
+	if vmi.IsCPUDedicated() || vmi.WantsToHaveQOSGuaranteed() {
+		resources.Requests[kubev1.ResourceCPU] = resources.Limits[kubev1.ResourceCPU]
+		resources.Requests[kubev1.ResourceMemory] = resources.Limits[kubev1.ResourceMemory]
+	}
+
+	return resources
+}
+
+// CreateImageVolumeInitContainer creates a single init container for ImageVolume feature
+func CreateImageVolumeInitContainer(vmi *v1.VirtualMachineInstance, config *virtconfig.ClusterConfig, name, image string, imagePullPolicy kubev1.PullPolicy) kubev1.Container {
+	resources := getMinimalInitContainerDiskResources(vmi, config)
+	return kubev1.Container{
+		Name:            fmt.Sprintf("volume%s", name),
+		Image:           image,
+		ImagePullPolicy: imagePullPolicy,
+		Command:         []string{filepath.Join(util.ContainerBinary, "/usr/bin/container-disk")},
+		Args:            []string{"--no-op"},
+		Resources:       resources,
+		SecurityContext: &kubev1.SecurityContext{
+			RunAsUser:                pointer.P(int64(util.NonRootUID)),
+			RunAsNonRoot:             pointer.P(true),
+			AllowPrivilegeEscalation: pointer.P(false),
+			Capabilities: &kubev1.Capabilities{
+				Drop: []kubev1.Capability{"ALL"},
+			},
+		},
+		VolumeMounts: []kubev1.VolumeMount{{
+			Name:      LauncherVolume,
+			MountPath: util.ContainerBinary,
+			ReadOnly:  true,
+		}},
+	}
+}
