@@ -61,7 +61,7 @@ import (
 	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
 	"kubevirt.io/api/migrations"
 	migrationsv1 "kubevirt.io/api/migrations/v1alpha1"
-	poolv1 "kubevirt.io/api/pool/v1alpha1"
+	poolv1 "kubevirt.io/api/pool/v1beta1"
 	"kubevirt.io/api/snapshot"
 	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
 	"kubevirt.io/client-go/kubecli"
@@ -357,7 +357,7 @@ func NewKubeInformerFactory(restClient *rest.RESTClient, clientSet kubecli.Kubev
 		clientSet:        clientSet,
 		aggregatorClient: aggregatorClient,
 		// Resulting resync period will be between 12 and 24 hours, like the default for k8s
-		defaultResync:     resyncPeriod(12 * time.Hour),
+		defaultResync:     ResyncPeriod(12 * time.Hour),
 		informers:         make(map[string]cache.SharedIndexInformer),
 		startedInformers:  make(map[string]bool),
 		kubevirtNamespace: kubevirtNamespace,
@@ -516,7 +516,7 @@ func (f *kubeInformerFactory) VMIReplicaSet() cache.SharedIndexInformer {
 
 func (f *kubeInformerFactory) VMPool() cache.SharedIndexInformer {
 	return f.getInformer("vmpool", func() cache.SharedIndexInformer {
-		lw := cache.NewListWatchFromClient(f.clientSet.GeneratedKubeVirtClient().PoolV1alpha1().RESTClient(), "virtualmachinepools", k8sv1.NamespaceAll, fields.Everything())
+		lw := cache.NewListWatchFromClient(f.clientSet.GeneratedKubeVirtClient().PoolV1beta1().RESTClient(), "virtualmachinepools", k8sv1.NamespaceAll, fields.Everything())
 		return cache.NewSharedIndexInformer(lw, &poolv1.VirtualMachinePool{}, f.defaultResync, cache.Indexers{cache.NamespaceIndex: cache.MetaNamespaceIndexFunc})
 	})
 }
@@ -1084,8 +1084,8 @@ func (f *kubeInformerFactory) KubeVirt() cache.SharedIndexInformer {
 	})
 }
 
-// resyncPeriod computes the time interval a shared informer waits before resyncing with the api server
-func resyncPeriod(minResyncPeriod time.Duration) time.Duration {
+// ResyncPeriod computes the time interval a shared informer waits before resyncing with the api server
+func ResyncPeriod(minResyncPeriod time.Duration) time.Duration {
 	// #nosec no need for better randomness
 	factor := rand.Float64() + 1
 	return time.Duration(float64(minResyncPeriod.Nanoseconds()) * factor)
