@@ -174,17 +174,17 @@ func createSparseRaw(diskdir *safepath.Path, diskName string, size int64) (err e
 
 	err = safepath.TouchAtNoFollow(diskdir, filepath.Base(diskName), 0666)
 	if err != nil {
-		return err
+		return fmt.Errorf("Failed touch %s,%s : %v", diskdir, diskName, err)
 	}
 
 	diskPath, err := safepath.JoinNoFollow(diskdir, diskName)
 	if err != nil {
-		return err
+		return fmt.Errorf("Failed append  %s,%s : %v", diskdir, diskName, err)
 	}
 
 	sFile, err := safepath.OpenAtNoFollow(diskPath)
 	if err != nil {
-		return err
+		return fmt.Errorf("Failed NewFile %s,%s : %v", diskdir, diskName, err)
 	}
 	defer util.CloseIOAndCheckErr(sFile, &err)
 
@@ -253,26 +253,26 @@ func shouldMountHostDisk(hostDisk *v1.HostDisk) bool {
 func (hdc *DiskImgCreator) mountHostDiskAndSetOwnership(vmi *v1.VirtualMachineInstance, volumeName string, hostDisk *v1.HostDisk) error {
 	diskDir, err := hdc.mountRoot.AppendAndResolveWithRelativeRoot(GetMountedHostDiskDir(volumeName))
 	if err != nil {
-		return err
+		return fmt.Errorf("Resolve diskdir : %v", err)
 	}
 
 	diskPath, err := safepath.JoinNoFollow(diskDir, filepath.Base(hostDisk.Path))
 	fileNotExists := errors.Is(err, unix.ENOENT)
 	if err != nil && !fileNotExists {
-		return err
+		return fmt.Errorf("Resolve diskPath :%v", err)
 	}
 
 	if fileNotExists {
-		if err = hdc.handleRequestedSizeAndCreateSparseRaw(vmi, diskDir, filepath.Base(hostDisk.Path), hostDisk); err != nil {
+		if err := hdc.handleRequestedSizeAndCreateSparseRaw(vmi, diskDir, filepath.Base(hostDisk.Path), hostDisk); err != nil {
 			return err
 		}
 
 		diskPath, err = safepath.JoinNoFollow(diskDir, filepath.Base(hostDisk.Path))
 		if err != nil {
-			return err
+			return fmt.Errorf("last %v", err)
 		}
 		// Change file ownership to the qemu user.
-		if err = ephemeraldiskutils.DefaultOwnershipManager.SetFileOwnership(diskPath); err != nil {
+		if err := ephemeraldiskutils.DefaultOwnershipManager.SetFileOwnership(diskPath); err != nil {
 			log.Log.Reason(err).Errorf("Couldn't set Ownership on %s: %v", diskPath, err)
 			return err
 		}
