@@ -38,8 +38,6 @@ import (
 
 	virtv1 "kubevirt.io/api/core/v1"
 	instancetypeapi "kubevirt.io/api/instancetype"
-	instancetypev1alpha1 "kubevirt.io/api/instancetype/v1alpha1"
-	instancetypev1alpha2 "kubevirt.io/api/instancetype/v1alpha2"
 	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 	fakeclientset "kubevirt.io/client-go/kubevirt/fake"
@@ -178,203 +176,6 @@ var _ = Describe("ControllerRevision upgrades", func() {
 			Expect(newPreferenceCR.Labels).To(HaveKeyWithValue(instancetypeapi.ControllerRevisionObjectKindLabel, originalKindLabel))
 		}
 	},
-		Entry("v1alpha1 VirtualMachinePreferenceSpec & VirtualMachineInstancetypeSpec within VirtualMachineInstancetypeSpecRevision",
-			func() *appsv1.ControllerRevision {
-				instancetypeSpec := instancetypev1alpha1.VirtualMachineInstancetypeSpec{
-					CPU: instancetypev1alpha1.CPUInstancetype{
-						Guest: uint32(1),
-					},
-					Memory: instancetypev1alpha1.MemoryInstancetype{
-						Guest: resource.MustParse("128Mi"),
-					},
-				}
-				instancetypeSpecBytes, err := json.Marshal(instancetypeSpec)
-				Expect(err).ToNot(HaveOccurred())
-
-				specRevision := instancetypev1alpha1.VirtualMachineInstancetypeSpecRevision{
-					APIVersion: instancetypev1alpha1.SchemeGroupVersion.String(),
-					Spec:       instancetypeSpecBytes,
-				}
-				specRevisionBytes, err := json.Marshal(specRevision)
-				Expect(err).ToNot(HaveOccurred())
-
-				return &appsv1.ControllerRevision{
-					ObjectMeta: metav1.ObjectMeta{
-						Name:      "legacy-instancetype-cr",
-						Namespace: vm.Namespace,
-					},
-					Data: runtime.RawExtension{
-						Raw: specRevisionBytes,
-					},
-				}
-			},
-			func() *appsv1.ControllerRevision {
-				preferenceSpec := instancetypev1alpha1.VirtualMachinePreferenceSpec{
-					CPU: &instancetypev1alpha1.CPUPreferences{
-						PreferredCPUTopology: instancetypev1alpha1.PreferSockets,
-					},
-				}
-				preferenceSpecBytes, err := json.Marshal(preferenceSpec)
-				Expect(err).ToNot(HaveOccurred())
-
-				specRevision := instancetypev1alpha1.VirtualMachineInstancetypeSpecRevision{
-					APIVersion: instancetypev1alpha1.SchemeGroupVersion.String(),
-					Spec:       preferenceSpecBytes,
-				}
-				specRevisionBytes, err := json.Marshal(specRevision)
-				Expect(err).ToNot(HaveOccurred())
-
-				return &appsv1.ControllerRevision{
-					ObjectMeta: metav1.ObjectMeta{
-						Name:      "legacy-preference-cr",
-						Namespace: vm.Namespace,
-					},
-					Data: runtime.RawExtension{
-						Raw: specRevisionBytes,
-					},
-				}
-			},
-		),
-		Entry("v1alpha1 VirtualMachineClusterPreference & VirtualMachineClusterInstancetype",
-			func() *appsv1.ControllerRevision {
-				return createControllerRevisionFromObject(
-					&instancetypev1alpha1.VirtualMachineClusterInstancetype{
-						ObjectMeta: metav1.ObjectMeta{
-							Name:      "instancetype",
-							Namespace: vm.Namespace,
-						},
-						Spec: instancetypev1alpha1.VirtualMachineInstancetypeSpec{
-							CPU: instancetypev1alpha1.CPUInstancetype{
-								Guest: uint32(1),
-							},
-							Memory: instancetypev1alpha1.MemoryInstancetype{
-								Guest: resource.MustParse("128Mi"),
-							},
-						},
-					},
-				)
-			},
-			func() *appsv1.ControllerRevision {
-				return createControllerRevisionFromObject(
-					&instancetypev1alpha1.VirtualMachineClusterPreference{
-						ObjectMeta: metav1.ObjectMeta{
-							Name:      "preference",
-							Namespace: vm.Namespace,
-						},
-						Spec: instancetypev1alpha1.VirtualMachinePreferenceSpec{
-							CPU: &instancetypev1alpha1.CPUPreferences{
-								PreferredCPUTopology: instancetypev1alpha1.PreferSockets,
-							},
-						},
-					},
-				)
-			},
-		),
-		Entry("v1alpha1 VirtualMachinePreference & VirtualMachineInstancetype",
-			func() *appsv1.ControllerRevision {
-				return createControllerRevisionFromObject(
-					&instancetypev1alpha1.VirtualMachineInstancetype{
-						ObjectMeta: metav1.ObjectMeta{
-							Name:      "instancetype",
-							Namespace: vm.Namespace,
-						},
-						Spec: instancetypev1alpha1.VirtualMachineInstancetypeSpec{
-							CPU: instancetypev1alpha1.CPUInstancetype{
-								Guest: uint32(1),
-							},
-							Memory: instancetypev1alpha1.MemoryInstancetype{
-								Guest: resource.MustParse("128Mi"),
-							},
-						},
-					},
-				)
-			},
-			func() *appsv1.ControllerRevision {
-				return createControllerRevisionFromObject(
-					&instancetypev1alpha1.VirtualMachinePreference{
-						ObjectMeta: metav1.ObjectMeta{
-							Name:      "preference",
-							Namespace: vm.Namespace,
-						},
-						Spec: instancetypev1alpha1.VirtualMachinePreferenceSpec{
-							CPU: &instancetypev1alpha1.CPUPreferences{
-								PreferredCPUTopology: instancetypev1alpha1.PreferSockets,
-							},
-						},
-					},
-				)
-			},
-		),
-		Entry("v1alpha2 VirtualMachineClusterPreference & VirtualMachineClusterInstancetype",
-			func() *appsv1.ControllerRevision {
-				return createControllerRevisionFromObject(
-					&instancetypev1alpha2.VirtualMachineClusterInstancetype{
-						ObjectMeta: metav1.ObjectMeta{
-							Name:      "instancetype",
-							Namespace: vm.Namespace,
-						},
-						Spec: instancetypev1alpha2.VirtualMachineInstancetypeSpec{
-							CPU: instancetypev1alpha2.CPUInstancetype{
-								Guest: uint32(1),
-							},
-							Memory: instancetypev1alpha2.MemoryInstancetype{
-								Guest: resource.MustParse("128Mi"),
-							},
-						},
-					},
-				)
-			},
-			func() *appsv1.ControllerRevision {
-				return createControllerRevisionFromObject(
-					&instancetypev1alpha2.VirtualMachineClusterPreference{
-						ObjectMeta: metav1.ObjectMeta{
-							Name:      "preference",
-							Namespace: vm.Namespace,
-						},
-						Spec: instancetypev1alpha2.VirtualMachinePreferenceSpec{
-							CPU: &instancetypev1alpha2.CPUPreferences{
-								PreferredCPUTopology: instancetypev1alpha2.PreferSockets,
-							},
-						},
-					},
-				)
-			},
-		),
-		Entry("VirtualMachinePreference & VirtualMachineInstancetype v1alpha2",
-			func() *appsv1.ControllerRevision {
-				return createControllerRevisionFromObject(
-					&instancetypev1alpha2.VirtualMachineInstancetype{
-						ObjectMeta: metav1.ObjectMeta{
-							Name:      "instancetype",
-							Namespace: vm.Namespace,
-						},
-						Spec: instancetypev1alpha2.VirtualMachineInstancetypeSpec{
-							CPU: instancetypev1alpha2.CPUInstancetype{
-								Guest: uint32(1),
-							},
-							Memory: instancetypev1alpha2.MemoryInstancetype{
-								Guest: resource.MustParse("128Mi"),
-							},
-						},
-					},
-				)
-			},
-			func() *appsv1.ControllerRevision {
-				return createControllerRevisionFromObject(
-					&instancetypev1alpha2.VirtualMachinePreference{
-						ObjectMeta: metav1.ObjectMeta{
-							Name:      "preference",
-							Namespace: vm.Namespace,
-						},
-						Spec: instancetypev1alpha2.VirtualMachinePreferenceSpec{
-							CPU: &instancetypev1alpha2.CPUPreferences{
-								PreferredCPUTopology: instancetypev1alpha2.PreferSockets,
-							},
-						},
-					},
-				)
-			},
-		),
 		Entry("v1beta1 VirtualMachineClusterPreference & VirtualMachineClusterInstancetype without version label",
 			func() *appsv1.ControllerRevision {
 				cr := createControllerRevisionFromObject(
