@@ -160,8 +160,8 @@ var _ = Describe("Instance type and Preference VirtualMachine Admitter", func()
 					},
 					{
 						Type:    metav1.CauseTypeFieldValueInvalid,
-						Message: "VM field(s) spec.template.spec.domain.memory conflicts with selected instance type",
-						Field:   "spec.template.spec.domain.memory",
+						Message: "VM field(s) spec.template.spec.domain.memory.guest conflicts with selected instance type",
+						Field:   "spec.template.spec.domain.memory.guest",
 					},
 				},
 			))
