@@ -83,7 +83,7 @@ var (
 )
 
 func migrationStatsCollectorCallback() []operatormetrics.CollectorResult {
-	cachedObjs := informers.VMIMigration.GetIndexer().List()
+	cachedObjs := indexers.VMIMigration.List()
 	vmims := make([]*k6tv1.VirtualMachineInstanceMigration, len(cachedObjs))
 	for i, obj := range cachedObjs {
 		vmims[i] = obj.(*k6tv1.VirtualMachineInstanceMigration)
