@@ -38,6 +38,11 @@ import (
 	"kubevirt.io/kubevirt/pkg/testutils"
 )
 
+// Minimal stub for label config used by vmstats tests
+type funcLabelsConfig func(string) bool
+
+func (f funcLabelsConfig) ShouldReport(label string) bool { return f(label) }
+
 var _ = Describe("VM Stats Collector", func() {
 	Context("VM status collector", func() {
 		createVM := func(status k6tv1.VirtualMachinePrintableStatus, vmLastTransitionsTime time.Time) *k6tv1.VirtualMachine {
@@ -71,9 +76,7 @@ var _ = Describe("VM Stats Collector", func() {
 
 		DescribeTable("Add VM status metrics", func(status k6tv1.VirtualMachinePrintableStatus, metric operatormetrics.Metric) {
 			t := time.Now()
-			vms := []*k6tv1.VirtualMachine{
-				createVM(status, t),
-			}
+			vms := cloneVM(createVM(status, t))
 
 			cr := reportVmsStats(vms)
 
@@ -107,56 +110,27 @@ var _ = Describe("VM Stats Collector", func() {
 		})
 
 		It("should show annotation types and machine_type labels correctly", func() {
-			vms := []*k6tv1.VirtualMachine{
-				{
-					Spec: k6tv1.VirtualMachineSpec{
-						Template: &k6tv1.VirtualMachineInstanceTemplateSpec{
-							ObjectMeta: metav1.ObjectMeta{
-								Annotations: map[string]string{
-									annotationPrefix + "os":       "centos8",
-									annotationPrefix + "workload": "server",
-									annotationPrefix + "flavor":   "tiny",
-									"other":                       "other",
-								},
+			vms := cloneVM(&k6tv1.VirtualMachine{
+				Spec: k6tv1.VirtualMachineSpec{
+					Template: &k6tv1.VirtualMachineInstanceTemplateSpec{
+						ObjectMeta: metav1.ObjectMeta{
+							Annotations: map[string]string{
+								annotationPrefix + "os":       "centos8",
+								annotationPrefix + "workload": "server",
+								annotationPrefix + "flavor":   "tiny",
+								"other":                       "other",
 							},
-							Spec: k6tv1.VirtualMachineInstanceSpec{
-								Domain: k6tv1.DomainSpec{
-									Machine: &k6tv1.Machine{
-										Type: "q35",
-									},
-								},
+						},
+						Spec: k6tv1.VirtualMachineInstanceSpec{
+							Domain: k6tv1.DomainSpec{
+								Machine: &k6tv1.Machine{Type: "q35"},
 							},
 						},
 					},
-					Status: k6tv1.VirtualMachineStatus{
-						PrintableStatus: k6tv1.VirtualMachineStatusCrashLoopBackOff,
-					},
 				},
-				{
-					Spec: k6tv1.VirtualMachineSpec{
-						Template: &k6tv1.VirtualMachineInstanceTemplateSpec{
-							ObjectMeta: metav1.ObjectMeta{
-								Annotations: map[string]string{
-									annotationPrefix + "os":       "centos8",
-									annotationPrefix + "workload": "server",
-									annotationPrefix + "flavor":   "tiny",
-									annotationPrefix + "phase":    "dummy",
-								},
-							},
-							Spec: k6tv1.VirtualMachineInstanceSpec{
-								Domain: k6tv1.DomainSpec{
-									Machine: &k6tv1.Machine{
-										Type: "q35",
-									},
-								},
-							},
-						},
-					},
-					Status: k6tv1.VirtualMachineStatus{
-						PrintableStatus: k6tv1.VirtualMachineStatusCrashLoopBackOff,
-					},
-				},
-			}
+				Status: k6tv1.VirtualMachineStatus{PrintableStatus: k6tv1.VirtualMachineStatusCrashLoopBackOff},
+			})
+			vms[1].Spec.Template.ObjectMeta.Annotations[annotationPrefix+"phase"] = "dummy"
 
 			crs := CollectVMsInfo(vms)
 			Expect(crs).To(HaveLen(2), "Expected 2 metrics")
@@ -191,19 +165,20 @@ var _ = Describe("VM Stats Collector", func() {
 				}
 			}
 
-			vms := []*k6tv1.VirtualMachine{{
+			vm := &k6tv1.VirtualMachine{
 				ObjectMeta: metav1.ObjectMeta{Namespace: "test-ns"},
 				Spec:       k6tv1.VirtualMachineSpec{Instancetype: instanceType},
-			}}
-			crs := CollectVMsInfo(vms)
-			Expect(crs).To(HaveLen(1), "Expected 1 metric")
+			}
+			crs := CollectVMsInfo(cloneVM(vm))
+			Expect(crs).To(HaveLen(2), "Expected 2 metrics")
 
-			cr := crs[0]
-			Expect(cr).ToNot(BeNil())
-			Expect(cr.Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_info"))
-			Expect(cr.Value).To(BeEquivalentTo(1))
-			Expect(cr.Labels).To(HaveLen(10))
-			Expect(cr.GetLabelValue("instance_type")).To(Equal(expected))
+			for _, cr := range crs {
+				Expect(cr).ToNot(BeNil())
+				Expect(cr.Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_info"))
+				Expect(cr.Value).To(BeEquivalentTo(1))
+				Expect(cr.Labels).To(HaveLen(10))
+				Expect(cr.GetLabelValue("instance_type")).To(Equal(expected))
+			}
 		},
 			Entry("with no instance type expect empty string", "VirtualMachineInstancetype", "", ""),
 			Entry("with managed instance type expect its name", "VirtualMachineInstancetype", "i-managed", "i-managed"),
@@ -226,19 +201,19 @@ var _ = Describe("VM Stats Collector", func() {
 				}
 			}
 
-			vms := []*k6tv1.VirtualMachine{{
+			vm := &k6tv1.VirtualMachine{
 				ObjectMeta: metav1.ObjectMeta{Namespace: "test-ns"},
 				Spec:       k6tv1.VirtualMachineSpec{Preference: preference},
-			}}
-			crs := CollectVMsInfo(vms)
-			Expect(crs).To(HaveLen(1), "Expected 1 metric")
+			}
+			crs := CollectVMsInfo(cloneVM(vm))
+			Expect(crs).To(HaveLen(2), "Expected 2 metrics")
 
-			cr := crs[0]
-
-			Expect(cr.Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_info"))
-			Expect(cr.Value).To(BeEquivalentTo(1))
-			Expect(cr.Labels).To(HaveLen(10))
-			Expect(cr.GetLabelValue("preference")).To(Equal(expected))
+			for _, cr := range crs {
+				Expect(cr.Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_info"))
+				Expect(cr.Value).To(BeEquivalentTo(1))
+				Expect(cr.Labels).To(HaveLen(10))
+				Expect(cr.GetLabelValue("preference")).To(Equal(expected))
+			}
 		},
 			Entry("with no preference expect empty string", "VirtualMachinePreference", "", ""),
 			Entry("with managed preference expect its name", "VirtualMachinePreference", "p-managed", "p-managed"),
@@ -269,8 +244,19 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			crs := CollectResourceRequestsAndLimits([]*k6tv1.VirtualMachine{vm})
-			expectDefaultCPUResourceRequests(crs)
+			crs := CollectResourceRequestsAndLimits(cloneVM(vm))
+			expectVMs(crs, "testvm", "test-ns", func(crs []operatormetrics.CollectorResult, name, ns string) {
+				Expect(crs).To(HaveLen(3), "Expected 3 metrics")
+				Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[0].Value).To(BeEquivalentTo(1))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns, "cpu", "cores", "default"}))
+				Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[1].Value).To(BeEquivalentTo(1))
+				Expect(crs[1].Labels).To(Equal([]string{name, ns, "cpu", "threads", "default"}))
+				Expect(crs[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[2].Value).To(BeEquivalentTo(1))
+				Expect(crs[2].Labels).To(Equal([]string{name, ns, "cpu", "sockets", "default"}))
+			})
 		})
 
 		It("should collect VM memory resource requests and limits", func() {
@@ -297,19 +283,31 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			crs := CollectResourceRequestsAndLimits([]*k6tv1.VirtualMachine{vm})
+			crs := CollectResourceRequestsAndLimits(cloneVM(vm))
 
-			By("checking the resource requests")
-			Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[0].Value).To(BeEquivalentTo(1024))
-			Expect(crs[0].Labels).To(Equal([]string{"testvm", "test-ns", "memory", "bytes", "domain"}))
+			expectVM := func(crs []operatormetrics.CollectorResult, name, ns string) {
+				By("checking the resource requests")
+				Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[0].Value).To(BeEquivalentTo(1024))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns, "memory", "bytes", "domain"}))
 
-			By("checking the resource limits")
-			Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_limits"))
-			Expect(crs[1].Value).To(BeEquivalentTo(2048))
-			Expect(crs[1].Labels).To(Equal([]string{"testvm", "test-ns", "memory", "bytes"}))
+				By("checking the resource limits")
+				Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_limits"))
+				Expect(crs[1].Value).To(BeEquivalentTo(2048))
+				Expect(crs[1].Labels).To(Equal([]string{name, ns, "memory", "bytes"}))
 
-			expectDefaultCPUResourceRequests(crs[2:])
+				Expect(crs[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[2].Value).To(BeEquivalentTo(1))
+				Expect(crs[2].Labels).To(Equal([]string{name, ns, "cpu", "cores", "default"}))
+				Expect(crs[3].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[3].Value).To(BeEquivalentTo(1))
+				Expect(crs[3].Labels).To(Equal([]string{name, ns, "cpu", "threads", "default"}))
+				Expect(crs[4].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[4].Value).To(BeEquivalentTo(1))
+				Expect(crs[4].Labels).To(Equal([]string{name, ns, "cpu", "sockets", "default"}))
+			}
+
+			expectVMs(crs, "testvm", "test-ns", expectVM)
 		})
 
 		It("should collect VM memory guest and hugepages requests", func() {
@@ -334,19 +332,31 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			crs := CollectResourceRequestsAndLimits([]*k6tv1.VirtualMachine{vm})
+			crs := CollectResourceRequestsAndLimits(cloneVM(vm))
 
-			By("checking the memory guest requests")
-			Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[0].Value).To(BeEquivalentTo(1024))
-			Expect(crs[0].Labels).To(Equal([]string{"testvm", "test-ns", "memory", "bytes", "guest"}))
+			expectVM := func(crs []operatormetrics.CollectorResult, name, ns string) {
+				By("checking the memory guest requests")
+				Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[0].Value).To(BeEquivalentTo(1024))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns, "memory", "bytes", "guest"}))
 
-			By("checking the memory hugepages requests")
-			Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[1].Value).To(BeEquivalentTo(2097152))
-			Expect(crs[1].Labels).To(Equal([]string{"testvm", "test-ns", "memory", "bytes", "hugepages"}))
+				By("checking the memory hugepages requests")
+				Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[1].Value).To(BeEquivalentTo(2097152))
+				Expect(crs[1].Labels).To(Equal([]string{name, ns, "memory", "bytes", "hugepages"}))
 
-			expectDefaultCPUResourceRequests(crs[2:])
+				Expect(crs[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[2].Value).To(BeEquivalentTo(1))
+				Expect(crs[2].Labels).To(Equal([]string{name, ns, "cpu", "cores", "default"}))
+				Expect(crs[3].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[3].Value).To(BeEquivalentTo(1))
+				Expect(crs[3].Labels).To(Equal([]string{name, ns, "cpu", "threads", "default"}))
+				Expect(crs[4].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[4].Value).To(BeEquivalentTo(1))
+				Expect(crs[4].Labels).To(Equal([]string{name, ns, "cpu", "sockets", "default"}))
+			}
+
+			expectVMs(crs, "testvm", "test-ns", expectVM)
 		})
 
 		It("should collect VM CPU resource requests and limits", func() {
@@ -373,18 +383,21 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			crs := CollectResourceRequestsAndLimits([]*k6tv1.VirtualMachine{vm})
-			Expect(crs).To(HaveLen(2), "Expected 2 metrics")
+			crs := CollectResourceRequestsAndLimits(cloneVM(vm))
 
-			By("checking the resource requests")
-			Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[0].Value).To(BeEquivalentTo(0.5))
-			Expect(crs[0].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "cores", "requests"}))
+			expectVM := func(crs []operatormetrics.CollectorResult, name, ns string) {
+				Expect(crs).To(HaveLen(2), "Expected 2 metrics")
+				By("checking the resource requests")
+				Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[0].Value).To(BeEquivalentTo(0.5))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns, "cpu", "cores", "requests"}))
+				By("checking the resource limits")
+				Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_limits"))
+				Expect(crs[1].Value).To(BeEquivalentTo(1))
+				Expect(crs[1].Labels).To(Equal([]string{name, ns, "cpu", "cores"}))
+			}
 
-			By("checking the resource limits")
-			Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_limits"))
-			Expect(crs[1].Value).To(BeEquivalentTo(1))
-			Expect(crs[1].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "cores"}))
+			expectVMs(crs, "testvm", "test-ns", expectVM)
 		})
 
 		It("should collect VM CPU resource requests from domain", func() {
@@ -408,20 +421,33 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			crs := CollectResourceRequestsAndLimits([]*k6tv1.VirtualMachine{vm})
-			Expect(crs).To(HaveLen(3), "Expected 3 metrics")
+			crs := CollectResourceRequestsAndLimits(cloneVM(vm))
+			vm1 := filterResultsByVM(crs, "testvm", "test-ns")
+			Expect(vm1).To(HaveLen(3), "Expected 3 metrics")
 
-			Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[0].Value).To(BeEquivalentTo(2))
-			Expect(crs[0].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "cores", "domain"}))
+			Expect(vm1[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+			Expect(vm1[0].Value).To(BeEquivalentTo(2))
+			Expect(vm1[0].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "cores", "domain"}))
 
-			Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[1].Value).To(BeEquivalentTo(4))
-			Expect(crs[1].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "threads", "domain"}))
+			Expect(vm1[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+			Expect(vm1[1].Value).To(BeEquivalentTo(4))
+			Expect(vm1[1].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "threads", "domain"}))
 
-			Expect(crs[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[2].Value).To(BeEquivalentTo(1))
-			Expect(crs[2].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "sockets", "domain"}))
+			Expect(vm1[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+			Expect(vm1[2].Value).To(BeEquivalentTo(1))
+			Expect(vm1[2].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "sockets", "domain"}))
+
+			vm2 := filterResultsByVM(crs, "testvm-2", "test-ns")
+			Expect(vm2).To(HaveLen(3), "Expected 3 metrics")
+			Expect(vm2[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+			Expect(vm2[0].Value).To(BeEquivalentTo(2))
+			Expect(vm2[0].Labels).To(Equal([]string{"testvm-2", "test-ns", "cpu", "cores", "domain"}))
+			Expect(vm2[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+			Expect(vm2[1].Value).To(BeEquivalentTo(4))
+			Expect(vm2[1].Labels).To(Equal([]string{"testvm-2", "test-ns", "cpu", "threads", "domain"}))
+			Expect(vm2[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+			Expect(vm2[2].Value).To(BeEquivalentTo(1))
+			Expect(vm2[2].Labels).To(Equal([]string{"testvm-2", "test-ns", "cpu", "sockets", "domain"}))
 		})
 
 		It("should collect VM CPU and Memory resource requests from Instance Type", func() {
@@ -439,29 +465,34 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			crs := CollectResourceRequestsAndLimits([]*k6tv1.VirtualMachine{vm})
+			crs := CollectResourceRequestsAndLimits(cloneVM(vm))
 
-			Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[0].Value).To(BeEquivalentTo(2048))
-			Expect(crs[0].Labels).To(Equal([]string{"testvm", "test-ns", "memory", "bytes", "guest"}))
+			expectVM := func(crs []operatormetrics.CollectorResult, name, ns string) {
+				Expect(crs).To(HaveLen(4), "Expected 4 metrics")
+				// memory from instancetype
+				Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[0].Value).To(BeEquivalentTo(2048))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns, "memory", "bytes", "guest"}))
+				// cpu cores/threads/sockets from instancetype
+				Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[1].Value).To(BeEquivalentTo(1))
+				Expect(crs[1].Labels).To(Equal([]string{name, ns, "cpu", "cores", "domain"}))
+				Expect(crs[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[2].Value).To(BeEquivalentTo(1))
+				Expect(crs[2].Labels).To(Equal([]string{name, ns, "cpu", "threads", "domain"}))
+				Expect(crs[3].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
+				Expect(crs[3].Value).To(BeEquivalentTo(2))
+				Expect(crs[3].Labels).To(Equal([]string{name, ns, "cpu", "sockets", "domain"}))
+			}
 
-			Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[1].Value).To(BeEquivalentTo(1))
-			Expect(crs[1].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "cores", "domain"}))
-
-			Expect(crs[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[2].Value).To(BeEquivalentTo(1))
-			Expect(crs[2].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "threads", "domain"}))
-
-			Expect(crs[3].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-			Expect(crs[3].Value).To(BeEquivalentTo(2))
-			Expect(crs[3].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "sockets", "domain"}))
+			expectVMs(crs, "testvm", "test-ns", expectVM)
 		})
 	})
 
 	Context("PVC allocated size metric collection", func() {
 		BeforeEach(func() {
-			informers.PersistentVolumeClaim, _ = testutils.NewFakeInformerFor(&k8sv1.PersistentVolumeClaim{})
+			pvcInformer, _ := testutils.NewFakeInformerFor(&k8sv1.PersistentVolumeClaim{})
+			stores.PersistentVolumeClaim = pvcInformer.GetIndexer()
 		})
 
 		createPVC := func(namespace, name string, size resource.Quantity, volumeMode *k8sv1.PersistentVolumeMode) *k8sv1.PersistentVolumeClaim {
@@ -484,7 +515,7 @@ var _ = Describe("VM Stats Collector", func() {
 
 		It("should collect PVC size metrics correctly", func() {
 			pvc := createPVC("default", "test-vm-pvc", resource.MustParse("5Gi"), pointer.P(k8sv1.PersistentVolumeFilesystem))
-			err := informers.PersistentVolumeClaim.GetIndexer().Add(pvc)
+			err := stores.PersistentVolumeClaim.Add(pvc)
 			Expect(err).ToNot(HaveOccurred())
 
 			vm := &k6tv1.VirtualMachine{
@@ -512,17 +543,21 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			results := CollectDiskAllocatedSize([]*k6tv1.VirtualMachine{vm})
+			results := CollectDiskAllocatedSize(cloneVM(vm))
 
 			Expect(results).ToNot(BeEmpty())
-			Expect(results[0].Metric.GetOpts().Name).To(Equal("kubevirt_vm_disk_allocated_size_bytes"))
-			Expect(results[0].Value).To(Equal(float64(5 * 1024 * 1024 * 1024)))
-			Expect(results[0].Labels).To(Equal([]string{"test-vm", "default", "test-vm-pvc", "Filesystem", "rootdisk"}))
+			expectVM := func(crs []operatormetrics.CollectorResult, name, ns string) {
+				Expect(crs).To(HaveLen(1))
+				Expect(crs[0].Metric.GetOpts().Name).To(Equal("kubevirt_vm_disk_allocated_size_bytes"))
+				Expect(crs[0].Value).To(Equal(float64(5 * 1024 * 1024 * 1024)))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns, "test-vm-pvc", "Filesystem", "rootdisk"}))
+			}
+			expectVMs(results, "test-vm", "default", expectVM)
 		})
 
 		It("should handle PVC with nil volume mode", func() {
 			pvc := createPVC("default", "test-vm-pvc-nil-mode", resource.MustParse("3Gi"), nil)
-			err := informers.PersistentVolumeClaim.GetIndexer().Add(pvc)
+			err := stores.PersistentVolumeClaim.Add(pvc)
 			Expect(err).ToNot(HaveOccurred())
 
 			vm := &k6tv1.VirtualMachine{
@@ -550,17 +585,21 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			results := CollectDiskAllocatedSize([]*k6tv1.VirtualMachine{vm})
+			results := CollectDiskAllocatedSize(cloneVM(vm))
 
 			Expect(results).ToNot(BeEmpty())
-			Expect(results[0].Metric.GetOpts().Name).To(Equal("kubevirt_vm_disk_allocated_size_bytes"))
-			Expect(results[0].Value).To(Equal(float64(3 * 1024 * 1024 * 1024)))
-			Expect(results[0].Labels).To(Equal([]string{"test-vm-nil-mode", "default", "test-vm-pvc-nil-mode", "", "rootdisk"}))
+			expectVM := func(crs []operatormetrics.CollectorResult, name, ns string) {
+				Expect(crs).To(HaveLen(1))
+				Expect(crs[0].Metric.GetOpts().Name).To(Equal("kubevirt_vm_disk_allocated_size_bytes"))
+				Expect(crs[0].Value).To(Equal(float64(3 * 1024 * 1024 * 1024)))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns, "test-vm-pvc-nil-mode", "", "rootdisk"}))
+			}
+			expectVMs(results, "test-vm-nil-mode", "default", expectVM)
 		})
 
 		It("should prioritize DataVolume template size over PVC size", func() {
 			pvc := createPVC("default", "test-dv-pvc", resource.MustParse("5Gi"), pointer.P(k8sv1.PersistentVolumeFilesystem))
-			err := informers.PersistentVolumeClaim.GetIndexer().Add(pvc)
+			err := stores.PersistentVolumeClaim.Add(pvc)
 			Expect(err).ToNot(HaveOccurred())
 
 			vm := &k6tv1.VirtualMachine{
@@ -602,12 +641,16 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			results := CollectDiskAllocatedSize([]*k6tv1.VirtualMachine{vm})
+			results := CollectDiskAllocatedSize(cloneVM(vm))
 
 			Expect(results).ToNot(BeEmpty())
-			Expect(results[0].Metric.GetOpts().Name).To(Equal("kubevirt_vm_disk_allocated_size_bytes"))
-			Expect(results[0].Value).To(Equal(float64(2 * 1024 * 1024 * 1024)))
-			Expect(results[0].Labels).To(Equal([]string{"test-vm-dv", "default", "test-dv-pvc", "Filesystem", "datavolumedisk"}))
+			expectVM := func(crs []operatormetrics.CollectorResult, name, ns string) {
+				Expect(crs).To(HaveLen(1))
+				Expect(crs[0].Metric.GetOpts().Name).To(Equal("kubevirt_vm_disk_allocated_size_bytes"))
+				Expect(crs[0].Value).To(Equal(float64(2 * 1024 * 1024 * 1024)))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns, "test-dv-pvc", "Filesystem", "datavolumedisk"}))
+			}
+			expectVMs(results, "test-vm-dv", "default", expectVM)
 		})
 	})
 
@@ -626,12 +669,16 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			results := collectVMCreationTimestamp([]*k6tv1.VirtualMachine{vm})
+			results := collectVMCreationTimestamp(cloneVM(vm))
 
 			Expect(results).ToNot(BeEmpty())
-			Expect(results[0].Metric.GetOpts().Name).To(Equal("kubevirt_vm_create_date_timestamp_seconds"))
-			Expect(results[0].Value).To(Equal(float64(testTime.Unix())))
-			Expect(results[0].Labels).To(Equal([]string{"test-vm", "test-ns"}))
+			expectVM := func(crs []operatormetrics.CollectorResult, name, ns string) {
+				Expect(crs).To(HaveLen(1))
+				Expect(crs[0].Metric.GetOpts().Name).To(Equal("kubevirt_vm_create_date_timestamp_seconds"))
+				Expect(crs[0].Value).To(Equal(float64(testTime.Unix())))
+				Expect(crs[0].Labels).To(Equal([]string{name, ns}))
+			}
+			expectVMs(results, "test-vm", "test-ns", expectVM)
 		})
 
 		It("should collect correct creation times for multiple VMs", func() {
@@ -676,9 +723,10 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			results := collectVMCreationTimestamp([]*k6tv1.VirtualMachine{vm})
+			results := collectVMCreationTimestamp(cloneVM(vm))
 
-			Expect(results).To(BeEmpty(), "kubevirt_vm_create_date_timestamp_seconds should not be collected for VMs with zero creation timestamp")
+			Expect(filterResultsByVM(results, "test-vm-zero-time", "test-ns")).To(BeEmpty())
+			Expect(filterResultsByVM(results, "test-vm-zero-time-2", "test-ns")).To(BeEmpty())
 		})
 	})
 
@@ -745,13 +793,22 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			metrics := CollectVmsVnicInfo([]*k6tv1.VirtualMachine{vm})
-			Expect(metrics).To(HaveLen(4), "Expected metrics for all vNICs")
+			metrics := CollectVmsVnicInfo(cloneVM(vm))
+			Expect(metrics).To(HaveLen(8), "Expected metrics for all vNICs in both VMs")
 
-			Expect(metrics[0].Labels).To(Equal([]string{"test-vm", "test-ns", "iface1", "core", "pod networking", "bridge", "virtio"}))
-			Expect(metrics[1].Labels).To(Equal([]string{"test-vm", "test-ns", "iface2", "core", "pod networking", "masquerade", "e1000e"}))
-			Expect(metrics[2].Labels).To(Equal([]string{"test-vm", "test-ns", "iface3", "core", "multus-net", "sriov", "<none>"}))
-			Expect(metrics[3].Labels).To(Equal([]string{"test-vm", "test-ns", "iface4", "plugin", "custom-net", "custom-plugin", "<none>"}))
+			vm1 := filterResultsByVM(metrics, "test-vm", "test-ns")
+			Expect(vm1).To(HaveLen(4))
+			Expect(vm1[0].Labels).To(Equal([]string{"test-vm", "test-ns", "iface1", "core", "pod networking", "bridge", "virtio"}))
+			Expect(vm1[1].Labels).To(Equal([]string{"test-vm", "test-ns", "iface2", "core", "pod networking", "masquerade", "e1000e"}))
+			Expect(vm1[2].Labels).To(Equal([]string{"test-vm", "test-ns", "iface3", "core", "multus-net", "sriov", "<none>"}))
+			Expect(vm1[3].Labels).To(Equal([]string{"test-vm", "test-ns", "iface4", "plugin", "custom-net", "custom-plugin", "<none>"}))
+
+			vm2 := filterResultsByVM(metrics, "test-vm-2", "test-ns")
+			Expect(vm2).To(HaveLen(4))
+			Expect(vm2[0].Labels).To(Equal([]string{"test-vm-2", "test-ns", "iface1", "core", "pod networking", "bridge", "virtio"}))
+			Expect(vm2[1].Labels).To(Equal([]string{"test-vm-2", "test-ns", "iface2", "core", "pod networking", "masquerade", "e1000e"}))
+			Expect(vm2[2].Labels).To(Equal([]string{"test-vm-2", "test-ns", "iface3", "core", "multus-net", "sriov", "<none>"}))
+			Expect(vm2[3].Labels).To(Equal([]string{"test-vm-2", "test-ns", "iface4", "plugin", "custom-net", "custom-plugin", "<none>"}))
 		})
 		It("should not collect kubevirt_vm_vnic_info metric if no network defined", func() {
 			vm := &k6tv1.VirtualMachine{
@@ -779,24 +836,200 @@ var _ = Describe("VM Stats Collector", func() {
 				},
 			}
 
-			metrics := CollectVmsVnicInfo([]*k6tv1.VirtualMachine{vm})
-			Expect(metrics).To(BeEmpty())
+			metrics := CollectVmsVnicInfo(cloneVM(vm))
+			Expect(filterResultsByVM(metrics, "test-vm", "test-ns")).To(BeEmpty())
+			Expect(filterResultsByVM(metrics, "test-vm-2", "test-ns")).To(BeEmpty())
+		})
+	})
+
+	Context("VM labels metric", func() {
+		BeforeEach(func() {
+			// Default to allowing all labels; individual tests override as needed
+			vmLabelsCfg = funcLabelsConfig(func(string) bool { return true })
+		})
+
+		It("should collect allowed labels", func() {
+			// default allow-all in BeforeEach is sufficient
+			vms := []*k6tv1.VirtualMachine{
+				{
+					ObjectMeta: metav1.ObjectMeta{
+						Name:      "vm1",
+						Namespace: "default",
+						Labels: map[string]string{
+							"environment": "production",
+							"team":        "backend",
+						},
+					},
+				},
+				{
+					ObjectMeta: metav1.ObjectMeta{
+						Name:      "vm2",
+						Namespace: "default",
+						Labels: map[string]string{
+							"environment": "staging",
+							"version":     "2.0",
+						},
+					},
+				},
+			}
+
+			allResults := reportVmsStats(vms)
+			var labelResults []operatormetrics.CollectorResult
+			for _, r := range allResults {
+				if r.Metric.GetOpts().Name == "kubevirt_vm_labels" {
+					labelResults = append(labelResults, r)
+				}
+			}
+			Expect(labelResults).To(HaveLen(2))
+
+			var r1, r2 operatormetrics.CollectorResult
+			if labelResults[0].Labels[0] == "vm1" {
+				r1, r2 = labelResults[0], labelResults[1]
+			} else {
+				r1, r2 = labelResults[1], labelResults[0]
+			}
+			Expect(r1.Labels).To(Equal([]string{"vm1", "default"}))
+			Expect(r1.ConstLabels).To(HaveKeyWithValue("label_environment", "production"))
+			Expect(r1.ConstLabels).To(HaveKeyWithValue("label_team", "backend"))
+
+			Expect(r2.Labels).To(Equal([]string{"vm2", "default"}))
+			Expect(r2.ConstLabels).To(HaveKeyWithValue("label_environment", "staging"))
+			Expect(r2.ConstLabels).To(HaveKeyWithValue("label_version", "2.0"))
+		})
+
+		It("should prioritize ignorelist over allowlist when overlapping", func() {
+			vmLabelsCfg = funcLabelsConfig(func(l string) bool {
+				if l == "vm.kubevirt.io/template" {
+					return false
+				}
+				return true
+			})
+
+			vm := &k6tv1.VirtualMachine{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "test-vm",
+					Namespace: "default",
+					Labels: map[string]string{
+						"environment":             "production",
+						"vm.kubevirt.io/template": "tmpl",
+					},
+				},
+			}
+
+			results := reportVmLabels(vm)
+			Expect(results).To(HaveLen(1))
+			res := results[0]
+			Expect(res.ConstLabels).To(HaveKeyWithValue("label_environment", "production"))
+			Expect(res.ConstLabels).ToNot(HaveKey("label_vm_kubevirt_io_template"))
+		})
+
+		It("should change metric output when configuration changes dynamically", func() {
+			// Restrict to specific labels and ignore secret
+			vmLabelsCfg = funcLabelsConfig(func(l string) bool {
+				if l == "secret" {
+					return false
+				}
+				return l == "environment" || l == "team" || l == "version"
+			})
+			vm := &k6tv1.VirtualMachine{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "test-vm",
+					Namespace: "default",
+					Labels: map[string]string{
+						"environment": "production",
+						"team":        "backend",
+						"secret":      "sensitive",
+						"version":     "1.0",
+					},
+				},
+			}
+
+			afterRestrict := reportVmLabels(vm)
+			Expect(afterRestrict).To(HaveLen(1))
+			Expect(afterRestrict[0].ConstLabels).To(HaveLen(3))
+			Expect(afterRestrict[0].ConstLabels).To(HaveKeyWithValue("label_environment", "production"))
+			Expect(afterRestrict[0].ConstLabels).To(HaveKeyWithValue("label_team", "backend"))
+			Expect(afterRestrict[0].ConstLabels).To(HaveKeyWithValue("label_version", "1.0"))
+			Expect(afterRestrict[0].ConstLabels).ToNot(HaveKey("label_secret"))
+		})
+
+		It("should not emit vm labels metric when allowlist is empty", func() {
+			vmLabelsCfg = funcLabelsConfig(func(string) bool { return false })
+
+			vm := &k6tv1.VirtualMachine{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "vm-no-metric",
+					Namespace: "default",
+					Labels: map[string]string{
+						"a": "1",
+					},
+				},
+			}
+
+			allResults := reportVmsStats([]*k6tv1.VirtualMachine{vm})
+			for _, r := range allResults {
+				Expect(r.Metric.GetOpts().Name).ToNot(Equal("kubevirt_vm_labels"))
+			}
+		})
+
+		It("should treat ignorelist '*' as no ignore (wildcards unsupported)", func() {
+			vmLabelsCfg = funcLabelsConfig(func(string) bool { return true })
+
+			vm := &k6tv1.VirtualMachine{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "vm-wildcard-ignore",
+					Namespace: "default",
+					Labels: map[string]string{
+						"environment": "prod",
+						"team":        "be",
+					},
+				},
+			}
+
+			allResults := reportVmsStats([]*k6tv1.VirtualMachine{vm})
+			var labelResults []operatormetrics.CollectorResult
+			for _, r := range allResults {
+				if r.Metric.GetOpts().Name == "kubevirt_vm_labels" {
+					labelResults = append(labelResults, r)
+				}
+			}
+			Expect(labelResults).To(HaveLen(1))
+			res := labelResults[0]
+			Expect(res.ConstLabels).To(HaveKeyWithValue("label_environment", "prod"))
+			Expect(res.ConstLabels).To(HaveKeyWithValue("label_team", "be"))
 		})
 	})
 })
 
-func expectDefaultCPUResourceRequests(crs []operatormetrics.CollectorResult) {
-	Expect(crs).To(HaveLen(3), "Expected 3 metrics")
+// Add helpers for two-VM testing
+func cloneVM(vm *k6tv1.VirtualMachine) []*k6tv1.VirtualMachine {
+	vm2 := vm.DeepCopy()
+	if vm2.Name == "" {
+		vm2.Name = vm.Name + "-2"
+	} else {
+		vm2.Name = vm2.Name + "-2"
+	}
+	if vm2.Namespace == "" {
+		vm2.Namespace = vm.Namespace
+	}
+	return []*k6tv1.VirtualMachine{vm, vm2}
+}
 
-	Expect(crs[0].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-	Expect(crs[0].Value).To(BeEquivalentTo(1))
-	Expect(crs[0].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "cores", "default"}))
+func filterResultsByVM(crs []operatormetrics.CollectorResult, name, namespace string) []operatormetrics.CollectorResult {
+	var out []operatormetrics.CollectorResult
+	for _, r := range crs {
+		if len(r.Labels) >= 2 && r.Labels[0] == name && r.Labels[1] == namespace {
+			out = append(out, r)
+		}
+	}
+	return out
+}
 
-	Expect(crs[1].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-	Expect(crs[1].Value).To(BeEquivalentTo(1))
-	Expect(crs[1].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "threads", "default"}))
-
-	Expect(crs[2].Metric.GetOpts().Name).To(ContainSubstring("kubevirt_vm_resource_requests"))
-	Expect(crs[2].Value).To(BeEquivalentTo(1))
-	Expect(crs[2].Labels).To(Equal([]string{"testvm", "test-ns", "cpu", "sockets", "default"}))
+func expectVMs(
+	results []operatormetrics.CollectorResult,
+	name, namespace string,
+	expectVM func([]operatormetrics.CollectorResult, string, string),
+) {
+	expectVM(filterResultsByVM(results, name, namespace), name, namespace)
+	expectVM(filterResultsByVM(results, name+"-2", namespace), name+"-2", namespace)
 }
