@@ -33,8 +33,6 @@ import (
 
 	v1 "kubevirt.io/api/core/v1"
 
-	"kubevirt.io/client-go/kubecli"
-
 	"kubevirt.io/kubevirt/pkg/libvmi"
 	libvmistatus "kubevirt.io/kubevirt/pkg/libvmi/status"
 	"kubevirt.io/kubevirt/pkg/network/downwardapi"
@@ -42,17 +40,10 @@ import (
 	"kubevirt.io/kubevirt/pkg/network/multus"
 	"kubevirt.io/kubevirt/pkg/network/pod/annotations"
 	"kubevirt.io/kubevirt/pkg/network/vmispec"
-	"kubevirt.io/kubevirt/pkg/testutils"
-	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 )
 
 var _ = Describe("Annotations Generator", func() {
-	const (
-		kubevirtCRName    = "kubevirt"
-		kubevirtNamespace = "kubevirt"
-
-		testNamespace = "default"
-	)
+	const testNamespace = "default"
 
 	Context("Multus", func() {
 		const (
@@ -65,15 +56,6 @@ var _ = Describe("Annotations Generator", func() {
 			networkAttachmentDefinitionName2       = "other-namespace/test1"
 		)
 
-		var clusterConfig *virtconfig.ClusterConfig
-
-		BeforeEach(func() {
-			kv := kubecli.NewMinimalKubeVirt(kubevirtCRName)
-			kv.Namespace = kubevirtNamespace
-
-			clusterConfig = newClusterConfig(kv)
-		})
-
 		It("should generate the Multus networks annotation", func() {
 			vmi := libvmi.New(
 				libvmi.WithNamespace(testNamespace),
@@ -85,7 +67,7 @@ var _ = Describe("Annotations Generator", func() {
 				libvmi.WithNetwork(libvmi.MultusNetwork(network2Name, networkAttachmentDefinitionName2)),
 			)
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations, err := generator.Generate(vmi)
 			Expect(err).NotTo(HaveOccurred())
 
@@ -107,7 +89,7 @@ var _ = Describe("Annotations Generator", func() {
 				libvmi.WithNetwork(libvmi.MultusNetwork(network1Name, networkAttachmentDefinitionName1)),
 			)
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations, err := generator.Generate(vmi)
 			Expect(err).NotTo(HaveOccurred())
 
@@ -130,7 +112,7 @@ var _ = Describe("Annotations Generator", func() {
 				libvmi.WithNetwork(libvmi.MultusNetwork(network1Name, networkAttachmentDefinitionName1)),
 			)
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations, err := generator.Generate(vmi)
 			Expect(err).NotTo(HaveOccurred())
 
@@ -144,22 +126,13 @@ var _ = Describe("Annotations Generator", func() {
 	})
 
 	Context("Istio annotations", func() {
-		var clusterConfig *virtconfig.ClusterConfig
-
-		BeforeEach(func() {
-			kv := kubecli.NewMinimalKubeVirt(kubevirtCRName)
-			kv.Namespace = kubevirtNamespace
-
-			clusterConfig = newClusterConfig(kv)
-		})
-
 		It("should generate Istio annotation when VMI is connected to pod network using masquerade binding", func() {
 			vmi := libvmi.New(
 				libvmi.WithInterface(*v1.DefaultMasqueradeNetworkInterface()),
 				libvmi.WithNetwork(v1.DefaultPodNetwork()),
 			)
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations, err := generator.Generate(vmi)
 			Expect(err).NotTo(HaveOccurred())
 
@@ -168,7 +141,7 @@ var _ = Describe("Annotations Generator", func() {
 		})
 
 		DescribeTable("should not generate Istio annotation", func(vmi *v1.VirtualMachineInstance) {
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations, err := generator.Generate(vmi)
 			Expect(err).NotTo(HaveOccurred())
 
@@ -186,10 +159,7 @@ var _ = Describe("Annotations Generator", func() {
 	})
 
 	Context("Network naming scheme conversion during migration", func() {
-		var (
-			clusterConfig *virtconfig.ClusterConfig
-			vmi           *v1.VirtualMachineInstance
-		)
+		var vmi *v1.VirtualMachineInstance
 
 		BeforeEach(func() {
 			const (
@@ -200,11 +170,6 @@ var _ = Describe("Annotations Generator", func() {
 				networkAttachmentDefinitionName2 = "other-namespace/test1"
 			)
 
-			kv := kubecli.NewMinimalKubeVirt(kubevirtCRName)
-			kv.Namespace = kubevirtNamespace
-
-			clusterConfig = newClusterConfig(kv)
-
 			vmi = libvmi.New(
 				libvmi.WithNamespace(testNamespace),
 				libvmi.WithInterface(*v1.DefaultBridgeNetworkInterface()),
@@ -226,7 +191,7 @@ var _ = Describe("Annotations Generator", func() {
 
 			sourcePod := newStubVirtLauncherPod(vmi, sourcePodAnnotations)
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			convertedAnnotations, err := generator.GenerateFromSource(vmi, sourcePod)
 			Expect(err).ToNot(HaveOccurred())
 
@@ -247,7 +212,7 @@ var _ = Describe("Annotations Generator", func() {
 
 			sourcePod := newStubVirtLauncherPod(vmi, sourcePodAnnotations)
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations, err := generator.GenerateFromSource(vmi, sourcePod)
 			Expect(err).ToNot(HaveOccurred())
 
@@ -305,22 +270,13 @@ var _ = Describe("Annotations Generator", func() {
 }`
 		)
 
-		var clusterConfig *virtconfig.ClusterConfig
+		var clusterConfig stubClusterConfig
 
 		BeforeEach(func() {
-			kv := kubecli.NewMinimalKubeVirt(kubevirtCRName)
-			kv.Namespace = kubevirtNamespace
-
-			kv.Spec.Configuration = v1.KubeVirtConfiguration{
-				NetworkConfiguration: &v1.NetworkConfiguration{
-					Binding: map[string]v1.InterfaceBindingPlugin{
-						deviceInfoPlugin:    {DownwardAPI: v1.DeviceInfo},
-						nonDeviceInfoPlugin: {},
-					},
-				},
+			clusterConfig.registeredPlugins = map[string]v1.InterfaceBindingPlugin{
+				deviceInfoPlugin:    {DownwardAPI: v1.DeviceInfo},
+				nonDeviceInfoPlugin: {},
 			}
-
-			clusterConfig = newClusterConfig(kv)
 		})
 
 		It("Should not generate the network info annotation when there are no networks", func() {
@@ -515,15 +471,6 @@ var _ = Describe("Annotations Generator", func() {
 				`]`
 		)
 
-		var clusterConfig *virtconfig.ClusterConfig
-
-		BeforeEach(func() {
-			kv := kubecli.NewMinimalKubeVirt(kubevirtCRName)
-			kv.Namespace = kubevirtNamespace
-
-			clusterConfig = newClusterConfig(kv)
-		})
-
 		It("Should not generate network attachment annotation when there are no networks", func() {
 			vmi := libvmi.New(
 				libvmi.WithNamespace(testNamespace),
@@ -534,7 +481,7 @@ var _ = Describe("Annotations Generator", func() {
 				networkv1.NetworkStatusAnnot: multusNetworkStatusWithPrimaryNet,
 			})
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 
 			annotations := generator.GenerateFromActivePod(vmi, pod)
 			Expect(annotations).ToNot(HaveKey(networkv1.NetworkAttachmentAnnot))
@@ -548,7 +495,7 @@ var _ = Describe("Annotations Generator", func() {
 			)
 
 			pod := newStubVirtLauncherPod(vmi, map[string]string{})
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 
 			annotations := generator.GenerateFromActivePod(vmi, pod)
 			Expect(annotations).ToNot(HaveKey(networkv1.NetworkAttachmentAnnot))
@@ -570,7 +517,7 @@ var _ = Describe("Annotations Generator", func() {
 				)
 
 				pod := newStubVirtLauncherPod(vmi, podAnnotations)
-				generator := annotations.NewGenerator(clusterConfig)
+				generator := annotations.NewGenerator(stubClusterConfig{})
 
 				annotations := generator.GenerateFromActivePod(vmi, pod)
 				Expect(annotations).ToNot(HaveKey(networkv1.NetworkAttachmentAnnot))
@@ -611,7 +558,7 @@ var _ = Describe("Annotations Generator", func() {
 				networkv1.NetworkAttachmentAnnot: multusNetworksAnnotation,
 				networkv1.NetworkStatusAnnot:     multusNetworkStatusWithPrimaryAndSecondaryNets,
 			})
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 
 			annotations := generator.GenerateFromActivePod(vmi, pod)
 			Expect(annotations).ToNot(HaveKey(networkv1.NetworkAttachmentAnnot))
@@ -630,7 +577,7 @@ var _ = Describe("Annotations Generator", func() {
 				podAnnotations := map[string]string{
 					networkv1.NetworkStatusAnnot: multusNetworkStatusWithPrimaryNet,
 				}
-				generator := annotations.NewGenerator(clusterConfig)
+				generator := annotations.NewGenerator(stubClusterConfig{})
 				annotations := generator.GenerateFromActivePod(vmi, newStubVirtLauncherPod(vmi, podAnnotations))
 
 				Expect(annotations[networkv1.NetworkAttachmentAnnot]).To(MatchJSON(multusNetworksAnnotation))
@@ -649,7 +596,7 @@ var _ = Describe("Annotations Generator", func() {
 					libvmi.WithNetwork(libvmi.MultusNetwork(network2Name, networkAttachmentDefinitionName2)),
 				)
 
-				generator := annotations.NewGenerator(clusterConfig)
+				generator := annotations.NewGenerator(stubClusterConfig{})
 				annotations := generator.GenerateFromActivePod(vmi, newStubVirtLauncherPod(vmi, podAnnotations))
 
 				Expect(annotations[networkv1.NetworkAttachmentAnnot]).To(MatchJSON(expectedMultusAnnotation))
@@ -679,7 +626,7 @@ var _ = Describe("Annotations Generator", func() {
 				networkv1.NetworkStatusAnnot: multusNetworkStatusWithPrimaryNet,
 			}
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations := generator.GenerateFromActivePod(vmi, newStubVirtLauncherPod(vmi, podAnnotations))
 
 			Expect(annotations[networkv1.NetworkAttachmentAnnot]).To(MatchJSON(multusNetworksAnnotationWithTwoNets))
@@ -701,19 +648,36 @@ var _ = Describe("Annotations Generator", func() {
 				networkv1.NetworkStatusAnnot: multusNetworkStatusWithPrimaryNet,
 			}
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations := generator.GenerateFromActivePod(vmi, newStubVirtLauncherPod(vmi, podAnnotations))
 
 			Expect(annotations).ToNot(HaveKey(networkv1.NetworkAttachmentAnnot))
 		})
 
 		It("Should generate network attachment annotation when a secondary interface is hot unplugged", func() {
+			ifaceWithStateAbsent := libvmi.InterfaceDeviceWithBridgeBinding(network1Name)
+			ifaceWithStateAbsent.State = v1.InterfaceStateAbsent
 			vmi := libvmi.New(
 				libvmi.WithNamespace(testNamespace),
 				libvmi.WithInterface(*v1.DefaultBridgeNetworkInterface()),
+				libvmi.WithInterface(ifaceWithStateAbsent),
 				libvmi.WithInterface(libvmi.InterfaceDeviceWithBridgeBinding(network2Name)),
 				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+				libvmi.WithNetwork(libvmi.MultusNetwork(network1Name, networkAttachmentDefinitionName1)),
 				libvmi.WithNetwork(libvmi.MultusNetwork(network2Name, networkAttachmentDefinitionName2)),
+				libvmistatus.WithStatus(
+					libvmistatus.New(
+						libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{Name: "default", PodInterfaceName: "eth0"}),
+						libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{
+							Name:       network1Name,
+							InfoSource: vmispec.InfoSourceMultusStatus,
+						}),
+						libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{
+							Name:       network2Name,
+							InfoSource: vmispec.InfoSourceMultusStatus,
+						}),
+					),
+				),
 			)
 
 			podAnnotations := map[string]string{
@@ -721,7 +685,7 @@ var _ = Describe("Annotations Generator", func() {
 				networkv1.NetworkStatusAnnot:     multusNetworkStatusWithPrimaryAndTwoSecondaryNets,
 			}
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations := generator.GenerateFromActivePod(vmi, newStubVirtLauncherPod(vmi, podAnnotations))
 
 			const expectedMultusNetAttach = `[{"name":"other-net","namespace":"default","interface":"pod16477688c0e"}]`
@@ -729,10 +693,23 @@ var _ = Describe("Annotations Generator", func() {
 		})
 
 		It("Should remove the Multus network attachment annotation when the last secondary interface is hot unplugged", func() {
+			ifaceWithStateAbsent := libvmi.InterfaceDeviceWithBridgeBinding(network1Name)
+			ifaceWithStateAbsent.State = v1.InterfaceStateAbsent
 			vmi := libvmi.New(
 				libvmi.WithNamespace(testNamespace),
 				libvmi.WithInterface(*v1.DefaultBridgeNetworkInterface()),
+				libvmi.WithInterface(ifaceWithStateAbsent),
 				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+				libvmi.WithNetwork(libvmi.MultusNetwork(network1Name, networkAttachmentDefinitionName1)),
+				libvmistatus.WithStatus(
+					libvmistatus.New(
+						libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{Name: "default", PodInterfaceName: "eth0"}),
+						libvmistatus.WithInterfaceStatus(v1.VirtualMachineInstanceNetworkInterface{
+							Name:       network1Name,
+							InfoSource: vmispec.InfoSourceMultusStatus,
+						}),
+					),
+				),
 			)
 
 			podAnnotations := map[string]string{
@@ -740,7 +717,7 @@ var _ = Describe("Annotations Generator", func() {
 				networkv1.NetworkStatusAnnot:     multusNetworkStatusWithPrimaryAndSecondaryNets,
 			}
 
-			generator := annotations.NewGenerator(clusterConfig)
+			generator := annotations.NewGenerator(stubClusterConfig{})
 			annotations := generator.GenerateFromActivePod(vmi, newStubVirtLauncherPod(vmi, podAnnotations))
 
 			Expect(annotations).To(HaveKeyWithValue(networkv1.NetworkAttachmentAnnot, ""))
@@ -748,11 +725,6 @@ var _ = Describe("Annotations Generator", func() {
 	})
 })
 
-func newClusterConfig(kv *v1.KubeVirt) *virtconfig.ClusterConfig {
-	clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKV(kv)
-	return clusterConfig
-}
-
 func newMultusDefaultPodNetwork(name, networkAttachmentDefinitionName string) *v1.Network {
 	return &v1.Network{
 		Name: name,
@@ -774,3 +746,11 @@ func newStubVirtLauncherPod(vmi *v1.VirtualMachineInstance, podAnnotations map[s
 		},
 	}
 }
+
+type stubClusterConfig struct {
+	registeredPlugins map[string]v1.InterfaceBindingPlugin
+}
+
+func (s stubClusterConfig) GetNetworkBindings() map[string]v1.InterfaceBindingPlugin {
+	return s.registeredPlugins
+}
