@@ -26,8 +26,6 @@ import (
 
 	"kubevirt.io/client-go/log"
 
-	"kubevirt.io/kubevirt/pkg/network/namescheme"
-
 	v1 "kubevirt.io/api/core/v1"
 
 	"kubevirt.io/kubevirt/pkg/util"
@@ -88,13 +86,9 @@ func (c *NetConf) Setup(vmi *v1.VirtualMachineInstance, networks []v1.Network, l
 	state, ok := c.state[string(vmi.UID)]
 	c.configStateMutex.RUnlock()
 	if !ok {
-		cache := NewConfigStateCache(string(vmi.UID), c.cacheCreator)
-		configStateCache, err := upgradeConfigStateCache(&cache, networks, c.cacheCreator, string(vmi.UID))
-		if err != nil {
-			return err
-		}
+		configStateCache := NewConfigStateCache(string(vmi.UID), c.cacheCreator)
 		ns := c.nsFactory(launcherPid)
-		state = netpod.NewState(configStateCache, ns)
+		state = netpod.NewState(&configStateCache, ns)
 		c.configStateMutex.Lock()
 		c.state[string(vmi.UID)] = state
 		c.configStateMutex.Unlock()
@@ -126,31 +120,6 @@ func (c *NetConf) Setup(vmi *v1.VirtualMachineInstance, networks []v1.Network, l
 	return nil
 }
 
-func upgradeConfigStateCache(stateCache *ConfigStateCache, networks []v1.Network, cacheCreator cacheCreator, vmiUID string) (*ConfigStateCache, error) {
-	for networkName, podIfaceName := range namescheme.CreateOrdinalNetworkNameScheme(networks) {
-		exists, err := stateCache.Exists(podIfaceName)
-		if err != nil {
-			return nil, err
-		}
-		if exists {
-			data, rErr := stateCache.Read(podIfaceName)
-			if rErr != nil {
-				return nil, rErr
-			}
-			if wErr := stateCache.Write(networkName, data); wErr != nil {
-				return nil, wErr
-			}
-			if dErr := stateCache.Delete(podIfaceName); dErr != nil {
-				log.Log.Reason(dErr).Errorf("failed to delete pod interface (%s) state from cache", podIfaceName)
-			}
-			if dErr := cache.DeletePodInterfaceCache(cacheCreator, vmiUID, podIfaceName); dErr != nil {
-				log.Log.Reason(dErr).Errorf("failed to delete pod interface (%s) from cache", podIfaceName)
-			}
-		}
-	}
-	return stateCache, nil
-}
-
 func (c *NetConf) Teardown(vmi *v1.VirtualMachineInstance) error {
 	c.configStateMutex.Lock()
 	delete(c.state, string(vmi.UID))
