@@ -41,6 +41,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/tools/record"
+	"k8s.io/client-go/util/certificate"
 	"k8s.io/client-go/util/workqueue"
 	virtv1 "kubevirt.io/api/core/v1"
 	exportv1 "kubevirt.io/api/export/v1beta1"
@@ -57,7 +58,6 @@ import (
 	preferencefind "kubevirt.io/kubevirt/pkg/instancetype/preference/find"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/storage/snapshot"
-	"kubevirt.io/kubevirt/pkg/storage/status"
 	"kubevirt.io/kubevirt/pkg/storage/types"
 	storageutils "kubevirt.io/kubevirt/pkg/storage/utils"
 	kutil "kubevirt.io/kubevirt/pkg/util"
@@ -221,13 +221,11 @@ type VMExportController struct {
 
 	vmExportQueue workqueue.TypedRateLimitingInterface[string]
 
-	caCertManager *bootstrap.FileCertificateManager
+	caCertManager certificate.Manager
 
 	clusterConfig *virtconfig.ClusterConfig
 
 	instancetypeHandler instancetypeVMHandler
-
-	statusUpdater *status.VMExportStatusUpdater
 }
 
 type CertParams struct {
@@ -369,8 +367,6 @@ func (ctrl *VMExportController) Init() error {
 		),
 	)
 
-	ctrl.statusUpdater = status.NewVMExportStatusUpdater(ctrl.Client)
-
 	initCert(ctrl)
 	return nil
 }
@@ -1280,7 +1276,7 @@ func (ctrl *VMExportController) updateCommonVMExportStatusFields(vmExport, vmExp
 
 func (ctrl *VMExportController) updateVMExportStatus(vmExport, vmExportCopy *exportv1.VirtualMachineExport) error {
 	if !equality.Semantic.DeepEqual(vmExport.Status, vmExportCopy.Status) {
-		if err := ctrl.statusUpdater.UpdateStatus(vmExportCopy); err != nil {
+		if _, err := ctrl.Client.VirtualMachineExport(vmExportCopy.Namespace).UpdateStatus(context.Background(), vmExportCopy, metav1.UpdateOptions{}); err != nil {
 			return err
 		}
 	}
