@@ -19,10 +19,7 @@
 package export
 
 import (
-	"crypto/tls"
 	"fmt"
-	"os"
-	"path/filepath"
 	"time"
 
 	. "github.com/onsi/ginkgo/v2"
@@ -52,12 +49,11 @@ import (
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
 	"kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/pkg/virt-operator/resource/generate/components"
 
-	"kubevirt.io/kubevirt/pkg/certificates/bootstrap"
 	virtcontroller "kubevirt.io/kubevirt/pkg/controller"
 	"kubevirt.io/kubevirt/pkg/testutils"
 	"kubevirt.io/kubevirt/pkg/virt-controller/services"
-	"kubevirt.io/kubevirt/pkg/virt-operator/resource/generate/components"
 )
 
 const (
@@ -92,22 +88,14 @@ var _ = Describe("PVC source", func() {
 		k8sClient                   *k8sfake.Clientset
 		vmExportClient              *kubevirtfake.Clientset
 		fakeVolumeSnapshotProvider  *MockVolumeSnapshotProvider
+		fakeCertManager             *MockCertManager
 		mockVMExportQueue           *testutils.MockWorkQueue[string]
 		routeCache                  cache.Store
 		ingressCache                cache.Store
-		certDir                     string
-		certFilePath                string
-		keyFilePath                 string
 	)
 
 	BeforeEach(func() {
 		ctrl = gomock.NewController(GinkgoT())
-		var err error
-		certDir, err = os.MkdirTemp("", "certs")
-		Expect(err).ToNot(HaveOccurred())
-		certFilePath = filepath.Join(certDir, "tls.crt")
-		keyFilePath = filepath.Join(certDir, "tls.key")
-		writeCertsToDir(certDir)
 		virtClient := kubecli.NewMockKubevirtClient(ctrl)
 		pvcInformer, _ = testutils.NewFakeInformerFor(&k8sv1.PersistentVolumeClaim{})
 		podInformer, _ = testutils.NewFakeInformerFor(&k8sv1.Pod{})
@@ -136,6 +124,7 @@ var _ = Describe("PVC source", func() {
 		fakeVolumeSnapshotProvider = &MockVolumeSnapshotProvider{
 			volumeSnapshots: []*vsv1.VolumeSnapshot{},
 		}
+		fakeCertManager = &MockCertManager{}
 
 		config, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&virtv1.KubeVirtConfiguration{})
 		k8sClient = k8sfake.NewSimpleClientset()
@@ -157,7 +146,7 @@ var _ = Describe("PVC source", func() {
 			DataVolumeInformer:          dvInformer,
 			KubevirtNamespace:           "kubevirt",
 			ManifestRenderer:            services.NewTemplateService("a", 240, "b", "c", "d", "e", "f", pvcInformer.GetStore(), virtClient, config, qemuGid, "g", rqInformer.GetStore(), nsInformer.GetStore()),
-			caCertManager:               bootstrap.NewFileCertificateManager(certFilePath, keyFilePath),
+			caCertManager:               fakeCertManager,
 			RouteCache:                  routeCache,
 			IngressCache:                ingressCache,
 			RouteConfigMapInformer:      cmInformer,
@@ -176,11 +165,8 @@ var _ = Describe("PVC source", func() {
 			ControllerRevisionInformer:  controllerRevisionInformer,
 		}
 		initCert = func(ctrl *VMExportController) {
-			go controller.caCertManager.Start()
-			// Give the thread time to read the certs.
-			Eventually(func() *tls.Certificate {
-				return controller.caCertManager.Current()
-			}, time.Second, time.Millisecond).ShouldNot(BeNil())
+			ctrl.caCertManager.Start()
+			Expect(ctrl.caCertManager.Current()).ToNot(BeNil())
 		}
 
 		controller.Init()
@@ -226,11 +212,6 @@ var _ = Describe("PVC source", func() {
 		).To(Succeed())
 	})
 
-	AfterEach(func() {
-		controller.caCertManager.Stop()
-		os.RemoveAll(certDir)
-	})
-
 	createExporterPod := func(name string, phase k8sv1.PodPhase) *k8sv1.Pod {
 		return &k8sv1.Pod{
 			ObjectMeta: metav1.ObjectMeta{
