@@ -345,7 +345,7 @@ func (ctrl *VMRestoreController) doUpdateErrorWithFailure(restore *snapshotv1.Vi
 
 func (ctrl *VMRestoreController) doUpdateStatus(original, updated *snapshotv1.VirtualMachineRestore) error {
 	if !equality.Semantic.DeepEqual(original.Status, updated.Status) {
-		if err := ctrl.VMRestoreStatusUpdater.UpdateStatus(updated); err != nil {
+		if _, err := ctrl.Client.VirtualMachineRestore(updated.Namespace).UpdateStatus(context.Background(), updated, metav1.UpdateOptions{}); err != nil {
 			return err
 		}
 	}
@@ -497,6 +497,8 @@ func (ctrl *VMRestoreController) reconcileVolumeRestores(vmRestore *snapshotv1.V
 	createdPVC := false
 	deletedPVC := false
 	waitingPVC := false
+	waitingDVNameUpdate := false
+
 	for i, restore := range restores {
 		pvc, err := ctrl.getPVC(vmRestore.Namespace, restore.PersistentVolumeClaimName)
 		if err != nil {
@@ -532,7 +534,15 @@ func (ctrl *VMRestoreController) reconcileVolumeRestores(vmRestore *snapshotv1.V
 			if ownerDV != "" {
 				log.Log.Object(vmRestore).Infof("marking datavolume %s/%s as prepopulated before deleting its PVC", vmRestore.Namespace, ownerDV)
 
-				vmRestore.Status.Restores[i].DataVolumeName = &ownerDV
+				// We update the status of the volume to note that it belongs to a DataVolume.
+				// We'll need this information later to restore the PVC with annotations to rebind it
+				// to the DV.
+				if vmRestore.Status.Restores[i].DataVolumeName == nil {
+					vmRestore.Status.Restores[i].DataVolumeName = &ownerDV
+					waitingDVNameUpdate = true
+					continue
+				}
+
 				if err := ctrl.prepopulateDataVolume(vmRestore.Namespace, ownerDV, vmRestore.Name); err != nil {
 					return false, err
 				}
@@ -559,7 +569,7 @@ func (ctrl *VMRestoreController) reconcileVolumeRestores(vmRestore *snapshotv1.V
 			return false, fmt.Errorf("PVC %s/%s in status %q", pvc.Namespace, pvc.Name, pvc.Status.Phase)
 		}
 	}
-	return createdPVC || deletedPVC || waitingPVC, nil
+	return createdPVC || deletedPVC || waitingPVC || waitingDVNameUpdate, nil
 }
 
 func (ctrl *VMRestoreController) getBindingMode(pvc *corev1.PersistentVolumeClaim) (*storagev1.VolumeBindingMode, error) {
@@ -682,7 +692,7 @@ func (t *vmRestoreTarget) Reconcile() (bool, error) {
 }
 
 func (t *vmRestoreTarget) reconcileBackendVolume(snapshotVM *snapshotv1.VirtualMachine) (bool, error) {
-	if !backendstorage.IsBackendStorageNeededForVMI(&snapshotVM.Spec.Template.Spec) {
+	if !backendstorage.IsBackendStorageNeeded(snapshotVM) {
 		return true, nil
 	}
 
@@ -1011,7 +1021,7 @@ func (t *vmRestoreTarget) reconcileSpec(restoredVM *kubevirtv1.VirtualMachine) (
 }
 
 func (t *vmRestoreTarget) updateRestorePVCOwnership() error {
-	if !t.Exists() {
+	if isVolumeOwnershipPolicyNone(t.vmRestore) || !t.Exists() {
 		return nil
 	}
 	for _, volume := range t.VirtualMachine().Spec.Template.Spec.Volumes {
@@ -1312,7 +1322,7 @@ func (ctrl *VMRestoreController) deleteObsoleteVolumes(vmRestore *snapshotv1.Vir
 
 func (ctrl *VMRestoreController) deleteObsoleteBackendPVC(vmRestore *snapshotv1.VirtualMachineRestore, target restoreTarget) error {
 	// Target should always exist at this point, just nil check for safety.
-	if target.Exists() && backendstorage.IsBackendStorageNeededForVM(target.VirtualMachine()) {
+	if target.Exists() && backendstorage.IsBackendStorageNeeded(target.VirtualMachine()) {
 		pvcs, err := ctrl.Client.CoreV1().PersistentVolumeClaims(vmRestore.Namespace).List(context.Background(), metav1.ListOptions{
 			LabelSelector: fmt.Sprintf("%s=%s", restoreCleanupBackendPVCLabel, getCleanupLabelValue(vmRestore)),
 		})
@@ -1490,7 +1500,7 @@ func (ctrl *VMRestoreController) createRestorePVC(
 	volumeBackup *snapshotv1.VolumeBackup,
 	volumeRestore *snapshotv1.VolumeRestore,
 	sourceVm *snapshotv1.VirtualMachine,
-	ownerOrphanDV string,
+	dvOwner string,
 ) error {
 	sourceVmName := sourceVm.Name
 	sourceVmNamespace := sourceVm.Namespace
@@ -1521,17 +1531,13 @@ func (ctrl *VMRestoreController) createRestorePVC(
 		pvc.Annotations = make(map[string]string)
 	}
 
-	if ownerOrphanDV != "" { // PVC is owned by a non-templated DV
-		if pvc.Annotations == nil {
-			pvc.Annotations = make(map[string]string)
-		}
-
+	if dvOwner != "" { // PVC is owned by a DV
 		// By setting this annotation, the CDI will set ownership of the PVC to the DV
-		pvc.Annotations[populatedForPVCAnnotation] = ownerOrphanDV
-	} else {
+		pvc.Annotations[populatedForPVCAnnotation] = dvOwner
+	} else if !isVolumeOwnershipPolicyNone(vmRestore) { // PVC is owned by the VM
 		if target.Exists() {
 			target.Own(pvc)
-		} else if sourcePVCOwnedBySourceVM(volumeBackup, sourceVm) { // PVC is owned by the VM
+		} else if sourcePVCOwnedBySourceVM(volumeBackup, sourceVm) {
 			pvc.Annotations[restoreOwnedByVMLabel] = vmRestore.Name
 		}
 	}
@@ -1753,11 +1759,9 @@ func (ctrl *VMRestoreController) prepopulateDataVolume(namespace, dataVolume, re
 	restoreNamePatch := patch.WithAdd(restoreNameAnnotation, restoreName)
 
 	// Set the DV as prepopulated so that it doesn't reconcile itself
-	// This value is arbitrarily set to "true", it will be replaced with the name of the PVC
-	// backing this DataVolume by the CDI once it finds the associated PVC
 	// As long as the annotation is present (no matter the value), the population process is blocked
 	prePopulatedAnnotation := fmt.Sprintf("/metadata/annotations/%s", patch.EscapeJSONPointer(cdiv1.AnnPrePopulated))
-	prePopulatedPatch := patch.WithAdd(prePopulatedAnnotation, "true")
+	prePopulatedPatch := patch.WithAdd(prePopulatedAnnotation, dataVolume)
 
 	// Craft the patch payload
 	dvPatch := patch.New(restoreNamePatch, prePopulatedPatch)
@@ -1771,6 +1775,16 @@ func (ctrl *VMRestoreController) prepopulateDataVolume(namespace, dataVolume, re
 	return err
 }
 
+// isVolumeOwnershipPolicyNone determines if the VolumeOwnershipPolicy is set to "None"
+// If this is the case, the restored volumes will not be owned by the restored VM
+func isVolumeOwnershipPolicyNone(vmRestore *snapshotv1.VirtualMachineRestore) bool {
+	if vmRestore.Spec.VolumeOwnershipPolicy == nil {
+		return false
+	}
+
+	return *vmRestore.Spec.VolumeOwnershipPolicy == snapshotv1.VolumeOwnershipPolicyNone
+}
+
 func setLegacyFirmwareUUID(vm *kubevirtv1.VirtualMachine) {
 	if vm.Spec.Template.Spec.Domain.Firmware == nil {
 		vm.Spec.Template.Spec.Domain.Firmware = &kubevirtv1.Firmware{}
