@@ -61,8 +61,8 @@ var _ = Describe("Object Graph", func() {
 	BeforeEach(func() {
 		ctrl := gomock.NewController(GinkgoT())
 		kvClient = kubecli.NewMockKubevirtClient(ctrl)
+		kubeClient = fake.NewClientset()
 
-		kubeClient = fake.NewSimpleClientset()
 		kvClient.EXPECT().CoreV1().Return(kubeClient.CoreV1()).AnyTimes()
 
 		vm = &v1.VirtualMachine{
@@ -255,6 +255,14 @@ var _ = Describe("Object Graph", func() {
 										},
 									},
 								},
+								{
+									Name: "serviceAccount",
+									VolumeSource: v1.VolumeSource{
+										ServiceAccount: &v1.ServiceAccountVolumeSource{
+											ServiceAccountName: "test-serviceAccount",
+										},
+									},
+								},
 							},
 							Networks: []v1.Network{
 								{
@@ -291,7 +299,7 @@ var _ = Describe("Object Graph", func() {
 			graph := NewObjectGraph(kvClient, &v1.ObjectGraphOptions{})
 			graphNodes, err := graph.GetObjectGraph(vm)
 			Expect(err).NotTo(HaveOccurred())
-			Expect(graphNodes.Children).To(HaveLen(4))
+			Expect(graphNodes.Children).To(HaveLen(5))
 			Expect(graphNodes.ObjectReference.Name).To(Equal("test-vm"))
 			Expect(graphNodes.Children[0].ObjectReference.Name).To(Equal("test-vm"))
 			// Child nodes of the VMI
@@ -302,6 +310,8 @@ var _ = Describe("Object Graph", func() {
 			Expect(graphNodes.Children[2].ObjectReference.Name).To(Equal("test-root-disk-pvc"))
 			Expect(graphNodes.Children[3].ObjectReference.Name).To(Equal("test-datavolume"))
 			Expect(graphNodes.Children[3].ObjectReference.Kind).To(Equal("DataVolume"))
+			Expect(graphNodes.Children[4].ObjectReference.Name).To(Equal("test-serviceAccount"))
+			Expect(graphNodes.Children[4].ObjectReference.Kind).To(Equal("ServiceAccount"))
 			// Child nodes of the DV
 			Expect(graphNodes.Children[3].Children).To(HaveLen(1))
 			Expect(graphNodes.Children[3].Children[0].ObjectReference.Name).To(Equal("test-datavolume"))
@@ -708,4 +718,68 @@ var _ = Describe("Object Graph", func() {
 			}
 		})
 	})
+
+	Context("Network handling", func() {
+		It("should handle VM with Multus network attachment definitions", func() {
+			vm.Spec.Template.Spec.Networks = []v1.Network{
+				{
+					Name: "default",
+					NetworkSource: v1.NetworkSource{
+						Pod: &v1.PodNetwork{},
+					},
+				},
+				{
+					Name: "multus-net",
+					NetworkSource: v1.NetworkSource{
+						Multus: &v1.MultusNetwork{
+							NetworkName: "test-nad",
+						},
+					},
+				},
+			}
+
+			graph := NewObjectGraph(kvClient, &v1.ObjectGraphOptions{})
+			graphNodes, err := graph.GetObjectGraph(vm)
+			Expect(err).NotTo(HaveOccurred())
+
+			// Check for NetworkAttachmentDefinition in children
+			childMap := make(map[string]string)
+			for _, child := range graphNodes.Children {
+				childMap[child.ObjectReference.Name] = child.ObjectReference.Kind
+			}
+
+			Expect(childMap).To(HaveKey("test-nad"))
+			Expect(childMap["test-nad"]).To(Equal("NetworkAttachmentDefinition"))
+		})
+
+		It("should filter network dependencies by label selector", func() {
+			vm.Spec.Template.Spec.Networks = []v1.Network{
+				{
+					Name: "multus-net",
+					NetworkSource: v1.NetworkSource{
+						Multus: &v1.MultusNetwork{
+							NetworkName: "test-nad",
+						},
+					},
+				},
+			}
+
+			options := &v1.ObjectGraphOptions{
+				LabelSelector: &metav1.LabelSelector{
+					MatchLabels: map[string]string{
+						ObjectGraphDependencyLabel: "network",
+					},
+				},
+			}
+
+			graph := NewObjectGraph(kvClient, options)
+			graphNodes, err := graph.GetObjectGraph(vm)
+			Expect(err).NotTo(HaveOccurred())
+
+			// Should only return network-related nodes
+			for _, child := range graphNodes.Children {
+				Expect(child.Labels[ObjectGraphDependencyLabel]).To(Equal("network"))
+			}
+		})
+	})
 })
