@@ -217,7 +217,6 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 	},
 		Entry("when architecture is amd64", "amd64", v1.DefaultCPUModel, "q35"),
 		Entry("when architecture is arm64", "arm64", v1.CPUModeHostPassthrough, "virt"),
-		Entry("when architecture is ppc64le", "ppc64le", v1.DefaultCPUModel, "pseries"),
 		Entry("when architecture is s390x", "s390x", v1.DefaultCPUModel, "s390-ccw-virtio"),
 	)
 
@@ -235,7 +234,6 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 	},
 		Entry("when architecture is amd64", "amd64", v1.DefaultCPUModel, "q35"),
 		Entry("when architecture is arm64", "arm64", v1.CPUModeHostPassthrough, "virt"),
-		Entry("when architecture is ppc64le", "ppc64le", v1.DefaultCPUModel, "pseries"),
 		Entry("when architecture is s390x", "s390x", v1.DefaultCPUModel, "s390-ccw-virtio"),
 	)
 
@@ -246,9 +244,9 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 					CPUModel:   cpuModelFromConfig,
 					CPURequest: &cpuReq,
 					ArchitectureConfiguration: &v1.ArchConfiguration{
-						Amd64:   &v1.ArchSpecificConfiguration{MachineType: machineTypeFromConfig},
-						Arm64:   &v1.ArchSpecificConfiguration{MachineType: machineTypeFromConfig},
-						Ppc64le: &v1.ArchSpecificConfiguration{MachineType: machineTypeFromConfig},
+						Amd64: &v1.ArchSpecificConfiguration{MachineType: machineTypeFromConfig},
+						Arm64: &v1.ArchSpecificConfiguration{MachineType: machineTypeFromConfig},
+						S390x: &v1.ArchSpecificConfiguration{MachineType: machineTypeFromConfig},
 					},
 				},
 			},
@@ -260,6 +258,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		Expect(*vmiSpec.Domain.Resources.Requests.Cpu()).To(Equal(cpuReq))
 	},
 		Entry("on amd64", "amd64", cpuModelFromConfig),
+		Entry("on s390x", "s390x", cpuModelFromConfig),
 		// Currently only Host-Passthrough is supported on Arm64, so you can only
 		// modify the CPU Model in a VMI yaml file, rather than in cluster config
 		Entry("on arm64", "arm64", v1.CPUModeHostPassthrough),
@@ -521,15 +520,15 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		presentVolumeName := "present-vol"
 		missingVolumeName := "missing-vol"
 		vmi.Spec.Domain.Devices.Disks = []v1.Disk{
-			v1.Disk{
+			{
 				Name: presentVolumeName,
 			},
 		}
 		vmi.Spec.Volumes = []v1.Volume{
-			v1.Volume{
+			{
 				Name: presentVolumeName,
 			},
-			v1.Volume{
+			{
 				Name: missingVolumeName,
 			},
 		}
@@ -648,44 +647,6 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		Expect(vmiSpec.Domain.CPU.Threads).To(Equal(uint32(1)), "Expect threads")
 	})
 
-	It("should apply memory-overcommit when guest-memory is set and memory-request is not set", func() {
-		// no limits wanted on this test, to not copy the limit to requests
-		testutils.UpdateFakeKubeVirtClusterConfig(kvStore, &v1.KubeVirt{
-			Spec: v1.KubeVirtSpec{
-				Configuration: v1.KubeVirtConfiguration{
-					DeveloperConfiguration: &v1.DeveloperConfiguration{
-						MemoryOvercommit: 150,
-					},
-				},
-			},
-		})
-
-		guestMemory := resource.MustParse("3072M")
-		vmi.Spec.Domain.Memory = &v1.Memory{Guest: &guestMemory}
-		_, vmiSpec, _ := getMetaSpecStatusFromAdmit()
-		Expect(vmiSpec.Domain.Memory.Guest.String()).To(Equal("3072M"))
-		Expect(vmiSpec.Domain.Resources.Requests.Memory().String()).To(Equal("2048M"))
-	})
-
-	It("should apply memory-overcommit when hugepages are set and memory-request is not set", func() {
-		// no limits wanted on this test, to not copy the limit to requests
-		vmi.Spec.Domain.Memory = &v1.Memory{Hugepages: &v1.Hugepages{PageSize: "3072M"}}
-		_, vmiSpec, _ := getMetaSpecStatusFromAdmit()
-		Expect(vmiSpec.Domain.Memory.Hugepages.PageSize).To(Equal("3072M"))
-		Expect(vmiSpec.Domain.Resources.Requests.Memory().String()).To(Equal("3072M"))
-	})
-
-	It("should not apply memory overcommit when memory-request and guest-memory are set", func() {
-		vmi.Spec.Domain.Resources.Requests = k8sv1.ResourceList{
-			k8sv1.ResourceMemory: resource.MustParse("512M"),
-		}
-		guestMemory := resource.MustParse("4096M")
-		vmi.Spec.Domain.Memory = &v1.Memory{Guest: &guestMemory}
-		_, vmiSpec, _ := getMetaSpecStatusFromAdmit()
-		Expect(vmiSpec.Domain.Resources.Requests.Memory().String()).To(Equal("512M"))
-		Expect(vmiSpec.Domain.Memory.Guest.String()).To(Equal("4096M"))
-	})
-
 	It("should apply foreground finalizer on VMI create", func() {
 		vmiMeta, _, _ := getMetaSpecStatusFromAdmit()
 		Expect(vmiMeta.Finalizers).To(ContainElement(v1.VirtualMachineInstanceFinalizer))
@@ -703,18 +664,6 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		Expect(vmiSpec.Domain.Resources.Limits.Cpu().String()).To(Equal("1"))
 	})
 
-	It("should copy memory limits to requests if only limits are set", func() {
-		vmi.Spec.Domain.Resources = v1.ResourceRequirements{
-			Requests: k8sv1.ResourceList{},
-			Limits: k8sv1.ResourceList{
-				k8sv1.ResourceMemory: resource.MustParse("64M"),
-			},
-		}
-		_, vmiSpec, _ := getMetaSpecStatusFromAdmit()
-		Expect(vmiSpec.Domain.Resources.Requests.Memory().String()).To(Equal("64M"))
-		Expect(vmiSpec.Domain.Resources.Limits.Memory().String()).To(Equal("64M"))
-	})
-
 	DescribeTable("should always set memory.guest", func(options ...libvmi.Option) {
 		for _, option := range options {
 			option(vmi)
@@ -724,12 +673,12 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		Expect(vmiSpec.Domain.Memory.Guest.String()).To(Equal("1Gi"))
 	},
 		Entry("when requests are set",
-			libvmi.WithResourceMemory("1Gi")),
+			libvmi.WithMemoryRequest("1Gi")),
 		Entry("when limits are set",
-			libvmi.WithLimitMemory("1Gi")),
+			libvmi.WithMemoryLimit("1Gi")),
 		Entry("when both requests and limits are set",
-			libvmi.WithResourceMemory("1Gi"),
-			libvmi.WithLimitMemory("1Gi"),
+			libvmi.WithMemoryRequest("1Gi"),
+			libvmi.WithMemoryLimit("1Gi"),
 		),
 		Entry("when only hugepages pagesize is set",
 			libvmi.WithHugepages("1Gi")),
