@@ -14,6 +14,7 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 
 	"kubevirt.io/kubevirt/pkg/downwardmetrics"
+	netvmispec "kubevirt.io/kubevirt/pkg/network/vmispec"
 	"kubevirt.io/kubevirt/pkg/tpm"
 	"kubevirt.io/kubevirt/pkg/util"
 	"kubevirt.io/kubevirt/pkg/util/hardware"
@@ -252,11 +253,35 @@ func WithHugePages(vmMemory *v1.Memory, memoryOverhead resource.Quantity) Resour
 	}
 }
 
-func WithMemoryOvercommit(overcommit int) ResourceRendererOption {
+func WithMemoryRequests(vmiSpecMemory *v1.Memory, overcommit int) ResourceRendererOption {
 	return func(renderer *ResourceRenderer) {
-		memory := renderer.vmRequests[k8sv1.ResourceMemory]
-		memory = *resource.NewQuantity((memory.Value()*int64(100))/int64(overcommit), memory.Format)
-		renderer.vmRequests[k8sv1.ResourceMemory] = memory
+		limit, hasLimit := renderer.vmLimits[k8sv1.ResourceMemory]
+		request, hasRequest := renderer.vmRequests[k8sv1.ResourceMemory]
+		if hasLimit && !limit.IsZero() && (!hasRequest || request.IsZero()) {
+			renderer.vmRequests[k8sv1.ResourceMemory] = limit
+		}
+
+		if _, exists := renderer.vmRequests[k8sv1.ResourceMemory]; exists {
+			return
+		}
+
+		var memory *resource.Quantity
+		if vmiSpecMemory != nil && vmiSpecMemory.Guest != nil {
+			memory = vmiSpecMemory.Guest
+		} else if vmiSpecMemory != nil && vmiSpecMemory.Hugepages != nil {
+			if hugepagesSize, err := resource.ParseQuantity(vmiSpecMemory.Hugepages.PageSize); err == nil {
+				memory = &hugepagesSize
+			}
+		}
+
+		if memory != nil && memory.Value() > 0 {
+			if overcommit == 100 {
+				renderer.vmRequests[k8sv1.ResourceMemory] = *memory
+			} else {
+				value := (memory.Value() * int64(100)) / int64(overcommit)
+				renderer.vmRequests[k8sv1.ResourceMemory] = *resource.NewQuantity(value, memory.Format)
+			}
+		}
 	}
 }
 
@@ -475,7 +500,7 @@ func GetMemoryOverhead(vmi *v1.VirtualMachineInstance, cpuArch string, additiona
 
 	// Consider memory overhead for SEV guests.
 	// Additional information can be found here: https://libvirt.org/kbase/launch_security_sev.html#memory
-	if util.IsSEVVMI(vmi) {
+	if util.IsSEVVMI(vmi) || util.IsSEVSNPVMI(vmi) || util.IsSEVESVMI(vmi) {
 		overhead.Add(resource.MustParse("256Mi"))
 	}
 
@@ -554,10 +579,10 @@ func calcVCPUs(cpu *v1.CPU) int64 {
 
 func getRequiredResources(vmi *v1.VirtualMachineInstance, allowEmulation bool) k8sv1.ResourceList {
 	res := k8sv1.ResourceList{}
-	if util.NeedTunDevice(vmi) {
+	if netvmispec.RequiresTunDevice(vmi) {
 		res[TunDevice] = resource.MustParse("1")
 	}
-	if util.NeedVirtioNetDevice(vmi, allowEmulation) {
+	if netvmispec.RequiresVirtioNetDevice(vmi, allowEmulation) {
 		// Note that about network interface, allowEmulation does not make
 		// any difference on eventual Domain xml, but uniformly making
 		// /dev/vhost-net unavailable and libvirt implicitly fallback
@@ -610,7 +635,7 @@ func validatePermittedHostDevices(spec *v1.VirtualMachineInstanceSpec, config *v
 	}
 
 	if len(errors) != 0 {
-		return fmt.Errorf(strings.Join(errors, " "))
+		return fmt.Errorf("%s", strings.Join(errors, " "))
 	}
 
 	return nil
