@@ -11,22 +11,30 @@ import (
 	"k8s.io/client-go/tools/cache"
 
 	v1 "kubevirt.io/api/core/v1"
+
+	"kubevirt.io/kubevirt/pkg/libvmi"
+	libvmistatus "kubevirt.io/kubevirt/pkg/libvmi/status"
+	"kubevirt.io/kubevirt/pkg/storage/cbt"
+	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 )
 
 var _ = Describe("Container spec renderer", func() {
 	var vsr *VolumeRenderer
+	var config *virtconfig.ClusterConfig
 
 	const (
-		containerDisk = "cdisk1"
-		ephemeralDisk = "disk1"
-		namespace     = "ns1"
-		virtShareDir  = "dir1"
+		containerDisk     = "cdisk1"
+		ephemeralDisk     = "disk1"
+		namespace         = "ns1"
+		virtShareDir      = "dir1"
+		backendStoragePVC = "vm-state-pvc"
+		launcherImage     = "test/virt-launcher:latest"
 	)
 
 	Context("without any options", func() {
 		BeforeEach(func() {
 			var err error
-			vsr, err = NewVolumeRenderer(false, namespace, ephemeralDisk, containerDisk, virtShareDir)
+			vsr, err = NewVolumeRenderer(config, false, launcherImage, make(map[string]string), namespace, ephemeralDisk, containerDisk, virtShareDir)
 			Expect(err).NotTo(HaveOccurred())
 		})
 
@@ -64,7 +72,7 @@ var _ = Describe("Container spec renderer", func() {
 			}
 
 			var err error
-			vsr, err = NewVolumeRenderer(false, namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIVolumes(pvcStore, []v1.Volume{ephemeralVolumeOption}, nil))
+			vsr, err = NewVolumeRenderer(config, false, launcherImage, make(map[string]string), namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIVolumes(pvcStore, []v1.Volume{ephemeralVolumeOption}, nil))
 			Expect(err).NotTo(HaveOccurred())
 		})
 
@@ -123,7 +131,7 @@ var _ = Describe("Container spec renderer", func() {
 			}
 
 			var err error
-			vsr, err = NewVolumeRenderer(false, namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIVolumes(pvcStore, []v1.Volume{hostDisk}, nil))
+			vsr, err = NewVolumeRenderer(config, false, launcherImage, make(map[string]string), namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIVolumes(pvcStore, []v1.Volume{hostDisk}, nil))
 			Expect(err).NotTo(HaveOccurred())
 		})
 
@@ -180,7 +188,7 @@ var _ = Describe("Container spec renderer", func() {
 			}
 
 			var err error
-			vsr, err = NewVolumeRenderer(false, namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIVolumes(pvcStore, []v1.Volume{cloudInitConfig}, nil))
+			vsr, err = NewVolumeRenderer(config, false, launcherImage, make(map[string]string), namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIVolumes(pvcStore, []v1.Volume{cloudInitConfig}, nil))
 			Expect(err).NotTo(HaveOccurred())
 		})
 
@@ -255,7 +263,7 @@ var _ = Describe("Container spec renderer", func() {
 			}
 
 			var err error
-			vsr, err = NewVolumeRenderer(false, namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIVolumes(pvcStore, []v1.Volume{dataVolume}, nil))
+			vsr, err = NewVolumeRenderer(config, false, launcherImage, make(map[string]string), namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIVolumes(pvcStore, []v1.Volume{dataVolume}, nil))
 			Expect(err).NotTo(HaveOccurred())
 		})
 
@@ -303,7 +311,7 @@ var _ = Describe("Container spec renderer", func() {
 			disk := v1.Disk{Name: downwardAPIVolumeName}
 
 			var err error
-			vsr, err = NewVolumeRenderer(false, namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIConfigVolumes([]v1.Disk{disk}, []v1.Volume{downwardAPIVolume}))
+			vsr, err = NewVolumeRenderer(config, false, launcherImage, make(map[string]string), namespace, ephemeralDisk, containerDisk, virtShareDir, withVMIConfigVolumes([]v1.Disk{disk}, []v1.Volume{downwardAPIVolume}))
 			Expect(err).NotTo(HaveOccurred())
 		})
 
@@ -334,6 +342,56 @@ var _ = Describe("Container spec renderer", func() {
 			Expect(vsr.VolumeDevices()).To(BeEmpty())
 		})
 	})
+	Context("With CBT", func() {
+		It("should not mount the CBT subpath when ChangedBlockTracking is not set", func() {
+			vmi := &v1.VirtualMachineInstance{}
+
+			var err error
+			vsr, err = NewVolumeRenderer(config, false, launcherImage, make(map[string]string), namespace, ephemeralDisk, containerDisk, virtShareDir, withBackendStorage(vmi, backendStoragePVC))
+			Expect(err).NotTo(HaveOccurred())
+
+			expectedMount := k8sv1.VolumeMount{
+				Name:      "vm-state",
+				ReadOnly:  false,
+				MountPath: cbt.PathForCBT(vmi),
+				SubPath:   "cbt",
+			}
+
+			Expect(vsr.Mounts()).NotTo(ContainElement(expectedMount))
+		})
+
+		It("should mount the vm state volume and CBT subpath when ChangedBlockTracking is initializing in VMI status", func() {
+			vmi := libvmi.New(
+				libvmistatus.WithStatus(libvmistatus.New(
+					libvmistatus.WithChangedBlockTracking(&v1.ChangedBlockTrackingStatus{State: v1.ChangedBlockTrackingInitializing}),
+				)),
+			)
+
+			var err error
+			vsr, err = NewVolumeRenderer(config, false, launcherImage, make(map[string]string), namespace, ephemeralDisk, containerDisk, virtShareDir, withBackendStorage(vmi, backendStoragePVC))
+			Expect(err).NotTo(HaveOccurred())
+
+			expectedVolume := k8sv1.Volume{
+				Name: "vm-state",
+				VolumeSource: k8sv1.VolumeSource{
+					PersistentVolumeClaim: &k8sv1.PersistentVolumeClaimVolumeSource{
+						ClaimName: backendStoragePVC,
+						ReadOnly:  false,
+					},
+				},
+			}
+			Expect(vsr.Volumes()).To(ContainElement(expectedVolume))
+
+			expectedMount := k8sv1.VolumeMount{
+				Name:      "vm-state",
+				ReadOnly:  false,
+				MountPath: cbt.PathForCBT(vmi),
+				SubPath:   "cbt",
+			}
+
+			Expect(vsr.Mounts()).To(ContainElement(expectedMount))
+		})
+	})
 })
 
 func vmiDiskPath(volumeName string) string {
