@@ -19,6 +19,7 @@ import (
 	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/kubevirt/pkg/controller"
+	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/util/pdbs"
 )
 
@@ -373,7 +374,7 @@ func (c *DisruptionBudgetController) execute(key string) error {
 			log.DefaultLogger().Reason(err).Error("Could not extract namespace and name from the controller key.")
 			return err
 		}
-		vmi = virtv1.NewVMIReferenceFromNameWithNS(namespace, name)
+		vmi = libvmi.New(libvmi.WithName(name), libvmi.WithNamespace(namespace))
 	}
 
 	// Only consider pdbs which belong to this vmi
