@@ -3,10 +3,11 @@ package evacuation
 import (
 	"context"
 	"fmt"
-	"time"
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	"github.com/onsi/gomega/gstruct"
+	"github.com/onsi/gomega/types"
 	"go.uber.org/mock/gomock"
 
 	k8sv1 "k8s.io/api/core/v1"
@@ -15,7 +16,6 @@ import (
 	"k8s.io/client-go/kubernetes/fake"
 	"k8s.io/client-go/testing"
 	"k8s.io/client-go/tools/cache"
-	framework "k8s.io/client-go/tools/cache/testing"
 	"k8s.io/client-go/tools/record"
 
 	v1 "kubevirt.io/api/core/v1"
@@ -28,83 +28,61 @@ import (
 	controllertesting "kubevirt.io/kubevirt/pkg/controller/testing"
 	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/testutils"
+	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
 )
 
 var _ = Describe("Evacuation", func() {
-	var ctrl *gomock.Controller
-	var stop chan struct{}
-	var virtClient *kubecli.MockKubevirtClient
-	var fakeVirtClient *kubevirtfake.Clientset
-	var vmiSource *framework.FakeControllerSource
-	var vmiInformer cache.SharedIndexInformer
-	var nodeSource *framework.FakeControllerSource
-	var nodeInformer cache.SharedIndexInformer
-	var migrationInformer cache.SharedIndexInformer
-	var migrationSource *framework.FakeControllerSource
-	var podInformer cache.SharedIndexInformer
-	var podSource *framework.FakeControllerSource
-	var recorder *record.FakeRecorder
-	var mockQueue *testutils.MockWorkQueue[string]
-	var kubeClient *fake.Clientset
-	var migrationFeeder *testutils.MigrationFeeder[string]
-	var vmiFeeder *testutils.VirtualMachineFeeder[string]
-
-	var controller *EvacuationController
-
-	syncCaches := func(stop chan struct{}) {
-		go vmiInformer.Run(stop)
-		go migrationInformer.Run(stop)
-		go nodeInformer.Run(stop)
-		go podInformer.Run(stop)
-
-		Expect(cache.WaitForCacheSync(stop,
-			vmiInformer.HasSynced,
-			migrationInformer.HasSynced,
-			nodeInformer.HasSynced,
-			podInformer.HasSynced,
-		)).To(BeTrue())
-	}
+	var (
+		virtClient *kubecli.MockKubevirtClient
+		recorder   *record.FakeRecorder
+		controller *EvacuationController
+	)
 
 	addNode := func(node *k8sv1.Node) {
-		mockQueue.ExpectAdds(1)
-		nodeSource.Add(node)
-		mockQueue.Wait()
+		controller.nodeStore.Add(node)
+	}
+	enqueue := func(node *k8sv1.Node) {
+		controller.Queue.Add(node.Name)
 	}
 
 	expectMigrationCreation := func() {
-		migrationList, err := fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(k8sv1.NamespaceDefault).List(context.TODO(), metav1.ListOptions{})
+		migrationList, err := virtClient.VirtualMachineInstanceMigration(k8sv1.NamespaceDefault).List(context.TODO(), metav1.ListOptions{})
 		ExpectWithOffset(1, err).ToNot(HaveOccurred())
 		ExpectWithOffset(1, migrationList.Items).To(HaveLen(1))
 	}
+	updateKV := func(func(kv *v1.KubeVirt)) { panic("Implement me") }
 
 	BeforeEach(func() {
-		stop = make(chan struct{})
-		ctrl = gomock.NewController(GinkgoT())
+		ctrl := gomock.NewController(GinkgoT())
 		virtClient = kubecli.NewMockKubevirtClient(ctrl)
-		fakeVirtClient = kubevirtfake.NewSimpleClientset()
+		fakeVirtClient := kubevirtfake.NewSimpleClientset()
 
-		vmiInformer, vmiSource = testutils.NewFakeInformerWithIndexersFor(&v1.VirtualMachineInstance{}, cache.Indexers{
+		vmiInformer, _ := testutils.NewFakeInformerWithIndexersFor(&v1.VirtualMachineInstance{}, cache.Indexers{
 			cache.NamespaceIndex: cache.MetaNamespaceIndexFunc,
 			"node": func(obj interface{}) (strings []string, e error) {
 				return []string{obj.(*v1.VirtualMachineInstance).Status.NodeName}, nil
 			},
 		})
-		migrationInformer, migrationSource = testutils.NewFakeInformerWithIndexersFor(&v1.VirtualMachineInstanceMigration{}, virtcontroller.GetVirtualMachineInstanceMigrationInformerIndexers())
-		nodeInformer, nodeSource = testutils.NewFakeInformerFor(&k8sv1.Node{})
-		podInformer, podSource = testutils.NewFakeInformerFor(&k8sv1.Pod{})
+		migrationInformer, _ := testutils.NewFakeInformerWithIndexersFor(&v1.VirtualMachineInstanceMigration{}, virtcontroller.GetVirtualMachineInstanceMigrationInformerIndexers())
+		nodeInformer, _ := testutils.NewFakeInformerFor(&k8sv1.Node{})
+		podInformer, _ := testutils.NewFakeInformerFor(&k8sv1.Pod{})
 		recorder = record.NewFakeRecorder(100)
 		recorder.IncludeObject = true
-		config, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{})
+		config, _, kvStore := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{})
+
+		updateKV = func(f func(kv *v1.KubeVirt)) {
+			kv := testutils.GetFakeKubeVirtClusterConfig(kvStore)
+			f(kv)
+			testutils.UpdateFakeKubeVirtClusterConfig(kvStore, kv)
+		}
 
 		controller, _ = NewEvacuationController(vmiInformer, migrationInformer, nodeInformer, podInformer, recorder, virtClient, config)
-		mockQueue = testutils.NewMockWorkQueue(controller.Queue)
+		mockQueue := testutils.NewMockWorkQueue(controller.Queue)
 		controller.Queue = mockQueue
-		migrationFeeder = testutils.NewMigrationFeeder(mockQueue, migrationSource)
-		vmiFeeder = testutils.NewVirtualMachineFeeder(mockQueue, vmiSource)
 
 		// Set up mock client
 		virtClient.EXPECT().VirtualMachineInstanceMigration(k8sv1.NamespaceDefault).Return(fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(k8sv1.NamespaceDefault)).AnyTimes()
-		kubeClient = fake.NewSimpleClientset()
+		kubeClient := fake.NewSimpleClientset()
 		virtClient.EXPECT().CoreV1().Return(kubeClient.CoreV1()).AnyTimes()
 		virtClient.EXPECT().PolicyV1().Return(kubeClient.PolicyV1()).AnyTimes()
 
@@ -113,7 +91,6 @@ var _ = Describe("Evacuation", func() {
 			Expect(action).To(BeNil())
 			return true, nil, nil
 		})
-		syncCaches(stop)
 	})
 
 	sanityExecute := func() {
@@ -124,12 +101,27 @@ var _ = Describe("Evacuation", func() {
 	}
 
 	Context("migration object creation", func() {
-		It("should have expected values and annotations", func() {
-			migration := GenerateNewMigration("my-vmi", "somenode")
+		DescribeTable("should have expected values, annotations and priority", func(fgs []string, annotations map[string]string, matcher types.GomegaMatcher) {
+			config, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
+				DeveloperConfiguration: &v1.DeveloperConfiguration{FeatureGates: fgs},
+			})
+			vmi := newVirtualMachine("my-vmi", "somenode")
+			vmi.Annotations = annotations
+			migration := GenerateNewMigration(vmi, "somenode", config)
 			Expect(migration.Spec.VMIName).To(Equal("my-vmi"))
 			Expect(migration.Annotations[v1.EvacuationMigrationAnnotation]).To(Equal("somenode"))
-		})
-
+			Expect(migration.Spec.Priority).To(matcher)
+		},
+			Entry("with MigrationPriorityQueue feature gate disabled", nil, nil, BeNil()),
+			Entry("with MigrationPriorityQueue feature gate enabled",
+				[]string{featuregate.MigrationPriorityQueue},
+				nil,
+				gstruct.PointTo(BeEquivalentTo("system-critical"))),
+			Entry("with MigrationPriorityQueue feature gate enabled, and descheduler annotation",
+				[]string{featuregate.MigrationPriorityQueue},
+				map[string]string{v1.EvictionSourceAnnotation: "descheduler"},
+				gstruct.PointTo(BeEquivalentTo("system-maintenance"))),
+		)
 	})
 
 	Context("no node eviction in progress", func() {
@@ -137,8 +129,9 @@ var _ = Describe("Evacuation", func() {
 		It("should do nothing with VMIs", func() {
 			node := newNode("testnode")
 			addNode(node)
+			enqueue(node)
 			vmi := newVirtualMachine("testvm", node.Name)
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			sanityExecute()
 		})
@@ -149,9 +142,10 @@ var _ = Describe("Evacuation", func() {
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
 			addNode(node1)
+			enqueue(node1)
 			vmi := newVirtualMachine("testvm", node1.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			sanityExecute()
 		})
@@ -161,14 +155,14 @@ var _ = Describe("Evacuation", func() {
 
 		It("should evict the VMI", func() {
 			node := newNode("testnode")
-			node1 := newNode("anothernode")
+			addNode(newNode("anothernode"))
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
-			addNode(node1)
+			enqueue(node)
 
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			sanityExecute()
 			testutils.ExpectEvent(recorder, SuccessfulCreateVirtualMachineInstanceMigrationReason)
@@ -177,20 +171,20 @@ var _ = Describe("Evacuation", func() {
 
 		It("should ignore VMIs which are not migratable", func() {
 			node := newNode("testnode")
-			node1 := newNode("anothernode")
+			addNode(newNode("anothernode"))
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
-			addNode(node1)
+			enqueue(node)
 
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			vmi.Status.Conditions = []v1.VirtualMachineInstanceCondition{{Type: v1.VirtualMachineInstanceIsMigratable, Status: k8sv1.ConditionFalse}}
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			vmi1 := newVirtualMachine("testvm1", node.Name)
 			vmi1.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			vmi1.Status.Conditions = nil
-			vmiFeeder.Add(vmi1)
+			controller.vmiIndexer.Add(vmi1)
 
 			sanityExecute()
 			testutils.ExpectEvents(recorder,
@@ -203,19 +197,20 @@ var _ = Describe("Evacuation", func() {
 			node := newNode("testnode")
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
+			enqueue(node)
 
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			vmi1 := newVirtualMachine("testvm1", node.Name)
 			vmi1.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
-			vmiFeeder.Add(vmi)
-			vmiFeeder.Add(vmi1)
+			controller.vmiIndexer.Add(vmi)
+			controller.vmiIndexer.Add(vmi1)
 
-			migrationFeeder.Add(newMigration("mig1", vmi.Name, v1.MigrationRunning))
-			migrationFeeder.Add(newMigration("mig2", vmi.Name, v1.MigrationRunning))
-			migrationFeeder.Add(newMigration("mig3", vmi.Name, v1.MigrationRunning))
-			migrationFeeder.Add(newMigration("mig4", vmi.Name, v1.MigrationRunning))
-			migrationFeeder.Add(newMigration("mig5", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig1", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig2", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig3", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig4", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig5", vmi.Name, v1.MigrationRunning))
 
 			sanityExecute()
 
@@ -225,25 +220,29 @@ var _ = Describe("Evacuation", func() {
 			node := newNode("testnode")
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
+			enqueue(node)
 
 			vmi1 := newVirtualMachineMarkedForEviction("testvmi1", node.Name)
 			migration1 := newMigration("mig1", vmi1.Name, v1.MigrationRunning)
-			vmiFeeder.Add(vmi1)
-			migrationFeeder.Add(migration1)
+			controller.vmiIndexer.Add(vmi1)
+			controller.migrationIndexer.Add(migration1)
 
 			vmi2 := newVirtualMachineMarkedForEviction("testvmi2", node.Name)
 			migration2 := newMigration("mig2", vmi1.Name, v1.MigrationRunning)
-			vmiFeeder.Add(vmi2)
-			migrationFeeder.Add(migration2)
+			controller.vmiIndexer.Add(vmi2)
+			controller.migrationIndexer.Add(migration2)
 
 			vmi3 := newVirtualMachineMarkedForEviction("testvmi3", node.Name)
-			vmiFeeder.Add(vmi3)
+			controller.vmiIndexer.Add(vmi3)
 
+			enqueue(node)
 			sanityExecute()
+			Expect(recorder.Events).To(BeEmpty())
 
 			migration2.Status.Phase = v1.MigrationSucceeded
-			migrationFeeder.Modify(migration2)
+			controller.migrationIndexer.Update(migration2)
 
+			enqueue(node)
 			sanityExecute()
 			testutils.ExpectEvent(recorder, SuccessfulCreateVirtualMachineInstanceMigrationReason)
 			expectMigrationCreation()
@@ -255,10 +254,11 @@ var _ = Describe("Evacuation", func() {
 		It("Should evict the VMI", func() {
 			node := newNode("foo")
 			addNode(node)
+			enqueue(node)
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			vmi.Status.EvacuationNodeName = node.Name
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 			sanityExecute()
 			testutils.ExpectEvent(recorder, SuccessfulCreateVirtualMachineInstanceMigrationReason)
 			expectMigrationCreation()
@@ -267,6 +267,7 @@ var _ = Describe("Evacuation", func() {
 		It("Should record a warning on a not migratable VMI", func() {
 			node := newNode("foo")
 			addNode(node)
+			enqueue(node)
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			vmi.Status.Conditions = []v1.VirtualMachineInstanceCondition{
@@ -282,7 +283,7 @@ var _ = Describe("Evacuation", func() {
 				},
 			}
 			vmi.Status.EvacuationNodeName = vmi.Status.NodeName
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 			sanityExecute()
 			testutils.ExpectEvent(recorder, FailedCreateVirtualMachineInstanceMigrationReason)
 		})
@@ -290,6 +291,7 @@ var _ = Describe("Evacuation", func() {
 		It("Should not evict VMI if max migrations are in progress", func() {
 			node := newNode("foo")
 			addNode(node)
+			enqueue(node)
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			vmi.Status.Conditions = []v1.VirtualMachineInstanceCondition{
@@ -299,12 +301,12 @@ var _ = Describe("Evacuation", func() {
 				},
 			}
 			vmi.Status.EvacuationNodeName = node.Name
-			vmiFeeder.Add(vmi)
-			migrationFeeder.Add(newMigration("mig1", vmi.Name, v1.MigrationRunning))
-			migrationFeeder.Add(newMigration("mig2", vmi.Name, v1.MigrationRunning))
-			migrationFeeder.Add(newMigration("mig3", vmi.Name, v1.MigrationRunning))
-			migrationFeeder.Add(newMigration("mig4", vmi.Name, v1.MigrationRunning))
-			migrationFeeder.Add(newMigration("mig5", vmi.Name, v1.MigrationRunning))
+			controller.vmiIndexer.Add(vmi)
+			controller.migrationIndexer.Add(newMigration("mig1", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig2", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig3", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig4", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("mig5", vmi.Name, v1.MigrationRunning))
 			sanityExecute()
 		})
 
@@ -312,30 +314,23 @@ var _ = Describe("Evacuation", func() {
 			const maxParallelMigrationsPerCluster uint32 = 2
 			const maxParallelMigrationsPerSourceNode uint32 = 1
 			const activeMigrations = 10
-			config, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
-				MigrationConfiguration: &v1.MigrationConfiguration{
+
+			updateKV(func(kv *v1.KubeVirt) {
+				kv.Spec.Configuration.MigrationConfiguration = &v1.MigrationConfiguration{
 					ParallelMigrationsPerCluster:      pointer.P(maxParallelMigrationsPerCluster),
 					ParallelOutboundMigrationsPerNode: pointer.P(maxParallelMigrationsPerSourceNode),
-				},
+				}
 			})
 
 			nodeName := "node01"
-			addNode(newNode(nodeName))
-
-			controller, _ =
-				NewEvacuationController(
-					vmiInformer,
-					migrationInformer,
-					nodeInformer,
-					podInformer,
-					recorder,
-					virtClient,
-					config)
+			node := newNode(nodeName)
+			addNode(node)
+			enqueue(node)
 
 			for i := 1; i <= activeMigrations; i++ {
 				vmiName := fmt.Sprintf("testvmi-migrating-%d", i)
-				vmiFeeder.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
-				migrationFeeder.Add(newMigration(fmt.Sprintf("mig%d", i), vmiName, v1.MigrationRunning))
+				controller.vmiIndexer.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
+				controller.migrationIndexer.Add(newMigration(fmt.Sprintf("mig%d", i), vmiName, v1.MigrationRunning))
 			}
 
 			sanityExecute()
@@ -344,6 +339,7 @@ var _ = Describe("Evacuation", func() {
 		It("Should not create a migration if one is already in progress", func() {
 			node := newNode("foo")
 			addNode(node)
+			enqueue(node)
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Status.Conditions = []v1.VirtualMachineInstanceCondition{
 				{
@@ -353,36 +349,32 @@ var _ = Describe("Evacuation", func() {
 			}
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			vmi.Status.EvacuationNodeName = node.Name
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			migration := newMigration("mig1", vmi.Name, v1.MigrationRunning)
 			migration.Status.Phase = v1.MigrationRunning
 
-			migrationFeeder.Add(migration)
+			controller.migrationIndexer.Add(migration)
 
 			sanityExecute()
 		})
 
 		It("should evict the VMI if only one pod is running", func() {
 			node := newNode("testnode")
-			node1 := newNode("anothernode")
+			addNode(newNode("anothernode"))
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
-			addNode(node1)
+			enqueue(node)
 
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 
-			podSource.Add(newPod(vmi, "runningPod", k8sv1.PodRunning, true))
-			podSource.Add(newPod(vmi, "succededPod", k8sv1.PodSucceeded, true))
-			podSource.Add(newPod(vmi, "failedPod", k8sv1.PodFailed, true))
-			podSource.Add(newPod(vmi, "notOwnedRunningPod", k8sv1.PodRunning, false))
-			// pods do not cause the queue to get added to
-			// we just use them for caching purposes
-			// so wait for cache to catch up with a brief sleep
-			time.Sleep(1 * time.Second)
+			controller.vmiPodIndexer.Add(newPod(vmi, "runningPod", k8sv1.PodRunning, true))
+			controller.vmiPodIndexer.Add(newPod(vmi, "succededPod", k8sv1.PodSucceeded, true))
+			controller.vmiPodIndexer.Add(newPod(vmi, "failedPod", k8sv1.PodFailed, true))
+			controller.vmiPodIndexer.Add(newPod(vmi, "notOwnedRunningPod", k8sv1.PodRunning, false))
 
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			sanityExecute()
 			testutils.ExpectEvent(recorder, SuccessfulCreateVirtualMachineInstanceMigrationReason)
@@ -391,40 +383,35 @@ var _ = Describe("Evacuation", func() {
 
 		It("should not evict the VMI with multiple pods active", func() {
 			node := newNode("testnode")
-			node1 := newNode("anothernode")
+			addNode(newNode("anothernode"))
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
-			addNode(node1)
+			enqueue(node)
 
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyLiveMigrate()
 
-			podSource.Add(newPod(vmi, "runningPod", k8sv1.PodRunning, true))
-			podSource.Add(newPod(vmi, "pendingPod", k8sv1.PodPending, true))
-			// pods do not cause the queue to get added to
-			// we just use them for caching purposes
-			// so wait for cache to catch up with a brief sleep
-			time.Sleep(1 * time.Second)
+			controller.vmiPodIndexer.Add(newPod(vmi, "runningPod", k8sv1.PodRunning, true))
+			controller.vmiPodIndexer.Add(newPod(vmi, "pendingPod", k8sv1.PodPending, true))
 
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			sanityExecute()
 		})
 
 		It("should migrate the VMI if EvictionStrategy is set in the cluster config", func() {
-			config, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
-				EvictionStrategy: newEvictionStrategyLiveMigrate(),
+			updateKV(func(kv *v1.KubeVirt) {
+				kv.Spec.Configuration.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			})
-			controller, _ = NewEvacuationController(vmiInformer, migrationInformer, nodeInformer, podInformer, recorder, virtClient, config)
 
 			node := newNode("testnode")
-			node1 := newNode("anothernode")
+			addNode(newNode("anothernode"))
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
-			addNode(node1)
+			enqueue(node)
 
 			vmi := newVirtualMachine("testvm", node.Name)
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			sanityExecute()
 			testutils.ExpectEvent(recorder, SuccessfulCreateVirtualMachineInstanceMigrationReason)
@@ -432,20 +419,19 @@ var _ = Describe("Evacuation", func() {
 		})
 
 		It("should do nothing if EvictionStrategy is set in the cluster config but VMI opted-out", func() {
-			config, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
-				EvictionStrategy: newEvictionStrategyLiveMigrate(),
+			updateKV(func(kv *v1.KubeVirt) {
+				kv.Spec.Configuration.EvictionStrategy = newEvictionStrategyLiveMigrate()
 			})
-			controller, _ = NewEvacuationController(vmiInformer, migrationInformer, nodeInformer, podInformer, recorder, virtClient, config)
 
 			node := newNode("testnode")
-			node1 := newNode("anothernode")
+			addNode(newNode("anothernode"))
 			node.Spec.Taints = append(node.Spec.Taints, *newTaint())
 			addNode(node)
-			addNode(node1)
+			enqueue(node)
 
 			vmi := newVirtualMachine("testvm", node.Name)
 			vmi.Spec.EvictionStrategy = newEvictionStrategyNone()
-			vmiFeeder.Add(vmi)
+			controller.vmiIndexer.Add(vmi)
 
 			sanityExecute()
 		})
@@ -455,37 +441,30 @@ var _ = Describe("Evacuation", func() {
 			var maxParallelMigrationsPerOutboundNode uint32 = 5
 			var activeMigrationsFromThisSourceNode = 4
 			var migrationCandidatesFromThisSourceNode = 4
-			config, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
-				MigrationConfiguration: &v1.MigrationConfiguration{
+
+			updateKV(func(kv *v1.KubeVirt) {
+				kv.Spec.Configuration.MigrationConfiguration = &v1.MigrationConfiguration{
 					ParallelMigrationsPerCluster:      &maxParallelMigrationsPerCluster,
 					ParallelOutboundMigrationsPerNode: &maxParallelMigrationsPerOutboundNode,
-				},
+				}
 			})
 
-			controller, _ =
-				NewEvacuationController(
-					vmiInformer,
-					migrationInformer,
-					nodeInformer,
-					podInformer,
-					recorder,
-					virtClient,
-					config)
-
 			nodeName := "node01"
-			addNode(newNode(nodeName))
+			node := newNode(nodeName)
+			addNode(node)
+			enqueue(node)
 
 			By(fmt.Sprintf("Creating %d active migrations from source node %s", activeMigrationsFromThisSourceNode, nodeName))
 			for i := 1; i <= activeMigrationsFromThisSourceNode; i++ {
 				vmiName := fmt.Sprintf("testvmi%d", i)
-				vmiFeeder.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
-				migrationFeeder.Add(newMigration(fmt.Sprintf("mig%d", i), vmiName, v1.MigrationRunning))
+				controller.vmiIndexer.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
+				controller.migrationIndexer.Add(newMigration(fmt.Sprintf("mig%d", i), vmiName, v1.MigrationRunning))
 			}
 
 			By(fmt.Sprintf("Creating %d migration candidates from source node %s", migrationCandidatesFromThisSourceNode, nodeName))
 			for i := 1; i <= migrationCandidatesFromThisSourceNode; i++ {
 				vmiName := fmt.Sprintf("testvmi%d", i+activeMigrationsFromThisSourceNode)
-				vmiFeeder.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
+				controller.vmiIndexer.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
 			}
 
 			By(fmt.Sprintf("Expect only one new migration from node %s although cluster capacity allows more candidates", nodeName))
@@ -501,36 +480,28 @@ var _ = Describe("Evacuation", func() {
 			const maxParallelMigrationsPerSourceNode uint32 = 10
 			const pendingMigrations = 10
 
-			config, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
-				MigrationConfiguration: &v1.MigrationConfiguration{
+			updateKV(func(kv *v1.KubeVirt) {
+				kv.Spec.Configuration.MigrationConfiguration = &v1.MigrationConfiguration{
 					ParallelMigrationsPerCluster:      pointer.P(maxParallelMigrationsPerCluster),
 					ParallelOutboundMigrationsPerNode: pointer.P(maxParallelMigrationsPerSourceNode),
-				},
+				}
 			})
 
-			controller, _ =
-				NewEvacuationController(
-					vmiInformer,
-					migrationInformer,
-					nodeInformer,
-					podInformer,
-					recorder,
-					virtClient,
-					config)
-
 			nodeName := "node01"
-			addNode(newNode(nodeName))
+			node := newNode(nodeName)
+			addNode(node)
+			enqueue(node)
 
 			By(fmt.Sprintf("Creating %d pending migrations from source node %s", pendingMigrations, nodeName))
 			for i := 1; i <= pendingMigrations; i++ {
 				vmiName := fmt.Sprintf("testvmi%d", i)
-				vmiFeeder.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
-				migrationFeeder.Add(newMigration(fmt.Sprintf("mig%d", i), vmiName, v1.MigrationPending))
+				controller.vmiIndexer.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
+				controller.migrationIndexer.Add(newMigration(fmt.Sprintf("mig%d", i), vmiName, v1.MigrationPending))
 			}
 
 			By(fmt.Sprintf("Creating a migration candidate from source node %s", nodeName))
 			vmiName := fmt.Sprintf("testvmi%d", pendingMigrations+1)
-			vmiFeeder.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
+			controller.vmiIndexer.Add(newVirtualMachineMarkedForEviction(vmiName, nodeName))
 
 			sanityExecute()
 
@@ -541,7 +512,6 @@ var _ = Describe("Evacuation", func() {
 	})
 
 	AfterEach(func() {
-		close(stop)
 		// Ensure that we add checks for expected events to every test
 		Expect(recorder.Events).To(BeEmpty())
 	})
@@ -602,6 +572,7 @@ func newPod(vmi *v1.VirtualMachineInstance, name string, phase k8sv1.PodPhase, o
 		pod.Annotations = map[string]string{
 			v1.DomainAnnotation: vmi.Name,
 		}
+		pod.OwnerReferences = []metav1.OwnerReference{*metav1.NewControllerRef(vmi, v1.VirtualMachineInstanceGroupVersionKind)}
 	}
 
 	return pod
