@@ -99,17 +99,22 @@ const defaultCatchAllPendingTimeoutSeconds = int64(60 * 15)
 // capacity reasons, we need to ensure it doesn't get re-processed as long as
 // capacity hasn't freed up, or it will delay processing of active migrations.
 // The informer will preserve priorities above 0 but bump negative ones to 0.
-const pendingPriority = -100
-const activePriority = 100
 
 var migrationBackoffError = errors.New(controller.MigrationBackoffReason)
 
+type templateService interface {
+	RenderMigrationManifest(vmi *virtv1.VirtualMachineInstance, migration *virtv1.VirtualMachineInstanceMigration, sourcePod *k8sv1.Pod) (*k8sv1.Pod, error)
+	RenderLaunchManifest(vmi *virtv1.VirtualMachineInstance) (*k8sv1.Pod, error)
+	RenderHotplugAttachmentPodTemplate(volumes []*virtv1.Volume, ownerPod *k8sv1.Pod, vmi *virtv1.VirtualMachineInstance, claimMap map[string]*k8sv1.PersistentVolumeClaim) (*k8sv1.Pod, error)
+	GetLauncherImage() string
+}
+
 type networkAnnotationsGenerator interface {
 	GenerateFromActivePod(vmi *virtv1.VirtualMachineInstance, pod *k8sv1.Pod) map[string]string
 }
 
 type Controller struct {
-	templateService                   services.TemplateService
+	templateService                   templateService
 	clientset                         kubecli.KubevirtClient
 	Queue                             priorityqueue.PriorityQueue[string]
 	vmiStore                          cache.Store
@@ -140,7 +145,7 @@ type Controller struct {
 	catchAllPendingTimeoutSeconds      int64
 }
 
-func NewController(templateService services.TemplateService,
+func NewController(templateService templateService,
 	vmiInformer cache.SharedIndexInformer,
 	podInformer cache.SharedIndexInformer,
 	migrationInformer cache.SharedIndexInformer,
@@ -430,11 +435,42 @@ func (c *Controller) execute(key string) error {
 		if err != nil {
 			return err
 		}
+		if c.clusterConfig.MigrationPriorityQueueEnabled() {
+			// re-enqueue of highest priority pending migration since now there is a free spot
+			err = c.reEnqueueHighestPriorityPendingMigrations()
+			if err != nil {
+				return err
+			}
+		}
 	}
 
 	return nil
 }
 
+func (c *Controller) reEnqueueHighestPriorityPendingMigrations() error {
+	unfinishedMigrations := migrationsutil.ListUnfinishedMigrations(c.migrationIndexer)
+	var pendings []*virtv1.VirtualMachineInstanceMigration
+	for _, m := range unfinishedMigrations {
+		if m.Status.Phase == virtv1.MigrationPending {
+			pendings = append(pendings, m)
+		}
+	}
+
+	sort.Slice(pendings, func(i, j int) bool {
+		return migrationsutil.PriorityFromMigration(pendings[i]) > migrationsutil.PriorityFromMigration(pendings[j])
+	})
+
+	parallelLimit := int(*c.clusterConfig.GetMigrationConfiguration().ParallelMigrationsPerCluster)
+	for i := 0; i < min(len(pendings), parallelLimit); i++ {
+		key, err := controller.KeyFunc(pendings[i])
+		if err != nil {
+			continue
+		}
+		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.PriorityFromMigration(pendings[i])}, key)
+	}
+	return nil
+}
+
 func (c *Controller) canMigrateVMI(migration *virtv1.VirtualMachineInstanceMigration, vmi *virtv1.VirtualMachineInstance) (bool, error) {
 
 	if vmi.Status.MigrationState == nil {
@@ -480,7 +516,7 @@ func (c *Controller) failMigration(migration *virtv1.VirtualMachineInstanceMigra
 }
 
 func (c *Controller) interruptMigration(migration *virtv1.VirtualMachineInstanceMigration, vmi *virtv1.VirtualMachineInstance) error {
-	if vmi == nil || !backendstorage.IsBackendStorageNeededForVMI(&vmi.Spec) {
+	if vmi == nil || !backendstorage.IsBackendStorageNeeded(vmi) {
 		return c.failMigration(migration)
 	}
 
@@ -757,7 +793,7 @@ func (c *Controller) processMigrationPhase(
 		if migration.IsLocalOrDecentralizedTarget() {
 			_, exists := pod.Annotations[virtv1.MigrationTargetReadyTimestamp]
 			if !exists && vmi.Status.MigrationState.TargetNodeDomainReadyTimestamp != nil {
-				if backendstorage.IsBackendStorageNeededForVMI(&vmi.Spec) {
+				if backendstorage.IsBackendStorageNeeded(vmi) {
 					err := backendstorage.MigrationHandoff(c.clientset, c.pvcStore, migration)
 					if err != nil {
 						return err
@@ -1017,7 +1053,7 @@ func (c *Controller) handleMigrationBackoff(key string, vmi *virtv1.VirtualMachi
 
 	if backoff > 0 {
 		log.Log.Object(vmi).Errorf("vmi in migration backoff, re-enqueueing after %v", backoff)
-		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: activePriority, After: backoff}, key)
+		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning, After: backoff}, key)
 		return migrationBackoffError
 	}
 	return nil
@@ -1219,7 +1255,7 @@ func (c *Controller) markMigrationAbortInVmiStatus(migration *virtv1.VirtualMach
 		if err != nil {
 			msg := fmt.Sprintf("failed to set MigrationState in VMI status. :%v", err)
 			c.recorder.Eventf(migration, k8sv1.EventTypeWarning, controller.FailedAbortMigrationReason, msg)
-			return fmt.Errorf(msg)
+			return fmt.Errorf("%s", msg)
 		}
 		log.Log.Object(vmi).Infof("Signaled migration %s/%s to be aborted.", migration.Namespace, migration.Name)
 		c.recorder.Eventf(migration, k8sv1.EventTypeNormal, controller.SuccessfulAbortMigrationReason, "Migration is ready to be canceled by virt-handler.")
@@ -1234,11 +1270,11 @@ func (c *Controller) handleTargetPodCreation(key string, migration *virtv1.Virtu
 
 	// Don't start new migrations if we wait for cache updates on migration target pods
 	if c.podExpectations.AllPendingCreations() > 0 {
-		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: activePriority, After: 1 * time.Second}, key)
+		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning, After: 1 * time.Second}, key)
 		return nil
 	} else if controller.VMIActivePodsCount(vmi, c.podIndexer) > 1 {
 		log.Log.Object(migration).Infof("Waiting to schedule target pod for migration because there are already multiple pods running for vmi %s/%s", vmi.Namespace, vmi.Name)
-		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: activePriority, After: 1 * time.Second}, key)
+		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning, After: 1 * time.Second}, key)
 		return nil
 
 	}
@@ -1248,12 +1284,20 @@ func (c *Controller) handleTargetPodCreation(key string, migration *virtv1.Virtu
 	if err != nil {
 		return fmt.Errorf("failed to determin the number of running migrations: %v", err)
 	}
+	log.Log.V(3).Infof("number of running migrations: %d", len(runningMigrations))
 
 	// XXX: Make this configurable, think about limit per node, bandwidth per migration, and so on.
 	if len(runningMigrations) >= int(*c.clusterConfig.GetMigrationConfiguration().ParallelMigrationsPerCluster) {
 		log.Log.Object(migration).Infof("Waiting to schedule target pod for vmi [%s/%s] migration because total running parallel migration count [%d] is currently at the global cluster limit.", vmi.Namespace, vmi.Name, len(runningMigrations))
 		// The controller is busy with active migrations, mark ourselves as low priority to give more cycles to those
-		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: pendingPriority, After: 5 * time.Second}, key)
+		if c.clusterConfig.MigrationPriorityQueueEnabled() {
+			priority := migrationsutil.PriorityFromMigration(migration)
+			delay := getRequeueDelayForPriority(priority)
+			c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: priority, After: delay}, key)
+		} else {
+			c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityPending, After: 5 * time.Second}, key)
+		}
+
 		return nil
 	}
 
@@ -1263,7 +1307,13 @@ func (c *Controller) handleTargetPodCreation(key string, migration *virtv1.Virtu
 		// XXX: Make this configurable, think about inbound migration limit, bandwidth per migration, and so on.
 		log.Log.Object(migration).Infof("Waiting to schedule target pod for vmi [%s/%s] migration because total running parallel outbound migrations on target node [%d] has hit outbound migrations per node limit.", vmi.Namespace, vmi.Name, outboundMigrations)
 		// The controller is busy with active migrations, mark ourselves as low priority to give more cycles to those
-		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: pendingPriority, After: 5 * time.Second}, key)
+		if c.clusterConfig.MigrationPriorityQueueEnabled() {
+			priority := migrationsutil.PriorityFromMigration(migration)
+			delay := getRequeueDelayForPriority(priority)
+			c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: priority, After: delay}, key)
+		} else {
+			c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityPending, After: 5 * time.Second}, key)
+		}
 		return nil
 	}
 
@@ -1280,8 +1330,19 @@ func (c *Controller) handleTargetPodCreation(key string, migration *virtv1.Virtu
 	return nil
 }
 
+func getRequeueDelayForPriority(priority int) time.Duration {
+	switch {
+	case priority >= migrationsutil.QueuePrioritySystemCritical:
+		return 1 * time.Second
+	case priority >= migrationsutil.QueuePriorityUserTriggered:
+		return 3 * time.Second
+	default:
+		return 5 * time.Second // the lowest as it was before
+	}
+}
+
 func (c *Controller) handleBackendStorage(migration *virtv1.VirtualMachineInstanceMigration, vmi *virtv1.VirtualMachineInstance) error {
-	if !backendstorage.IsBackendStorageNeededForVMI(&vmi.Spec) {
+	if !backendstorage.IsBackendStorageNeeded(vmi) {
 		return nil
 	}
 	if migration.Status.MigrationState == nil {
@@ -1473,7 +1534,7 @@ func (c *Controller) handlePendingPodTimeout(migration *virtv1.VirtualMachineIns
 		} else {
 			// Make sure we check this again after some time
 			delay := time.Second * time.Duration(unschedulableTimeout-secondsSpentPending)
-			c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: activePriority, After: delay}, migrationKey)
+			c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning, After: delay}, migrationKey)
 		}
 	}
 
@@ -1482,7 +1543,7 @@ func (c *Controller) handlePendingPodTimeout(migration *virtv1.VirtualMachineIns
 	} else {
 		// Make sure we check this again after some time
 		delay := time.Second * time.Duration(catchAllTimeout-secondsSpentPending)
-		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: activePriority, After: delay}, migrationKey)
+		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning, After: delay}, migrationKey)
 	}
 
 	return nil
@@ -1721,13 +1782,17 @@ func (c *Controller) enqueueMigration(obj interface{}) {
 		logger.Object(migration).Reason(err).Error("Failed to extract key from migration.")
 		return
 	}
-	// If the key is already in the queue at active priority or higher, it will keep that priority.
-	// If the key is already in the queue at pending priority, it will be bumped to 0 (still below all active ones).
-	// If the key is not present in the queue, it will default to the active priority if the migration is running, 0 otherwise.
+	// If the migration is running, it will default to the active priority.
 	if migration.Status.Phase == virtv1.MigrationRunning {
-		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: activePriority}, key)
+		c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning}, key)
 	} else {
-		c.Queue.Add(key)
+		if c.clusterConfig.MigrationPriorityQueueEnabled() {
+			c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.PriorityFromMigration(migration)}, key)
+		} else {
+			// If the key is already in the queue at active priority or higher, it will keep that priority.
+			// If the key is already in the queue at pending priority, it will be bumped to 0 (still below all active ones).
+			c.Queue.Add(key)
+		}
 	}
 }
 
@@ -1789,7 +1854,7 @@ func (c *Controller) addPod(obj interface{}) {
 	}
 	log.Log.V(4).Object(pod).Infof("Pod created for key %s", migrationKey)
 	c.podExpectations.CreationObserved(migrationKey)
-	c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: activePriority}, migrationKey)
+	c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning}, migrationKey)
 }
 
 // When a pod is updated, figure out what migration manages it and wake them
@@ -1834,7 +1899,7 @@ func (c *Controller) updatePod(old, cur interface{}) {
 	if err != nil {
 		return
 	}
-	c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: activePriority}, migrationKey)
+	c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning}, migrationKey)
 }
 
 // When a resourceQuota is updated, figure out if there are pending migration in the namespace
@@ -1947,7 +2012,7 @@ func (c *Controller) addPVC(obj interface{}) {
 	}
 	migrationKey := controller.NamespacedKey(pvc.Namespace, migrationName)
 	c.pvcExpectations.CreationObserved(migrationKey)
-	c.Queue.Add(migrationKey)
+	c.Queue.AddWithOpts(priorityqueue.AddOpts{Priority: migrationsutil.QueuePriorityRunning}, migrationKey)
 }
 
 type vmimCollection []*virtv1.VirtualMachineInstanceMigration
