@@ -31,6 +31,7 @@ import (
 
 	k8sv1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/strategicpatch"
@@ -46,6 +47,7 @@ import (
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
 	"kubevirt.io/kubevirt/pkg/controller"
+	"kubevirt.io/kubevirt/pkg/pointer"
 	backendstorage "kubevirt.io/kubevirt/pkg/storage/backend-storage"
 	storagetypes "kubevirt.io/kubevirt/pkg/storage/types"
 	"kubevirt.io/kubevirt/pkg/util"
@@ -414,6 +416,7 @@ func (c *Controller) updateStatus(vmi *virtv1.VirtualMachineInstance, pod *k8sv1
 
 		if allDeleted {
 			log.Log.V(3).Object(vmi).Infof("all pods have been deleted, removing finalizer")
+			controller.RemoveFinalizer(vmiCopy, virtv1.DeprecatedVirtualMachineInstanceFinalizer)
 			controller.RemoveFinalizer(vmiCopy, virtv1.VirtualMachineInstanceFinalizer)
 			if vmiCopy.Labels != nil {
 				delete(vmiCopy.Labels, virtv1.OutdatedLauncherImageLabel)
@@ -464,9 +467,14 @@ func (c *Controller) updateStatus(vmi *virtv1.VirtualMachineInstance, pod *k8sv1
 
 	case vmi.IsScheduled():
 		if !vmiPodExists {
-			if vmiCopy.IsDecentralizedMigration() {
+			if vmiCopy.IsDecentralizedMigration() && vmiCopy.IsMigrationTarget() {
 				log.Log.Object(vmi).V(2).Infof("setting VMI to WaitingForSync while scheduled because pod does not exist")
 				vmiCopy.Status.Phase = virtv1.WaitingForSync
+				if vmiCopy.Status.MigrationState != nil {
+					vmiCopy.Status.MigrationState.Failed = true
+					vmiCopy.Status.MigrationState.Completed = true
+					vmiCopy.Status.MigrationState.EndTimestamp = pointer.P(metav1.Now())
+				}
 				break
 			}
 			log.Log.Object(vmi).V(5).Infof("setting VMI to failed while scheduled because pod does not exist")
@@ -481,6 +489,7 @@ func (c *Controller) updateStatus(vmi *virtv1.VirtualMachineInstance, pod *k8sv1
 		if vmi.DeletionTimestamp != nil {
 			// Deleted VMI while waiting for sync, remove finalizers.
 			log.Log.Object(vmi).V(1).Infof("deleting VMI while waiting for sync, removing finalizers")
+			controller.RemoveFinalizer(vmiCopy, virtv1.DeprecatedVirtualMachineInstanceFinalizer)
 			controller.RemoveFinalizer(vmiCopy, virtv1.VirtualMachineInstanceFinalizer)
 
 			if !c.hasOwnerVM(vmi) && len(vmiCopy.Finalizers) > 0 {
@@ -494,6 +503,22 @@ func (c *Controller) updateStatus(vmi *virtv1.VirtualMachineInstance, pod *k8sv1
 		return fmt.Errorf("unknown vmi phase %v", vmi.Status.Phase)
 	}
 
+	if vmiCopy.IsMarkedForEviction() {
+		if !conditionManager.HasConditionWithStatus(vmiCopy, virtv1.VirtualMachineInstanceEvictionRequested, k8sv1.ConditionTrue) {
+			now := v1.Now()
+			conditionManager.UpdateCondition(vmiCopy, &virtv1.VirtualMachineInstanceCondition{
+				Type:               virtv1.VirtualMachineInstanceEvictionRequested,
+				Status:             k8sv1.ConditionTrue,
+				Reason:             virtv1.VirtualMachineInstanceReasonEvictionRequested,
+				Message:            "VMI is marked for eviction",
+				LastProbeTime:      now,
+				LastTransitionTime: now,
+			})
+		}
+	} else {
+		conditionManager.RemoveCondition(vmiCopy, virtv1.VirtualMachineInstanceEvictionRequested)
+	}
+
 	// VMI is owned by virt-handler, so patch instead of update
 	if vmi.IsRunning() || vmi.IsScheduled() {
 		patchSet := prepareVMIPatch(vmi, vmiCopy)
@@ -662,13 +687,18 @@ func (c *Controller) syncDynamicAnnotationsAndLabelsToPod(vmi *virtv1.VirtualMac
 		}
 	}
 
+	dynamicLabels := []string{virtv1.NodeNameLabel, virtv1.OutdatedLauncherImageLabel}
+	dynamicLabels = append(dynamicLabels, c.additionalLauncherLabelsSync...)
+	dynamicAnnotations := []string{descheduler.EvictPodAnnotationKeyAlpha, descheduler.EvictPodAnnotationKeyAlphaPreferNoEviction}
+	dynamicAnnotations = append(dynamicAnnotations, c.additionalLauncherAnnotationsSync...)
+
 	syncMap(
-		[]string{virtv1.NodeNameLabel, virtv1.OutdatedLauncherImageLabel},
+		dynamicLabels,
 		vmi.Labels, newPodLabels, pod.ObjectMeta.Labels, "labels",
 	)
 
 	syncMap(
-		[]string{descheduler.EvictPodAnnotationKeyAlpha, descheduler.EvictPodAnnotationKeyAlphaPreferNoEviction},
+		dynamicAnnotations,
 		vmi.Annotations, newPodAnnotations, pod.ObjectMeta.Annotations, "annotations",
 	)
 
@@ -834,7 +864,7 @@ func checkForContainerImageError(pod *k8sv1.Pod) common.SyncError {
 		}
 		reason := containerStatus.State.Waiting.Reason
 		if reason == controller.ErrImagePullReason || reason == controller.ImagePullBackOffReason {
-			return common.NewSyncError(fmt.Errorf(containerStatus.State.Waiting.Message), reason)
+			return common.NewSyncError(fmt.Errorf("%s", containerStatus.State.Waiting.Message), reason)
 		}
 	}
 	return nil
@@ -847,7 +877,7 @@ func (c *Controller) deleteAllMatchingPods(vmi *virtv1.VirtualMachineInstance) e
 	}
 	vmiKey := controller.VirtualMachineInstanceKey(vmi)
 	for _, pod := range pods {
-		if pod.DeletionTimestamp != nil && !isPodFinal(pod) || !controller.IsControlledBy(pod, vmi) {
+		if pod.DeletionTimestamp != nil && !isPodFinal(pod) || !v1.IsControlledBy(pod, vmi) {
 			continue
 		}
 		if err = c.deletePod(vmiKey, pod, v1.DeleteOptions{}); err != nil {
@@ -884,7 +914,7 @@ func (c *Controller) setActivePods(vmi *virtv1.VirtualMachineInstance) (*virtv1.
 	activePods := make(map[types.UID]string)
 	count := 0
 	for _, pod := range pods {
-		if !controller.IsControlledBy(pod, vmi) {
+		if !v1.IsControlledBy(pod, vmi) {
 			continue
 		}
 		count++
@@ -903,7 +933,7 @@ func (c *Controller) allPodsDeleted(vmi *virtv1.VirtualMachineInstance) (bool, e
 		return false, err
 	}
 	for _, pod := range pods {
-		if controller.IsControlledBy(pod, vmi) {
+		if v1.IsControlledBy(pod, vmi) {
 			return false, nil
 		}
 	}
@@ -982,10 +1012,10 @@ func (c *Controller) waitForFirstConsumerTemporaryPods(vmi *virtv1.VirtualMachin
 		if !isTempPod(pod) {
 			continue
 		}
-		if controller.IsControlledBy(pod, vmi) {
+		if v1.IsControlledBy(pod, vmi) {
 			temporaryPods = append(temporaryPods, pod)
 		}
-		if ownerRef := controller.GetControllerOf(pod); ownerRef != nil && ownerRef.UID == virtLauncherPod.UID {
+		if v1.IsControlledBy(pod, virtLauncherPod) {
 			temporaryPods = append(temporaryPods, pod)
 		}
 	}
