@@ -134,6 +134,7 @@ type DeviceController struct {
 	stop                chan struct{}
 	mdevTypesManager    *MDEVTypesManager
 	clientset           k8scli.CoreV1Interface
+	mdevRefreshWG       *sync.WaitGroup
 }
 
 func NewDeviceController(
@@ -159,6 +160,7 @@ func NewDeviceController(
 		virtConfig:       clusterConfig,
 		mdevTypesManager: NewMDEVTypesManager(),
 		clientset:        clientset,
+		mdevRefreshWG:    &sync.WaitGroup{},
 	}
 
 	return controller
@@ -253,7 +255,7 @@ func (c *DeviceController) updatePermittedHostDevicePlugins() []Device {
 func removeSelectorSpaces(selectorName string) string {
 	// The name usually contain spaces which should be replaced with _
 	// Such as GRID T4-1Q
-	typeNameStr := strings.Replace(string(selectorName), " ", "_", -1)
+	typeNameStr := strings.Replace(selectorName, " ", "_", -1)
 	typeNameStr = strings.TrimSpace(typeNameStr)
 	return typeNameStr
 }
@@ -308,16 +310,15 @@ func (c *DeviceController) refreshMediatedDeviceTypes() bool {
 		return false
 	}
 
-	requiresDevicePluginsUpdate := false
 	node, err := c.clientset.Nodes().Get(context.Background(), c.host, metav1.GetOptions{})
 	if err != nil {
 		log.Log.Reason(err).Errorf("failed to configure the desired mdev types, failed to get node details")
-		return requiresDevicePluginsUpdate
+		return false
 	}
 	externallyProvidedMdevMap := c.getExternallyProvidedMdevs()
 
 	nodeDesiredMdevTypesList := c.virtConfig.GetDesiredMDEVTypes(node)
-	requiresDevicePluginsUpdate, err = c.mdevTypesManager.updateMDEVTypesConfiguration(nodeDesiredMdevTypesList, externallyProvidedMdevMap)
+	requiresDevicePluginsUpdate, err := c.mdevTypesManager.updateMDEVTypesConfiguration(nodeDesiredMdevTypesList, externallyProvidedMdevMap)
 	if err != nil {
 		log.Log.Reason(err).Errorf("failed to configure the desired mdev types: %s", strings.Join(nodeDesiredMdevTypesList, ", "))
 	}
@@ -325,6 +326,7 @@ func (c *DeviceController) refreshMediatedDeviceTypes() bool {
 }
 
 func (c *DeviceController) refreshPermittedDevices() {
+	c.mdevRefreshWG.Add(1)
 	logger := log.DefaultLogger()
 	var debugDevAdded []string
 	var debugDevRemoved []string
@@ -352,9 +354,14 @@ func (c *DeviceController) refreshPermittedDevices() {
 		debugDevRemoved = append(debugDevRemoved, resourceName)
 	}
 
-	logger.Info("refreshed device plugins for permitted/forbidden host devices")
-	logger.Infof("enabled device-plugins for: %v", debugDevAdded)
-	logger.Infof("disabled device-plugins for: %v", debugDevRemoved)
+	logger.V(3).Info("refreshed device plugins for permitted/forbidden host devices")
+	if len(debugDevAdded) > 0 {
+		logger.Infof("enabled device-plugins for: %v", debugDevAdded)
+	}
+	if len(debugDevRemoved) > 0 {
+		logger.Infof("disabled device-plugins for: %v", debugDevRemoved)
+	}
+	c.mdevRefreshWG.Done()
 }
 
 func (c *DeviceController) startDevice(resourceName string, dev Device) {
@@ -375,7 +382,7 @@ func (c *DeviceController) stopDevice(resourceName string) {
 	}
 }
 
-func (c *DeviceController) Run(stop chan struct{}) error {
+func (c *DeviceController) Run(stop chan struct{}) {
 	logger := log.DefaultLogger()
 
 	// start the permanent DevicePlugins
@@ -405,8 +412,11 @@ func (c *DeviceController) Run(stop chan struct{}) error {
 			c.stopDevice(name)
 		}
 	}()
+
+	// wait for any concurrent mdev refreshes to finish
+	c.mdevRefreshWG.Wait()
+
 	logger.Info("Shutting down device plugin controller")
-	return nil
 }
 
 func (c *DeviceController) Initialized() bool {
