@@ -38,7 +38,6 @@ import (
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/tools/record"
@@ -59,10 +58,10 @@ import (
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 	"kubevirt.io/kubevirt/pkg/virt-controller/services"
 	cmdclient "kubevirt.io/kubevirt/pkg/virt-handler/cmd-client"
-	container_disk "kubevirt.io/kubevirt/pkg/virt-handler/container-disk"
-	hotplug_volume "kubevirt.io/kubevirt/pkg/virt-handler/hotplug-disk"
+	containerdisk "kubevirt.io/kubevirt/pkg/virt-handler/container-disk"
+	hotplugvolume "kubevirt.io/kubevirt/pkg/virt-handler/hotplug-disk"
 	"kubevirt.io/kubevirt/pkg/virt-handler/isolation"
-	launcher_clients "kubevirt.io/kubevirt/pkg/virt-handler/launcher-clients"
+	launcherclients "kubevirt.io/kubevirt/pkg/virt-handler/launcher-clients"
 	migrationproxy "kubevirt.io/kubevirt/pkg/virt-handler/migration-proxy"
 	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/api"
 )
@@ -78,20 +77,12 @@ type passtRepairTargetHandler interface {
 type MigrationTargetController struct {
 	*BaseController
 	capabilities                     *libvirtxml.Caps
-	clientset                        kubecli.KubevirtClient
-	containerDiskMounter             container_disk.Mounter
-	hotplugVolumeMounter             hotplug_volume.VolumeMounter
-	queue                            workqueue.TypedRateLimitingInterface[string]
-	launcherClients                  launcher_clients.LauncherClientsManager
+	containerDiskMounter             containerdisk.Mounter
+	hotplugVolumeMounter             hotplugvolume.VolumeMounter
 	migrationIpAddress               string
-	migrationProxy                   migrationproxy.ProxyManager
 	netBindingPluginMemoryCalculator netBindingPluginMemoryCalculator
 	netConf                          netconf
-	netStat                          netstat
 	passtRepairHandler               passtRepairTargetHandler
-	podIsolationDetector             isolation.PodIsolationDetector
-	recorder                         record.EventRecorder
-	virtLauncherFSRunDirPattern      string
 }
 
 func NewMigrationTargetController(
@@ -101,12 +92,13 @@ func NewMigrationTargetController(
 	virtPrivateDir string,
 	kubeletPodsDir string,
 	migrationIpAddress string,
-	launcherClients launcher_clients.LauncherClientsManager,
+	launcherClients launcherclients.LauncherClientsManager,
 	vmiInformer cache.SharedIndexInformer,
 	domainInformer cache.SharedInformer,
 	clusterConfig *virtconfig.ClusterConfig,
 	podIsolationDetector isolation.PodIsolationDetector,
 	migrationProxy migrationproxy.ProxyManager,
+	virtLauncherFSRunDirPattern string,
 	capabilities *libvirtxml.Caps,
 	netConf netconf,
 	netStat netstat,
@@ -114,21 +106,30 @@ func NewMigrationTargetController(
 	passtRepairHandler passtRepairTargetHandler,
 ) (*MigrationTargetController, error) {
 
-	baseCtrl, err := NewBaseController(
-		host,
-		vmiInformer,
-		domainInformer,
-		clusterConfig,
-		podIsolationDetector,
-	)
-	if err != nil {
-		return nil, err
-	}
-
 	queue := workqueue.NewTypedRateLimitingQueueWithConfig[string](
 		workqueue.DefaultTypedControllerRateLimiter[string](),
 		workqueue.TypedRateLimitingQueueConfig[string]{Name: "virt-handler-target"},
 	)
+	logger := log.Log.With("controller", "migration-target")
+
+	baseCtrl, err := NewBaseController(
+		logger,
+		host,
+		recorder,
+		clientset,
+		queue,
+		vmiInformer,
+		domainInformer,
+		clusterConfig,
+		podIsolationDetector,
+		launcherClients,
+		migrationProxy,
+		virtLauncherFSRunDirPattern,
+		netStat,
+	)
+	if err != nil {
+		return nil, err
+	}
 
 	containerDiskState := filepath.Join(virtPrivateDir, "container-disk-mount-state")
 	if err := os.MkdirAll(containerDiskState, 0700); err != nil {
@@ -143,20 +144,12 @@ func NewMigrationTargetController(
 	c := &MigrationTargetController{
 		BaseController:                   baseCtrl,
 		capabilities:                     capabilities,
-		clientset:                        clientset,
-		containerDiskMounter:             container_disk.NewMounter(podIsolationDetector, containerDiskState, clusterConfig),
-		hotplugVolumeMounter:             hotplug_volume.NewVolumeMounter(hotplugState, kubeletPodsDir, host),
-		queue:                            queue,
-		launcherClients:                  launcherClients,
+		containerDiskMounter:             containerdisk.NewMounter(podIsolationDetector, containerDiskState, clusterConfig),
+		hotplugVolumeMounter:             hotplugvolume.NewVolumeMounter(hotplugState, kubeletPodsDir, host),
 		migrationIpAddress:               migrationIpAddress,
-		migrationProxy:                   migrationProxy,
 		netBindingPluginMemoryCalculator: netBindingPluginMemoryCalculator,
 		netConf:                          netConf,
-		netStat:                          netStat,
 		passtRepairHandler:               passtRepairHandler,
-		podIsolationDetector:             podIsolationDetector,
-		recorder:                         recorder,
-		virtLauncherFSRunDirPattern:      "/proc/%d/root/var/run",
 	}
 
 	_, err = vmiInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
@@ -198,24 +191,31 @@ func domainIsActiveOnTarget(domain *api.Domain) bool {
 }
 
 func (c *MigrationTargetController) ackMigrationCompletion(vmi *v1.VirtualMachineInstance, domain *api.Domain) {
+	// as fallback set the target migration start timestamp
+	if vmi.Status.MigrationState.StartTimestamp == nil && domain.Spec.Metadata.KubeVirt.Migration.StartTimestamp != nil {
+		vmi.Status.MigrationState.StartTimestamp = domain.Spec.Metadata.KubeVirt.Migration.StartTimestamp
+	}
 	vmi.Status.MigrationState.EndTimestamp = domain.Spec.Metadata.KubeVirt.Migration.EndTimestamp
 	vmi.Labels[v1.NodeNameLabel] = c.host
+	if _, exists := vmi.GetAnnotations()[v1.EvictionSourceAnnotation]; exists {
+		delete(vmi.Annotations, v1.EvictionSourceAnnotation)
+	}
 	delete(vmi.Labels, v1.OutdatedLauncherImageLabel)
 	vmi.Status.LauncherContainerImageVersion = ""
 	vmi.Status.NodeName = c.host
 	// clean the evacuation node name since have already migrated to a new node
 	vmi.Status.EvacuationNodeName = ""
-	// update the vmi migrationTransport to indicate that next migration should use unix URI
-	// new workloads will set the migrationTransport on their creation, however, legacy workloads
+	// update the vmi migrationTransport to indicate that the next migration should use unix URI
+	// new workloads will set the migrationTransport on creation, however legacy workloads
 	// can make the switch only after the first migration
 	vmi.Status.MigrationTransport = v1.MigrationTransportUnix
 	c.recorder.Event(vmi, k8sv1.EventTypeNormal, v1.Migrated.String(), fmt.Sprintf("The VirtualMachineInstance migrated to node %s.", c.host))
-	log.Log.Object(vmi).Info("The target node detected that the migration has completed")
+	c.logger.Object(vmi).Info("The target node detected that the migration has completed")
 }
 
 func (c *MigrationTargetController) updateStatus(vmi *v1.VirtualMachineInstance, domain *api.Domain) error {
 	if migrations.MigrationFailed(vmi) {
-		log.Log.Object(vmi).V(4).Info("migration has failed, nothing to report on the target node")
+		c.logger.Object(vmi).V(4).Info("migration has failed, nothing to report on the target node")
 		return nil
 	}
 
@@ -224,14 +224,14 @@ func (c *MigrationTargetController) updateStatus(vmi *v1.VirtualMachineInstance,
 	// detect domain on target node
 	if domainExists && !vmi.Status.MigrationState.TargetNodeDomainDetected {
 		// record that we've seen the domain populated on the target's node
-		log.Log.Object(vmi).Info("The target node received the migrated domain")
+		c.logger.Object(vmi).Info("The target node received the migrated domain")
 		vmi.Status.MigrationState.TargetNodeDomainDetected = true
 		if vmi.Status.MigrationState.TargetState != nil {
 			vmi.Status.MigrationState.TargetState.DomainDetected = true
 		}
 
 		// adjust QEMU process memlock limits in order to enable old virt-launcher pod's to
-		// perform hotplug host-devices on post migration.
+		// perform host-devices hotplug post migration.
 		if err := isolation.AdjustQemuProcessMemoryLimits(c.podIsolationDetector, vmi, c.clusterConfig.GetConfig().AdditionalGuestMemoryOverheadRatio); err != nil {
 			c.recorder.Event(vmi, k8sv1.EventTypeWarning, err.Error(), "Failed to update target node qemu memory limits during live migration")
 		}
@@ -247,7 +247,7 @@ func (c *MigrationTargetController) updateStatus(vmi *v1.VirtualMachineInstance,
 			vmi.Status.MigrationState.TargetState.DomainReadyTimestamp = vmi.Status.MigrationState.TargetNodeDomainReadyTimestamp
 		}
 
-		log.Log.Object(vmi).Info("The target node received the running migrated domain")
+		c.logger.Object(vmi).Info("The target node received the running migrated domain")
 
 		cm := controller.NewVirtualMachineInstanceConditionManager()
 		cm.RemoveCondition(vmi, v1.VirtualMachineInstanceMigrationRequired)
@@ -261,7 +261,7 @@ func (c *MigrationTargetController) updateStatus(vmi *v1.VirtualMachineInstance,
 	}
 
 	if migrations.IsMigrating(vmi) {
-		log.Log.Object(vmi).V(4).Info("migration is already in progress")
+		c.logger.Object(vmi).V(4).Info("migration is already in progress")
 		return nil
 	}
 
@@ -272,7 +272,7 @@ func (c *MigrationTargetController) updateStatus(vmi *v1.VirtualMachineInstance,
 	destSrcPortsMap := c.migrationProxy.GetTargetListenerPorts(vmiUID)
 	if len(destSrcPortsMap) == 0 {
 		msg := "target migration listener is not up for this vmi, giving it time"
-		log.Log.Object(vmi).Info(msg)
+		c.logger.Object(vmi).Info(msg)
 		c.queue.AddAfter(controller.VirtualMachineInstanceKey(vmi), time.Second*1)
 		return nil
 	}
@@ -316,7 +316,7 @@ func (c *MigrationTargetController) updateStatus(vmi *v1.VirtualMachineInstance,
 
 func (c *MigrationTargetController) Run(threadiness int, stopCh chan struct{}) {
 	defer c.queue.ShutDown()
-	log.Log.Info("Starting virt-handler target controller.")
+	c.logger.Info("Starting virt-handler target controller.")
 
 	cache.WaitForCacheSync(stopCh, c.hasSynced)
 
@@ -343,7 +343,7 @@ func (c *MigrationTargetController) Run(threadiness int, stopCh chan struct{}) {
 	}
 
 	<-stopCh
-	log.Log.Info("Stopping virt-handler target controller.")
+	c.logger.Info("Stopping virt-handler target controller.")
 }
 
 func (c *MigrationTargetController) runWorker() {
@@ -358,10 +358,10 @@ func (c *MigrationTargetController) Execute() bool {
 	}
 	defer c.queue.Done(key)
 	if err := c.execute(key); err != nil {
-		log.Log.Reason(err).Infof("re-enqueuing VirtualMachineInstance %v", key)
+		c.logger.Reason(err).Infof("re-enqueuing VirtualMachineInstance %v", key)
 		c.queue.AddRateLimited(key)
 	} else {
-		log.Log.V(4).Infof("processed VirtualMachineInstance %v", key)
+		c.logger.V(4).Infof("processed VirtualMachineInstance %v", key)
 		c.queue.Forget(key)
 	}
 	return true
@@ -393,13 +393,13 @@ func (c *MigrationTargetController) finalCleanup(vmi *v1.VirtualMachineInstance,
 			// However, there is one specific case where we can't: on post-copy migration failure that hasn't been acted on at the VMI level yet.
 			// This is because, in that specific scenario, the source of truth is in the libvirt domain running in our pod.
 			// Once we terminate our pod, the information is gone.
-			log.Log.Object(vmi).Info("we're the target of a failed post-copy but the VMI is still running, waiting a sec")
+			c.logger.Object(vmi).Info("we're the target of a failed post-copy but the VMI is still running, waiting a sec")
 			c.queue.AddAfter(controller.VirtualMachineInstanceKey(vmi), time.Second*1)
 			return nil
 		}
 		if vmi.Status.Phase == v1.Succeeded {
 			// Ensuring failed post-copy migrations don't lead to a successful VMI, shouldn't be needed
-			log.Log.Object(vmi).Warning("VMI status wrongly set to succeeded, this shouldn't happen, fixing VMI phase")
+			c.logger.Object(vmi).Warning("VMI status wrongly set to succeeded, this shouldn't happen, fixing VMI phase")
 			vmi.Status.Phase = v1.Failed
 		}
 	}
@@ -414,13 +414,13 @@ func (c *MigrationTargetController) finalCleanup(vmi *v1.VirtualMachineInstance,
 	if vmi.Status.MigrationState.Failed {
 		err = client.SignalTargetPodCleanup(vmi)
 		if err != nil {
-			log.Log.Object(vmi).Warningf("Failed to signal target pod cleanup: %v, ignoring.", err)
+			c.logger.Object(vmi).Warningf("Failed to signal target pod cleanup: %v, ignoring.", err)
 		}
 		err = c.unmountVolumes(vmi)
 		if err != nil {
 			return err
 		}
-		log.Log.Object(vmi).Infof("Signaled target pod for failed migration to clean up")
+		c.logger.Object(vmi).Infof("Signaled target pod for failed migration to clean up")
 
 		// tear down network cache
 		if err = c.netConf.Teardown(vmi); err != nil {
@@ -457,9 +457,9 @@ func (c *MigrationTargetController) sync(vmi *v1.VirtualMachineInstance, domain
 	}
 
 	if domain != nil {
-		log.Log.Object(vmi).Infof("VMI is in phase: %v | Domain status: %v, reason: %v", vmi.Status.Phase, domain.Status.Status, domain.Status.Reason)
+		c.logger.Object(vmi).Infof("VMI is in phase: %v | Domain status: %v, reason: %v", vmi.Status.Phase, domain.Status.Status, domain.Status.Reason)
 	} else {
-		log.Log.Object(vmi).Infof("VMI is in phase: %v | Domain does not exist", vmi.Status.Phase)
+		c.logger.Object(vmi).Infof("VMI is in phase: %v | Domain does not exist", vmi.Status.Phase)
 	}
 
 	syncErr := c.processVMI(vmi)
@@ -467,12 +467,12 @@ func (c *MigrationTargetController) sync(vmi *v1.VirtualMachineInstance, domain
 		c.recorder.Event(vmi, k8sv1.EventTypeWarning, v1.SyncFailed.String(), syncErr.Error())
 		// `syncErr` will be propagated anyway, and it will be logged in `re-enqueueing`
 		// so there is no need to log it twice in hot path without increased verbosity.
-		log.Log.Object(vmi).Reason(syncErr).Error("Synchronizing the VirtualMachineInstance failed.")
+		c.logger.Object(vmi).Reason(syncErr).Error("Synchronizing the VirtualMachineInstance failed.")
 	}
 
 	updateErr := c.updateStatus(vmi, domain)
 	if updateErr != nil {
-		log.Log.Object(vmi).Reason(updateErr).Error("Updating the migration status failed.")
+		c.logger.Object(vmi).Reason(updateErr).Error("Updating the migration status failed.")
 		return updateErr
 	}
 
@@ -484,7 +484,7 @@ func (c *MigrationTargetController) sync(vmi *v1.VirtualMachineInstance, domain
 		return updateVMIErr
 	}
 
-	log.Log.Object(vmi).V(4).Info("Target synchronization loop done.")
+	c.logger.Object(vmi).V(4).Info("Target synchronization loop done.")
 	return syncErr
 }
 
@@ -500,12 +500,12 @@ func (c *MigrationTargetController) execute(key string) error {
 	}
 
 	if !vmiExists {
-		log.Log.V(4).Infof("vmi for key %v does not exists", key)
+		c.logger.V(4).Infof("vmi for key %v does not exists", key)
 		return nil
 	}
 
 	if vmi.IsFinal() || vmi.DeletionTimestamp != nil {
-		log.Log.V(4).Infof("vmi for key %v is terminating or final, doing only a best-effort cleanup", key)
+		c.logger.V(4).Infof("vmi for key %v is terminating or final, doing only a best-effort cleanup", key)
 		_ = c.unmountVolumes(vmi)
 		_ = c.netConf.Teardown(vmi)
 		c.netStat.Teardown(vmi)
@@ -532,17 +532,17 @@ func (c *MigrationTargetController) execute(key string) error {
 		domain.Status.Status != ""
 
 	if domainExists && !domainAlive {
-		log.Log.V(4).Object(vmi).Info("domain is not alive")
+		c.logger.V(4).Object(vmi).Info("domain is not alive")
 		return nil
 	}
 
 	if vmi.Status.MigrationState == nil {
-		log.Log.Object(vmi).V(4).Info("no migration is in progress")
+		c.logger.Object(vmi).V(4).Info("no migration is in progress")
 		return nil
 	}
 
 	if !c.isMigrationTarget(vmi) {
-		log.Log.Object(vmi).V(4).Info("not a migration target")
+		c.logger.Object(vmi).V(4).Info("not a migration target")
 		return nil
 	}
 
@@ -559,7 +559,7 @@ func migrationNeedsFinalization(migrationState *v1.VirtualMachineInstanceMigrati
 
 func (c *MigrationTargetController) handleTargetMigrationProxy(vmi *v1.VirtualMachineInstance) error {
 	// handle starting/stopping target migration proxy
-	migrationTargetSockets := []string{}
+	var migrationTargetSockets []string
 	res, err := c.podIsolationDetector.Detect(vmi)
 	if err != nil {
 		return err
@@ -623,7 +623,7 @@ func (c *MigrationTargetController) syncVolumes(vmi *v1.VirtualMachineInstance)
 			return err
 		}
 		c.queue.AddAfter(controller.VirtualMachineInstanceKey(vmi), time.Second*1)
-		return container_disk.ErrWaitingForDisks
+		return containerdisk.ErrWaitingForDisks
 	}
 
 	// Mount container disks
@@ -633,7 +633,7 @@ func (c *MigrationTargetController) syncVolumes(vmi *v1.VirtualMachineInstance)
 	}
 
 	// Mount hotplug disks
-	if attachmentPodUID := vmi.Status.MigrationState.TargetAttachmentPodUID; attachmentPodUID != types.UID("") {
+	if attachmentPodUID := vmi.Status.MigrationState.TargetAttachmentPodUID; attachmentPodUID != "" {
 		cgroupManager, err := getCgroupManager(vmi, c.host)
 		if err != nil {
 			return err
@@ -648,7 +648,7 @@ func (c *MigrationTargetController) syncVolumes(vmi *v1.VirtualMachineInstance)
 
 func (c *MigrationTargetController) unmountVolumes(vmi *v1.VirtualMachineInstance) error {
 	// The VolumeStatus is used to retrieve additional information for the volume handling.
-	// For example, for filesystem PVC, the information are used to create a right size image.
+	// For example, for filesystem PVC, the information is used to create a right size image.
 	// In the case of migrated volumes, we need to replace the original volume information with the
 	// destination volume properties.
 	replaceMigratedVolumesStatus(vmi)
@@ -662,7 +662,7 @@ func (c *MigrationTargetController) unmountVolumes(vmi *v1.VirtualMachineInstanc
 	}
 
 	// Mount hotplug disks
-	if attachmentPodUID := vmi.Status.MigrationState.TargetAttachmentPodUID; attachmentPodUID != types.UID("") {
+	if attachmentPodUID := vmi.Status.MigrationState.TargetAttachmentPodUID; attachmentPodUID != "" {
 		cgroupManager, err := getCgroupManager(vmi, c.host)
 		if err != nil {
 			return err
@@ -679,7 +679,7 @@ func (c *MigrationTargetController) unmountVolumes(vmi *v1.VirtualMachineInstanc
 // It returns an error and a boolean informing the caller if the key was re-enqueued by us.
 func (c *MigrationTargetController) processVMI(vmi *v1.VirtualMachineInstance) error {
 	if migrationNeedsFinalization(vmi.Status.MigrationState) {
-		log.Log.Object(vmi).V(4).Info("finalize migration")
+		c.logger.Object(vmi).V(4).Info("finalize migration")
 		return c.finalizeMigration(vmi)
 	}
 
@@ -688,35 +688,34 @@ func (c *MigrationTargetController) processVMI(vmi *v1.VirtualMachineInstance) e
 		return fmt.Errorf(unableCreateVirtLauncherConnectionFmt, err)
 	}
 
-	isUnresponsive, isInitialized, err := c.launcherClients.IsLauncherClientUnresponsive(vmi)
-	if err != nil {
-		return err
-	}
-	if !isInitialized {
-		log.Log.Object(vmi).V(4).Info("launcher client is not initialized")
-		c.queue.AddAfter(controller.VirtualMachineInstanceKey(vmi), time.Second*1)
-		return nil
-	} else if isUnresponsive {
-		return goerror.New(fmt.Sprintf("Can not update a VirtualMachineInstance with unresponsive command server."))
+	if vmi.Status.Phase == v1.WaitingForSync {
+		// clear the start timestamp to avoid the migration being considered as running
+		log.Log.Object(vmi).Infof("clearing the start timestamp to avoid the migration being considered as running")
+		vmi.Status.MigrationState.StartTimestamp = nil
+	} else {
+		shouldReturn, err := c.checkLauncherClient(vmi)
+		if shouldReturn {
+			return err
+		}
 	}
 
 	if migrations.IsMigrating(vmi) {
 		// If the migration has already started,
 		// then there's nothing left to prepare on the target side
-		log.Log.Object(vmi).V(4).Info("migration is already in progress")
+		c.logger.Object(vmi).V(4).Info("migration is already in progress")
 		return nil
 	}
 
 	vmi = vmi.DeepCopy()
 
 	err = c.syncVolumes(vmi)
-	if goerror.Is(err, container_disk.ErrWaitingForDisks) {
-		log.Log.Object(vmi).V(4).Info("waiting for container disks to become ready")
+	if goerror.Is(err, containerdisk.ErrWaitingForDisks) {
+		c.logger.Object(vmi).V(4).Info("waiting for container disks to become ready")
 		c.queue.AddAfter(controller.VirtualMachineInstanceKey(vmi), time.Second*1)
 		return nil
 	}
 	if err != nil {
-		log.Log.Object(vmi).Reason(err).Error("Failed to sync Volumes")
+		c.logger.Object(vmi).Reason(err).Error("Failed to sync Volumes")
 		return err
 	}
 
@@ -732,8 +731,8 @@ func (c *MigrationTargetController) processVMI(vmi *v1.VirtualMachineInstance) e
 	options.InterfaceDomainAttachment = domainspec.DomainAttachmentByInterfaceName(vmi.Spec.Domain.Devices.Interfaces, c.clusterConfig.GetNetworkBindings())
 
 	if c.clusterConfig.PasstIPStackMigrationEnabled() {
-		if err := c.passtRepairHandler.HandleMigrationTarget(vmi, c.passtSocketDirOnHostMigrationTarget); err != nil {
-			log.Log.Object(vmi).Warningf("failed to call passt-repair for migration target, %v", err)
+		if err := c.passtRepairHandler.HandleMigrationTarget(vmi, c.passtSocketDirOnHostForVMI); err != nil {
+			c.logger.Object(vmi).Warningf("failed to call passt-repair for migration target, %v", err)
 		}
 	}
 
@@ -751,14 +750,6 @@ func (c *MigrationTargetController) processVMI(vmi *v1.VirtualMachineInstance) e
 	return nil
 }
 
-func (c *MigrationTargetController) passtSocketDirOnHostMigrationTarget(vmi *v1.VirtualMachineInstance) (string, error) {
-	path, err := c.podIsolationDetector.Detect(vmi)
-	if err != nil {
-		return "", err
-	}
-	return passtSocketDirOnHost(path)
-}
-
 func (c *MigrationTargetController) addFunc(obj interface{}) {
 	key, err := controller.KeyFunc(obj)
 	if err == nil {
@@ -791,16 +782,16 @@ func (c *MigrationTargetController) deleteDomainFunc(obj interface{}) {
 	if !ok {
 		tombstone, ok := obj.(cache.DeletedFinalStateUnknown)
 		if !ok {
-			log.Log.Reason(fmt.Errorf("couldn't get object from tombstone %+v", obj)).Error("Failed to process delete notification")
+			c.logger.Reason(fmt.Errorf("couldn't get object from tombstone %+v", obj)).Error("Failed to process delete notification")
 			return
 		}
 		domain, ok = tombstone.Obj.(*api.Domain)
 		if !ok {
-			log.Log.Reason(fmt.Errorf("tombstone contained object that is not a domain %#v", obj)).Error("Failed to process delete notification")
+			c.logger.Reason(fmt.Errorf("tombstone contained object that is not a domain %#v", obj)).Error("Failed to process delete notification")
 			return
 		}
 	}
-	log.Log.Object(domain).Info("Domain deleted")
+	c.logger.Object(domain).Info("Domain deleted")
 	key, err := controller.KeyFunc(obj)
 	if err == nil {
 		c.queue.Add(key)
@@ -810,11 +801,11 @@ func (c *MigrationTargetController) updateDomainFunc(old, new interface{}) {
 	newDomain := new.(*api.Domain)
 	oldDomain := old.(*api.Domain)
 	if oldDomain.Status.Status != newDomain.Status.Status || oldDomain.Status.Reason != newDomain.Status.Reason {
-		log.Log.Object(newDomain).Infof("Domain is in state %s reason %s", newDomain.Status.Status, newDomain.Status.Reason)
+		c.logger.Object(newDomain).Infof("Domain is in state %s reason %s", newDomain.Status.Status, newDomain.Status.Reason)
 	}
 
 	if newDomain.ObjectMeta.DeletionTimestamp != nil {
-		log.Log.Object(newDomain).Info("Domain is marked for deletion")
+		c.logger.Object(newDomain).Info("Domain is marked for deletion")
 	}
 
 	key, err := controller.KeyFunc(new)
@@ -972,12 +963,12 @@ func (c *MigrationTargetController) finalizeMigration(vmi *v1.VirtualMachineInst
 	}
 
 	if err := c.hotplugCPU(vmi, client); err != nil {
-		log.Log.Object(vmi).Reason(err).Error(errorMessage)
+		c.logger.Object(vmi).Reason(err).Error(errorMessage)
 		c.recorder.Event(vmi, k8sv1.EventTypeWarning, err.Error(), "failed to change vCPUs")
 	}
 
 	if err := c.hotplugMemory(vmi, client); err != nil {
-		log.Log.Object(vmi).Reason(err).Error(errorMessage)
+		c.logger.Object(vmi).Reason(err).Error(errorMessage)
 		c.recorder.Event(vmi, k8sv1.EventTypeWarning, err.Error(), "failed to update guest memory")
 	}
 	removeMigratedVolumes(vmi)
@@ -985,7 +976,7 @@ func (c *MigrationTargetController) finalizeMigration(vmi *v1.VirtualMachineInst
 	options := &cmdv1.VirtualMachineOptions{}
 	options.InterfaceMigration = domainspec.BindingMigrationByInterfaceName(vmi.Spec.Domain.Devices.Interfaces, c.clusterConfig.GetNetworkBindings())
 	if err := client.FinalizeVirtualMachineMigration(vmi, options); err != nil {
-		log.Log.Object(vmi).Reason(err).Error(errorMessage)
+		c.logger.Object(vmi).Reason(err).Error(errorMessage)
 		return fmt.Errorf("%s: %v", errorMessage, err)
 	}
 
