@@ -98,6 +98,23 @@ var _ = Describe("Node-labeller config", func() {
 		Expect(cpuFeatures).To(HaveLen(4), "number of features doesn't match")
 	})
 
+	It("should mark all CPU models from domCapabilities as known, regardless of usability", func() {
+		nlController.domCapabilitiesFileName = "virsh_domcapabilities.xml"
+
+		err := nlController.loadDomCapabilities()
+		Expect(err).ToNot(HaveOccurred())
+
+		knownCpuModels := nlController.getKnownCpuModels(nlController.clusterConfig.GetObsoleteCPUModels())
+
+		Expect(knownCpuModels).To(ConsistOf(
+			"EPYC-IBPB",
+			"Penryn",
+			"IvyBridge",
+			"Haswell",
+			"Skylake-Client-IBRS",
+		), "expected all CPU models from domCapabilities to be marked as known")
+	})
+
 	It("Should return the cpu features on s390x even without policy='require' property", func() {
 		nlController.arch = newArchLabeller(s390x)
 		nlController.volumePath = "testdata/s390x"
@@ -163,9 +180,11 @@ var _ = Describe("Node-labeller config", func() {
 
 	Context("return correct SEV capabilities", func() {
 		DescribeTable("for SEV and SEV-ES",
-			func(isSupported bool, withES bool) {
-				if isSupported && withES {
+			func(isSupported bool, withES bool, withSNP bool) {
+				if isSupported && withES && !withSNP {
 					nlController.domCapabilitiesFileName = "domcapabilities_sev.xml"
+				} else if isSupported && withES && withSNP {
+					nlController.domCapabilitiesFileName = "domcapabilities_sevsnp.xml"
 				} else if isSupported {
 					nlController.domCapabilitiesFileName = "domcapabilities_noseves.xml"
 				} else {
@@ -183,6 +202,10 @@ var _ = Describe("Node-labeller config", func() {
 					if withES {
 						Expect(nlController.SEV.SupportedES).To(Equal("yes"))
 						Expect(nlController.SEV.MaxESGuests).To(Equal(uint(15)))
+
+						if withSNP {
+							Expect(nlController.SEV.SupportedSNP).To(Equal("yes"))
+						}
 					} else {
 						Expect(nlController.SEV.SupportedES).To(Equal("no"))
 						Expect(nlController.SEV.MaxESGuests).To(BeZero())
@@ -196,9 +219,10 @@ var _ = Describe("Node-labeller config", func() {
 					Expect(nlController.SEV.MaxESGuests).To(BeZero())
 				}
 			},
-			Entry("when only SEV is supported", true, false),
-			Entry("when both SEV and SEV-ES are supported", true, true),
-			Entry("when neither SEV nor SEV-ES are supported", false, false),
+			Entry("when only SEV is supported", true, false, false),
+			Entry("when both SEV and SEV-ES are supported", true, true, false),
+			Entry("when SEV, SEV-ES, and SEV-SNP are all supported", true, true, true),
+			Entry("when none of SEV, SEV-ES, and SEV-SNP is supported", false, false, false),
 		)
 	})
 
@@ -222,6 +246,27 @@ var _ = Describe("Node-labeller config", func() {
 		Entry("when Secure Execution is not supported", false),
 	)
 
+	Context("return correct Intel TDX capabilities", func() {
+		DescribeTable("for Intel TDX",
+			func(isSupported bool) {
+				supported := ""
+				if isSupported {
+					supported = "yes"
+					nlController.domCapabilitiesFileName = "domcapabilities_tdx.xml"
+				} else {
+					nlController.domCapabilitiesFileName = "virsh_domcapabilities.xml"
+					supported = "no"
+				}
+
+				err := nlController.loadDomCapabilities()
+				Expect(err).ToNot(HaveOccurred())
+				Expect(nlController.TDX.Supported).To(Equal(supported))
+			},
+			Entry("When Intel TDX is supported", true),
+			Entry("When Intel TDX is not supported", false),
+		)
+	})
+
 	It("Make sure proper labels are removed on removeLabellerLabels()", func() {
 		node := &k8sv1.Node{
 			ObjectMeta: metav1.ObjectMeta{
