@@ -39,7 +39,7 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 
 	"kubevirt.io/kubevirt/pkg/testutils"
-	util "kubevirt.io/kubevirt/pkg/virt-handler/node-labeller/util"
+	"kubevirt.io/kubevirt/pkg/virt-handler/node-labeller/util"
 )
 
 const nodeName = "testNode"
@@ -177,6 +177,43 @@ var _ = Describe("Node-labeller ", func() {
 		Expect(node.Labels).To(HaveKey(v1.SecureExecutionLabel))
 	})
 
+	It("should add SEV-SNP label", func() {
+		res := nlController.execute()
+		Expect(res).To(BeTrue())
+
+		node := retrieveNode(kubeClient)
+		Expect(node.Labels).To(HaveKey(v1.SEVSNPLabel))
+	})
+
+	It("should not add SEV-SNP label when SNP is not supported", func() {
+		nlController.SEV.SupportedSNP = "no"
+		res := nlController.execute()
+		Expect(res).To(BeTrue())
+
+		node := retrieveNode(kubeClient)
+		Expect(node.Labels).To(Not(HaveKey(v1.SEVSNPLabel)))
+	})
+
+	It("should not add TDX label", func() {
+		// virsh_domcapabilities.xml in which tdx is disabled
+		res := nlController.execute()
+		Expect(res).To(BeTrue())
+
+		node := retrieveNode(kubeClient)
+		Expect(node.Labels).To(Not(HaveKey(v1.TDXLabel)))
+	})
+
+	It("should add TDX label with value set to true", func() {
+		nlController.domCapabilitiesFileName = "domcapabilities_tdx.xml"
+		Expect(nlController.loadAll()).Should(Succeed())
+
+		res := nlController.execute()
+		Expect(res).To(BeTrue())
+
+		node := retrieveNode(kubeClient)
+		Expect(node.Labels).To(HaveKeyWithValue(v1.TDXLabel, "true"))
+	})
+
 	It("should add usable cpu model labels for the host cpu model", func() {
 		res := nlController.execute()
 		Expect(res).To(BeTrue())
@@ -189,6 +226,17 @@ var _ = Describe("Node-labeller ", func() {
 		))
 	})
 
+	It("should not include non-usable CPU models with the CPU model label but include them with the SupportedHostModelMigrationCPU label", func() {
+		res := nlController.execute()
+		Expect(res).To(BeTrue())
+
+		node := retrieveNode(kubeClient)
+		Expect(node.Labels).To(SatisfyAll(
+			Not(HaveKey(v1.CPUModelLabel+"EPYC-IBPB")),
+			HaveKey(v1.SupportedHostModelMigrationCPU+"EPYC-IBPB"),
+		))
+	})
+
 	It("should add usable cpu model labels if all required features are supported", func() {
 		res := nlController.execute()
 		Expect(res).To(BeTrue())
