@@ -713,6 +713,7 @@ type DiskSource struct {
 	Host          *DiskSourceHost `xml:"host,omitempty"`
 	Reservations  *Reservations   `xml:"reservations,omitempty"`
 	Slices        []Slice         `xml:"slices,omitempty"`
+	DataStore     *DataStore      `xml:"dataStore,omitempty"`
 }
 
 type DiskTarget struct {
@@ -747,6 +748,16 @@ type DiskSourceHost struct {
 	Port string `xml:"port,attr,omitempty"`
 }
 
+type DataStore struct {
+	Type   string           `xml:"type,attr,omitempty"`
+	Format *DataStoreFormat `xml:"format,omitempty"`
+	Source *DiskSource      `xml:"source,omitempty"`
+}
+
+type DataStoreFormat struct {
+	Type string `xml:"type,attr"`
+}
+
 type BackingStore struct {
 	Type   string              `xml:"type,attr,omitempty"`
 	Format *BackingStoreFormat `xml:"format,omitempty"`
@@ -758,8 +769,9 @@ type BackingStoreFormat struct {
 }
 
 type BlockIO struct {
-	LogicalBlockSize  uint `xml:"logical_block_size,attr,omitempty"`
-	PhysicalBlockSize uint `xml:"physical_block_size,attr,omitempty"`
+	LogicalBlockSize   uint  `xml:"logical_block_size,attr,omitempty"`
+	PhysicalBlockSize  uint  `xml:"physical_block_size,attr,omitempty"`
+	DiscardGranularity *uint `xml:"discard_granularity,attr,omitempty"`
 }
 
 type Reservations struct {
@@ -1058,11 +1070,11 @@ type Entry struct {
 
 type LaunchSecurity struct {
 	Type            string `xml:"type,attr"`
+	DHCert          string `xml:"dhCert,omitempty"`
+	Session         string `xml:"session,omitempty"`
 	Cbitpos         string `xml:"cbitpos,omitempty"`
 	ReducedPhysBits string `xml:"reducedPhysBits,omitempty"`
 	Policy          string `xml:"policy,omitempty"`
-	DHCert          string `xml:"dhCert,omitempty"`
-	Session         string `xml:"session,omitempty"`
 }
 
 //END LaunchSecurity --------------------
