@@ -56,6 +56,7 @@ type Connection interface {
 	DomainEventMemoryDeviceSizeChangeRegister(callback libvirt.DomainEventMemoryDeviceSizeChangeCallback) error
 	DomainEventDeregister(registrationID int) error
 	ListAllDomains(flags libvirt.ConnectListAllDomainsFlags) ([]VirDomain, error)
+	NewStream(flags libvirt.StreamFlags) (Stream, error)
 	SetReconnectChan(reconnect chan bool)
 	QemuAgentCommand(command string, domainName string) (string, error)
 	GetAllDomainStats(statsTypes libvirt.DomainStatsTypes, flags libvirt.ConnectGetAllDomainStatsFlags) ([]libvirt.DomainStats, error)
@@ -121,6 +122,19 @@ func (s *VirStream) UnderlyingStream() *libvirt.Stream {
 	return s.Stream
 }
 
+func (l *LibvirtConnection) NewStream(flags libvirt.StreamFlags) (Stream, error) {
+	if err := l.reconnectIfNecessary(); err != nil {
+		return nil, err
+	}
+
+	s, err := l.Connect.NewStream(flags)
+	if err != nil {
+		l.checkConnectionLost(err)
+		return nil, err
+	}
+	return &VirStream{Stream: s}, nil
+}
+
 func (l *LibvirtConnection) SetReconnectChan(reconnect chan bool) {
 	l.reconnect = reconnect
 }
@@ -511,49 +525,62 @@ func (l *LibvirtConnection) reconnectIfNecessary() (err error) {
 	defer l.reconnectLock.Unlock()
 	// TODO add a reconnect backoff, and immediately return an error in these cases
 	// We need this to avoid swamping libvirt with reconnect tries
-	if !l.alive {
-		l.Connect, err = newConnection(l.uri, l.user, l.pass)
-		if err != nil {
-			return
-		}
-		l.alive = true
+	if l.alive {
+		return nil
+	}
 
-		log.Log.Info("Established new Libvirt Connection")
+	if l.Connect, err = newConnection(l.uri, l.user, l.pass); err != nil {
+		return err
+	}
+	l.alive = true
 
-		for _, callback := range l.domainEventCallbacks {
-			log.Log.Info("Re-registered domain callback")
-			_, err = l.Connect.DomainEventLifecycleRegister(nil, callback)
-		}
-		for _, callback := range l.domainEventMigrationIterationCallbacks {
-			log.Log.Info("Re-registered iteration callback")
-			_, err = l.Connect.DomainEventMigrationIterationRegister(nil, callback)
-		}
-		for _, callback := range l.agentEventCallbacks {
-			log.Log.Info("Re-registered agent callback")
-			_, err = l.Connect.DomainEventAgentLifecycleRegister(nil, callback)
-		}
-		for _, callback := range l.domainDeviceAddedEventCallbacks {
-			log.Log.Info("Re-registered domain device added callback")
-			_, err = l.Connect.DomainEventDeviceAddedRegister(nil, callback)
-		}
-		for _, callback := range l.domainDeviceRemovedEventCallbacks {
-			log.Log.Info("Re-registered domain device removed callback")
-			_, err = l.Connect.DomainEventDeviceRemovedRegister(nil, callback)
-		}
-		for _, callback := range l.domainDeviceMemoryDeviceSizeChangeCallbacks {
-			log.Log.Info("Re-registered domain memory device size change callback")
-			_, err = l.Connect.DomainEventMemoryDeviceSizeChangeRegister(nil, callback)
-		}
+	log.Log.Info("Established new Libvirt Connection")
 
-		log.Log.Error("Re-registered domain and agent callbacks for new connection")
-
-		if l.reconnect != nil {
-			// Notify the callback about the reconnect through channel.
-			// This way we give the callback a chance to emit an error to the watcher
-			// ListWatcher will re-register automatically afterwards
-			l.reconnect <- true
+	for _, callback := range l.domainEventCallbacks {
+		log.Log.Infof("Re-registered domain callback: %p", callback)
+		if _, err = l.Connect.DomainEventLifecycleRegister(nil, callback); err != nil {
+			return err
 		}
 	}
+	for _, callback := range l.domainEventMigrationIterationCallbacks {
+		log.Log.Infof("Re-registered iteration callback: %p", callback)
+		if _, err = l.Connect.DomainEventMigrationIterationRegister(nil, callback); err != nil {
+			return err
+		}
+	}
+	for _, callback := range l.agentEventCallbacks {
+		log.Log.Infof("Re-registered agent callback: %p", callback)
+		if _, err = l.Connect.DomainEventAgentLifecycleRegister(nil, callback); err != nil {
+			return err
+		}
+	}
+	for _, callback := range l.domainDeviceAddedEventCallbacks {
+		log.Log.Infof("Re-registered domain device added callback: %p", callback)
+		if _, err = l.Connect.DomainEventDeviceAddedRegister(nil, callback); err != nil {
+			return err
+		}
+	}
+	for _, callback := range l.domainDeviceRemovedEventCallbacks {
+		log.Log.Infof("Re-registered domain device removed callback: %p", callback)
+		if _, err = l.Connect.DomainEventDeviceRemovedRegister(nil, callback); err != nil {
+			return err
+		}
+	}
+	for _, callback := range l.domainDeviceMemoryDeviceSizeChangeCallbacks {
+		log.Log.Infof("Re-registered domain memory device size change callback: %p", callback)
+		if _, err = l.Connect.DomainEventMemoryDeviceSizeChangeRegister(nil, callback); err != nil {
+			return err
+		}
+	}
+
+	log.Log.Error("Re-registered domain and agent callbacks for new connection")
+
+	if l.reconnect != nil {
+		// Notify the callback about the reconnect through channel.
+		// This way we give the callback a chance to emit an error to the watcher
+		// ListWatcher will re-register automatically afterwards
+		l.reconnect <- true
+	}
 	return nil
 }
 
@@ -622,6 +649,7 @@ type VirDomain interface {
 	SetLaunchSecurityState(params *libvirt.DomainLaunchSecurityStateParameters, flags uint32) error
 	FSFreeze(mounts []string, flags uint32) error
 	FSThaw(mounts []string, flags uint32) error
+	Screenshot(stream *libvirt.Stream, screen, flags uint32) (string, error)
 }
 
 func NewConnection(uri string, user string, pass string, checkInterval time.Duration) (Connection, error) {
