@@ -88,7 +88,7 @@ func CreateDomainInterfaces(vmi *v1.VirtualMachineInstance, c *ConverterContext)
 			}
 		}
 
-		if c.UseLaunchSecurity {
+		if c.UseLaunchSecuritySEV || c.UseLaunchSecurityPV {
 			if arch.NewConverter(vmi.Spec.Architecture).IsROMTuningSupported() {
 				// It's necessary to disable the iPXE option ROM as iPXE is not aware of SEV
 				domainIface.Rom = &api.Rom{Enabled: "no"}
