@@ -27,10 +27,14 @@ const (
 	// Guest policy bits as defined in AMD SEV API specification
 	SEVPolicyNoDebug        uint = 1 << 0
 	SEVPolicyEncryptedState uint = 1 << 2
+
+	// SEV-SNP guest policy as defined in AMD SEV-SNP API specification
+	SNPPolicySmt      uint = 1 << 16
+	SNPPolicyReserved uint = 1 << 17
 )
 
 func SEVPolicyToBits(policy *v1.SEVPolicy) uint {
-	// NoDebug is always true
+	// NoDebug is always true for SEV and SEV-ES
 	bits := uint(SEVPolicyNoDebug)
 
 	if policy != nil {
@@ -41,3 +45,10 @@ func SEVPolicyToBits(policy *v1.SEVPolicy) uint {
 
 	return bits
 }
+
+func SEVSNPPolicyToBits(policy *v1.SEVSNP) uint {
+	if policy != nil {
+		return SNPPolicySmt | SNPPolicyReserved
+	}
+	return 0
+}
