@@ -19,7 +19,7 @@ var Testdata = `[
             "Wait": 0,
             "DelaySet": false,
             "Delay": 0
-            
+
          },
          {
             "State" : 1,
@@ -126,61 +126,61 @@ var Testdata = `[
 var Testdataexpected = `{
    "Block": [
      {
-       "Allocation": 42099802112, 
-       "AllocationSet": true, 
-       "BackingIndex": 0, 
-       "BackingIndexSet": false, 
-       "Capacity": 42949672960, 
-       "CapacitySet": true, 
-       "Errors": 0, 
-       "ErrorsSet": false, 
-       "FlReqs": 613, 
-       "FlReqsSet": true, 
-       "FlTimes": 3721268610, 
-       "FlTimesSet": true, 
-       "Name": "vda", 
-       "NameSet": true, 
+       "Allocation": 42099802112,
+       "AllocationSet": true,
+       "BackingIndex": 0,
+       "BackingIndexSet": false,
+       "Capacity": 42949672960,
+       "CapacitySet": true,
+       "Errors": 0,
+       "ErrorsSet": false,
+       "FlReqs": 613,
+       "FlReqsSet": true,
+       "FlTimes": 3721268610,
+       "FlTimesSet": true,
+       "Name": "vda",
+       "NameSet": true,
        "Alias": "",
-       "Path": "/var/lib/libvirt/images/f28-worker-0.qcow2", 
-       "PathSet": true, 
-       "Physical": 41385254912, 
-       "PhysicalSet": true, 
-       "RdBytes": 348838912, 
-       "RdBytesSet": true, 
-       "RdReqs": 11104, 
-       "RdReqsSet": true, 
-       "RdTimes": 3642065293, 
-       "RdTimesSet": true, 
-       "WrBytes": 184719872, 
-       "WrBytesSet": true, 
-       "WrReqs": 9949, 
-       "WrReqsSet": true, 
-       "WrTimes": 1374368654, 
+       "Path": "/var/lib/libvirt/images/f28-worker-0.qcow2",
+       "PathSet": true,
+       "Physical": 41385254912,
+       "PhysicalSet": true,
+       "RdBytes": 348838912,
+       "RdBytesSet": true,
+       "RdReqs": 11104,
+       "RdReqsSet": true,
+       "RdTimes": 3642065293,
+       "RdTimesSet": true,
+       "WrBytes": 184719872,
+       "WrBytesSet": true,
+       "WrReqs": 9949,
+       "WrReqsSet": true,
+       "WrTimes": 1374368654,
        "WrTimesSet": true
      }
-   ], 
+   ],
    "Cpu": {
-     "System": 27980000000, 
-     "SystemSet": true, 
-     "Time": 86393420788, 
-     "TimeSet": true, 
-     "User": 1620000000, 
+     "System": 27980000000,
+     "SystemSet": true,
+     "Time": 86393420788,
+     "TimeSet": true,
+     "User": 1620000000,
      "UserSet": true
-   }, 
+   },
    "Memory": {
-     "ActualBalloon": 0, 
-     "ActualBalloonSet": false, 
-     "Available": 0, 
-     "AvailableSet": false, 
-     "RSS": 0, 
-     "RSSSet": false, 
+     "ActualBalloon": 0,
+     "ActualBalloonSet": false,
+     "Available": 0,
+     "AvailableSet": false,
+     "RSS": 0,
+     "RSSSet": false,
      "SwapIn": 0,
      "SwapInSet": false,
      "SwapOut": 0,
      "SwapOutSet": false,
-     "Unused": 0, 
+     "Unused": 0,
      "UnusedSet": false,
-     "Cached": 0, 
+     "Cached": 0,
      "CachedSet": false,
      "MajorFault": 0,
      "MajorFaultSet": false,
@@ -190,7 +190,7 @@ var Testdataexpected = `{
      "UsableSet": false,
      "Total": 0,
      "TotalSet": false
-   }, 
+   },
    "MigrateDomainJobInfo": {
 	 "DataTotal": 0,
 	 "DataTotalSet": false,
@@ -203,68 +203,68 @@ var Testdataexpected = `{
      "MemoryBpsSet": false,
      "MemoryBps": 0
    },
-   "Name": "testName", 
+   "Name": "testName",
    "Net": [
      {
-       "Name": "vnet0", 
-       "NameSet": true, 
+       "Name": "vnet0",
+       "NameSet": true,
        "Alias": "",
        "AliasSet": false,
-       "RxBytes": 29735062, 
-       "RxBytesSet": true, 
-       "RxDrop": 0, 
-       "RxDropSet": true, 
-       "RxErrs": 0, 
-       "RxErrsSet": true, 
-       "RxPkts": 15177, 
-       "RxPktsSet": true, 
-       "TxBytes": 577941, 
-       "TxBytesSet": true, 
-       "TxDrop": 0, 
-       "TxDropSet": true, 
-       "TxErrs": 0, 
-       "TxErrsSet": true, 
-       "TxPkts": 8875, 
+       "RxBytes": 29735062,
+       "RxBytesSet": true,
+       "RxDrop": 0,
+       "RxDropSet": true,
+       "RxErrs": 0,
+       "RxErrsSet": true,
+       "RxPkts": 15177,
+       "RxPktsSet": true,
+       "TxBytes": 577941,
+       "TxBytesSet": true,
+       "TxDrop": 0,
+       "TxDropSet": true,
+       "TxErrs": 0,
+       "TxErrsSet": true,
+       "TxPkts": 8875,
        "TxPktsSet": true
      }
-   ], 
-   "UUID": "testUUID", 
+   ],
+   "UUID": "testUUID",
    "Vcpu": [
      {
-       "State": 1, 
-       "StateSet": true, 
-       "Time": 23810000000, 
+       "State": 1,
+       "StateSet": true,
+       "Time": 23810000000,
        "TimeSet": true,
        "WaitSet": false,
        "Wait": 0,
        "DelaySet": false,
        "Delay": 0
-     }, 
+     },
      {
-       "State": 1, 
-       "StateSet": true, 
-       "Time": 17800000000, 
+       "State": 1,
+       "StateSet": true,
+       "Time": 17800000000,
        "TimeSet": true,
        "WaitSet": false,
        "Wait": 0,
        "DelaySet": false,
        "Delay": 0
-       
-     }, 
+
+     },
      {
-       "State": 1, 
-       "StateSet": true, 
-       "Time": 23310000000, 
+       "State": 1,
+       "StateSet": true,
+       "Time": 23310000000,
        "TimeSet": true,
        "WaitSet": false,
        "Wait": 0,
        "DelaySet": false,
        "Delay": 0
-     }, 
+     },
      {
-       "State": 1, 
-       "StateSet": true, 
-       "Time": 17360000000, 
+       "State": 1,
+       "StateSet": true,
+       "Time": 17360000000,
        "TimeSet": true,
        "WaitSet": true,
        "Wait": 1500,
@@ -276,15 +276,16 @@ var Testdataexpected = `{
    "CPUMap": null,
    "NrVirtCpu": 0,
    "DirtyRate": {
-     "CalcStatusSet": false, 
-     "CalcStatus": 0, 
-     "CalcStartTimeSet": false, 
-     "CalcStartTime": 0, 
-     "CalcPeriodSet": false, 
+     "CalcStatusSet": false,
+     "CalcStatus": 0,
+     "CalcStartTimeSet": false,
+     "CalcStartTime": 0,
+     "CalcPeriodSet": false,
      "CalcPeriod": 0,
      "MegabytesPerSecondSet": false,
      "MegabytesPerSecond": 0
-   }
+   },
+   "Load": null
  }`
 
 func LoadStats() ([]libvirt.DomainStats, error) {
