@@ -1061,6 +1061,12 @@ func (c *KubeVirtController) syncInstallation(kv *v1.KubeVirt) error {
 	// add finalizer to prevent deletion of CR before KubeVirt was undeployed
 	util.AddFinalizer(kv)
 
+	//  delete old install strategies to ensure a clean re-creation
+	err = c.deleteAllOldInstallStrategies(config.GetKubeVirtVersion())
+	if err != nil {
+		return err
+	}
+
 	// once all the install strategies are loaded, garbage collect any
 	// install strategy jobs that were created.
 	err = c.garbageCollectInstallStrategyJobs()
