@@ -28,6 +28,8 @@ const (
 	KubeVirtExportCASecretName                        = "kubevirt-export-ca"
 	VirtHandlerCertSecretName                         = "kubevirt-virt-handler-certs"
 	VirtHandlerServerCertSecretName                   = "kubevirt-virt-handler-server-certs"
+	VirtHandlerMigrationClientCertSecretName          = "kubevirt-virt-handler-migration-client-certs"
+	VirtHandlerVsockClientCertSecretName              = "kubevirt-virt-handler-vsock-client-certs"
 	VirtOperatorCertSecretName                        = "kubevirt-operator-certs"
 	VirtApiCertSecretName                             = "kubevirt-virt-api-certs"
 	VirtControllerCertSecretName                      = "kubevirt-controller-certs"
@@ -119,6 +121,32 @@ var populationStrategy = map[string]CertificateCreationCallback{
 		)
 		return keyPair.Cert, keyPair.Key
 	},
+	VirtHandlerMigrationClientCertSecretName: func(secret *k8sv1.Secret, caCert *tls.Certificate, duration time.Duration) (cert *x509.Certificate, key *ecdsa.PrivateKey) {
+		caKeyPair := &triple.KeyPair{
+			Key:  caCert.PrivateKey.(*ecdsa.PrivateKey),
+			Cert: caCert.Leaf,
+		}
+		keyPair, _ := triple.NewClientKeyPair(
+			caKeyPair,
+			"kubevirt.io:system:client:migration",
+			nil,
+			duration,
+		)
+		return keyPair.Cert, keyPair.Key
+	},
+	VirtHandlerVsockClientCertSecretName: func(secret *k8sv1.Secret, caCert *tls.Certificate, duration time.Duration) (cert *x509.Certificate, key *ecdsa.PrivateKey) {
+		caKeyPair := &triple.KeyPair{
+			Key:  caCert.PrivateKey.(*ecdsa.PrivateKey),
+			Cert: caCert.Leaf,
+		}
+		keyPair, _ := triple.NewClientKeyPair(
+			caKeyPair,
+			"kubevirt.io:system:client:vsock",
+			nil,
+			duration,
+		)
+		return keyPair.Cert, keyPair.Key
+	},
 	VirtHandlerCertSecretName: func(secret *k8sv1.Secret, caCert *tls.Certificate, duration time.Duration) (cert *x509.Certificate, key *ecdsa.PrivateKey) {
 		caKeyPair := &triple.KeyPair{
 			Key:  caCert.PrivateKey.(*ecdsa.PrivateKey),
@@ -334,6 +362,34 @@ func NewCertSecrets(installNamespace string, operatorNamespace string) []*k8sv1.
 			},
 			Type: k8sv1.SecretTypeTLS,
 		},
+		{
+			TypeMeta: metav1.TypeMeta{
+				Kind:       "Secret",
+				APIVersion: "v1",
+			},
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      VirtHandlerMigrationClientCertSecretName,
+				Namespace: installNamespace,
+				Labels: map[string]string{
+					v1.ManagedByLabel: v1.ManagedByLabelOperatorValue,
+				},
+			},
+			Type: k8sv1.SecretTypeTLS,
+		},
+		{
+			TypeMeta: metav1.TypeMeta{
+				Kind:       "Secret",
+				APIVersion: "v1",
+			},
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      VirtHandlerVsockClientCertSecretName,
+				Namespace: installNamespace,
+				Labels: map[string]string{
+					v1.ManagedByLabel: v1.ManagedByLabelOperatorValue,
+				},
+			},
+			Type: k8sv1.SecretTypeTLS,
+		},
 		{
 			TypeMeta: metav1.TypeMeta{
 				Kind:       "Secret",
