@@ -55,16 +55,17 @@ const (
 	apiVMClones           = "virtualmachineclones"
 	apiVMPools            = "virtualmachinepools"
 
-	apiVMExpandSpec   = "virtualmachines/expand-spec"
-	apiVMPortForward  = "virtualmachines/portforward"
-	apiVMStart        = "virtualmachines/start"
-	apiVMStop         = "virtualmachines/stop"
-	apiVMRestart      = "virtualmachines/restart"
-	apiVMAddVolume    = "virtualmachines/addvolume"
-	apiVMRemoveVolume = "virtualmachines/removevolume"
-	apiVMMigrate      = "virtualmachines/migrate"
-	apiVMMemoryDump   = "virtualmachines/memorydump"
-	apiVMObjectGraph  = "virtualmachines/objectgraph"
+	apiVMExpandSpec     = "virtualmachines/expand-spec"
+	apiVMPortForward    = "virtualmachines/portforward"
+	apiVMStart          = "virtualmachines/start"
+	apiVMStop           = "virtualmachines/stop"
+	apiVMRestart        = "virtualmachines/restart"
+	apiVMAddVolume      = "virtualmachines/addvolume"
+	apiVMRemoveVolume   = "virtualmachines/removevolume"
+	apiVMMigrate        = "virtualmachines/migrate"
+	apiVMMemoryDump     = "virtualmachines/memorydump"
+	apiVMObjectGraph    = "virtualmachines/objectgraph"
+	apiVMEvacuateCancel = "virtualmachines/evacuate/cancel"
 
 	apiVMInstancesConsole                   = "virtualmachineinstances/console"
 	apiVMInstancesVNC                       = "virtualmachineinstances/vnc"
@@ -87,6 +88,7 @@ const (
 	apiVMInstancesSEVInjectLaunchSecret     = "virtualmachineinstances/sev/injectlaunchsecret"
 	apiVMInstancesUSBRedir                  = "virtualmachineinstances/usbredir"
 	apiVMInstancesObjectGraph               = "virtualmachineinstances/objectgraph"
+	apiVMInstancesEvacuateCancel            = "virtualmachineinstances/evacuate/cancel"
 )
 
 func GetAllCluster() []runtime.Object {
@@ -227,6 +229,7 @@ func newAdminClusterRole() *rbacv1.ClusterRole {
 					apiVMInstancesReset,
 					apiVMInstancesSEVSetupSession,
 					apiVMInstancesSEVInjectLaunchSecret,
+					apiVMInstancesEvacuateCancel,
 				},
 				Verbs: []string{
 					"update",
@@ -255,6 +258,7 @@ func newAdminClusterRole() *rbacv1.ClusterRole {
 					apiVMAddVolume,
 					apiVMRemoveVolume,
 					apiVMMemoryDump,
+					apiVMEvacuateCancel,
 				},
 				Verbs: []string{
 					"update",
@@ -422,6 +426,7 @@ func newEditClusterRole() *rbacv1.ClusterRole {
 					apiVMInstancesReset,
 					apiVMInstancesSEVSetupSession,
 					apiVMInstancesSEVInjectLaunchSecret,
+					apiVMInstancesEvacuateCancel,
 				},
 				Verbs: []string{
 					"update",
@@ -450,6 +455,7 @@ func newEditClusterRole() *rbacv1.ClusterRole {
 					apiVMAddVolume,
 					apiVMRemoveVolume,
 					apiVMMemoryDump,
+					apiVMEvacuateCancel,
 				},
 				Verbs: []string{
 					"update",
