@@ -11,8 +11,9 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/log"
 
-	"kubevirt.io/kubevirt/pkg/virt-operator/resource/apply"
+	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/virt-operator/resource/generate/components"
+	"kubevirt.io/kubevirt/pkg/virt-operator/resource/placement"
 	"kubevirt.io/kubevirt/pkg/virt-operator/util"
 	operatorutil "kubevirt.io/kubevirt/pkg/virt-operator/util"
 )
@@ -54,7 +55,8 @@ func (c *KubeVirtController) generateInstallStrategyJob(infraPlacement *v1.Compo
 			Template: k8sv1.PodTemplateSpec{
 				ObjectMeta: metav1.ObjectMeta{
 					Labels: map[string]string{
-						v1.AppLabel: virtOperatorJobAppLabel,
+						v1.AppLabel:                          virtOperatorJobAppLabel,
+						v1.AllowAccessClusterServicesNPLabel: "true",
 					},
 				},
 				Spec: k8sv1.PodSpec{
@@ -91,6 +93,16 @@ func (c *KubeVirtController) generateInstallStrategyJob(infraPlacement *v1.Compo
 									Value: deploymentConfigJson,
 								},
 							},
+							SecurityContext: &k8sv1.SecurityContext{
+								AllowPrivilegeEscalation: pointer.P(false),
+								Capabilities: &k8sv1.Capabilities{
+									Drop: []k8sv1.Capability{"ALL"},
+								},
+								RunAsNonRoot: pointer.P(true),
+								SeccompProfile: &k8sv1.SeccompProfile{
+									Type: k8sv1.SeccompProfileTypeRuntimeDefault,
+								},
+							},
 						},
 					},
 				},
@@ -98,7 +110,7 @@ func (c *KubeVirtController) generateInstallStrategyJob(infraPlacement *v1.Compo
 		},
 	}
 
-	apply.InjectPlacementMetadata(infraPlacement, &job.Spec.Template.Spec, apply.RequireControlPlanePreferNonWorker)
+	placement.InjectPlacementMetadata(infraPlacement, &job.Spec.Template.Spec, placement.RequireControlPlanePreferNonWorker)
 	env := job.Spec.Template.Spec.Containers[0].Env
 	extraEnv := util.NewEnvVarMap(config.GetExtraEnv())
 	job.Spec.Template.Spec.Containers[0].Env = append(env, *extraEnv...)
