@@ -25,6 +25,7 @@ import (
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	v1 "kubevirt.io/api/core/v1"
 
 	k8sv1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/util/rand"
@@ -65,100 +66,6 @@ var _ = Describe("Operator Config", func() {
 		Entry("with shasum", "kubevirt/virt-operator@sha256:abcdef", getConfig("kubevirt", "latest")),
 	)
 
-	getConfigWithShas := func(apiSha, controllerSha, handlerSha, launcherSha, version string) *KubeVirtDeploymentConfig {
-		return &KubeVirtDeploymentConfig{
-			KubeVirtVersion:   version,
-			VirtApiSha:        apiSha,
-			VirtControllerSha: controllerSha,
-			VirtHandlerSha:    handlerSha,
-			VirtLauncherSha:   launcherSha,
-		}
-	}
-
-	getFullConfig := func(registry, operatorSha, apiSha, controllerSha, handlerSha, launcherSha, version string) *KubeVirtDeploymentConfig {
-		return &KubeVirtDeploymentConfig{
-			Registry:          registry,
-			KubeVirtVersion:   version,
-			VirtOperatorSha:   operatorSha,
-			VirtApiSha:        apiSha,
-			VirtControllerSha: controllerSha,
-			VirtHandlerSha:    handlerSha,
-			VirtLauncherSha:   launcherSha,
-		}
-	}
-
-	DescribeTable("Read shasums", func(image string, envVersions *KubeVirtDeploymentConfig, expectedConfig *KubeVirtDeploymentConfig, useShasums bool) {
-		envVarManager.Setenv(OldOperatorImageEnvName, image)
-
-		envVarManager.Setenv(VirtApiShasumEnvName, envVersions.VirtApiSha)
-		envVarManager.Setenv(VirtControllerShasumEnvName, envVersions.VirtControllerSha)
-		envVarManager.Setenv(VirtHandlerShasumEnvName, envVersions.VirtHandlerSha)
-		envVarManager.Setenv(VirtLauncherShasumEnvName, envVersions.VirtLauncherSha)
-		envVarManager.Setenv(KubeVirtVersionEnvName, envVersions.KubeVirtVersion)
-
-		err := VerifyEnv()
-		Expect(err).ToNot(HaveOccurred())
-
-		parsedConfig, err := GetConfigFromEnv()
-		Expect(err).ToNot(HaveOccurred())
-
-		Expect(parsedConfig.GetImageRegistry()).To(Equal(expectedConfig.GetImageRegistry()), "registry should match")
-		Expect(parsedConfig.GetKubeVirtVersion()).To(Equal(expectedConfig.GetKubeVirtVersion()), "tag / shasums should match")
-
-		if useShasums {
-			Expect(parsedConfig.GetApiVersion()).To(Equal(expectedConfig.GetApiVersion()), "api shasums should match")
-			Expect(parsedConfig.GetControllerVersion()).To(Equal(expectedConfig.GetControllerVersion()), "controller shasums should match")
-			Expect(parsedConfig.GetHandlerVersion()).To(Equal(expectedConfig.GetHandlerVersion()), "handler shasums should match")
-			Expect(parsedConfig.GetLauncherVersion()).To(Equal(expectedConfig.GetLauncherVersion()), "launcher shasums should match")
-		} else {
-			Expect(parsedConfig.GetApiVersion()).To(Equal(expectedConfig.GetKubeVirtVersion()), "api version should be tag")
-			Expect(parsedConfig.GetControllerVersion()).To(Equal(expectedConfig.GetKubeVirtVersion()), "controller version should be tag")
-			Expect(parsedConfig.GetHandlerVersion()).To(Equal(expectedConfig.GetKubeVirtVersion()), "handler version should be tag")
-			Expect(parsedConfig.GetLauncherVersion()).To(Equal(expectedConfig.GetKubeVirtVersion()), "launcher version should be tag")
-		}
-
-	},
-		Entry("with no shasum given", "kubevirt/virt-operator:v123",
-			&KubeVirtDeploymentConfig{},
-			getConfig("kubevirt", "v123"),
-			false),
-		Entry("with all shasums given", "kubevirt/virt-operator@sha256:operator",
-			getConfigWithShas("sha256:api", "sha256:controller", "sha256:handler", "sha256:launcher", "v234"),
-			getFullConfig("kubevirt", "sha256:operator", "sha256:api", "sha256:controller", "sha256:handler", "sha256:launcher", "v234"),
-			true),
-	)
-
-	It("should be able to extract shasum from image names", func() {
-		envVarManager.Setenv(VirtOperatorImageEnvName,
-			"acme.com/kubevirt/virt-operator@sha256:virt-operator-sha")
-		envVarManager.Setenv(VirtApiImageEnvName,
-			"acme.com/kubevirt/virt-api@sha256:virt-api-sha")
-		envVarManager.Setenv(VirtControllerImageEnvName,
-			"acme.com/kubevirt/virt-controller@sha256:virt-controller-sha")
-		envVarManager.Setenv(VirtHandlerImageEnvName,
-			"acme.com/kubevirt/virt-handler@sha256:virt-handler-sha")
-		envVarManager.Setenv(VirtLauncherImageEnvName,
-			"acme.com/kubevirt/virt-launcher@sha256:virt-launcher-sha")
-		envVarManager.Setenv(VirtExportProxyImageEnvName,
-			"acme.com/kubevirt/virt-exportproxy@sha256:virt-exportproxy-sha")
-		envVarManager.Setenv(VirtExportServerImageEnvName,
-			"acme.com/kubevirt/virt-exportserver@sha256:virt-exportserver-sha")
-
-		err := VerifyEnv()
-		Expect(err).ToNot(HaveOccurred())
-
-		parsedConfig, err := GetConfigFromEnv()
-		Expect(err).ToNot(HaveOccurred())
-		Expect("virt-operator-sha").To(Equal(parsedConfig.GetOperatorVersion()))
-		Expect("virt-api-sha").To(Equal(parsedConfig.GetApiVersion()))
-		Expect("virt-controller-sha").To(Equal(parsedConfig.GetControllerVersion()))
-		Expect("virt-handler-sha").To(Equal(parsedConfig.GetHandlerVersion()))
-		Expect("virt-launcher-sha").To(Equal(parsedConfig.GetLauncherVersion()))
-		Expect("virt-exportproxy-sha").To(Equal(parsedConfig.GetExportProxyVersion()))
-		Expect("virt-exportserver-sha").To(Equal(parsedConfig.GetExportServerVersion()))
-
-	})
-
 	Describe("GetPassthroughEnv()", func() {
 		It("should eturn environment variables matching the passthrough prefix (and only those vars)", func() {
 			realKey := rand.String(10)
@@ -319,7 +226,7 @@ var _ = Describe("Operator Config", func() {
 		var definedEnvVars []string
 
 		setCustomImageForComponent := func(component string) string {
-			customImage := "a/kubevirt:" + component
+			customImage := "registry/kubevirt/" + component
 
 			// defining a different SHA so we make sure the custom image has precedence
 			customSha := "sha256:" + component + "fake-suffix"
@@ -381,6 +288,73 @@ var _ = Describe("Operator Config", func() {
 			Expect(parsedConfig.GsImage).To(Equal(gsImage), errMsg)
 		})
 
+		type testInput struct {
+			kv            *v1.KubeVirt
+			envVars       map[string]string
+			expectedImage string
+		}
+
+		DescribeTable("should ", func(input testInput) {
+			envManager := EnvVarManagerMock{}
+			for k, v := range input.envVars {
+				envManager.Setenv(k, v)
+			}
+			config := GetTargetConfigFromKVWithEnvVarManager(
+				input.kv,
+				&envManager)
+			Expect(config.VirtOperatorImage).To(Equal(input.expectedImage))
+		},
+			Entry("prefer KubeVirt Spec over operator env", testInput{
+				kv: &v1.KubeVirt{Spec: v1.KubeVirtSpec{
+					ImageTag:      "v1.6.2",
+					ImageRegistry: "quay.io/kubevirt",
+				}},
+				envVars:       map[string]string{VirtOperatorImageEnvName: "registry/kubevirt/virt-operator"},
+				expectedImage: "quay.io/kubevirt/virt-operator:v1.6.2",
+			}),
+			Entry("prefer KubeVirt Spec over the old operator env", testInput{
+				kv: &v1.KubeVirt{Spec: v1.KubeVirtSpec{
+					ImageTag:      "v1.6.2",
+					ImageRegistry: "quay.io/kubevirt",
+				}},
+				envVars:       map[string]string{OldOperatorImageEnvName: "registry/kubevirt/virt-operator"},
+				expectedImage: "quay.io/kubevirt/virt-operator:v1.6.2",
+			}),
+			Entry("use operator env", testInput{
+				kv:            &v1.KubeVirt{},
+				envVars:       map[string]string{VirtOperatorImageEnvName: "registry/kubevirt/virt-operator"},
+				expectedImage: "registry/kubevirt/virt-operator",
+			}),
+			Entry("use the old operator env", testInput{
+				kv:            &v1.KubeVirt{},
+				envVars:       map[string]string{OldOperatorImageEnvName: "registry/kubevirt/virt-operator"},
+				expectedImage: "registry/kubevirt/virt-operator",
+			}),
+
+			Entry("prefer the new operator env over old one", testInput{
+				kv: &v1.KubeVirt{},
+				envVars: map[string]string{
+					OldOperatorImageEnvName:  "registry/kubevirt/virt-operator",
+					VirtOperatorImageEnvName: "registry/kubevirt/virt-operator:new",
+				},
+				expectedImage: "registry/kubevirt/virt-operator:new",
+			}),
+			Entry("prefer KubeVirt Spec tag over the operator env", testInput{
+				kv: &v1.KubeVirt{Spec: v1.KubeVirtSpec{
+					ImageTag: "v1.6.2",
+				}},
+				envVars:       map[string]string{VirtOperatorImageEnvName: "registry/kubevirt/virt-operator"},
+				expectedImage: "registry/kubevirt/virt-operator:v1.6.2",
+			}),
+			Entry("prefer KubeVirt Spec prefix over the operator env", testInput{
+				kv: &v1.KubeVirt{Spec: v1.KubeVirtSpec{
+					ImageRegistry: "quay.io/kubevirt",
+				}},
+				envVars:       map[string]string{VirtOperatorImageEnvName: "registry/kubevirt/virt-operator"},
+				expectedImage: "quay.io/kubevirt/virt-operator:latest",
+			}),
+		)
+
 		DescribeTable("when virt-operator image is", func(envVarName string, isValid bool) {
 			const image = "some.registry.io/virt-operator@sha256:abcdefg"
 
