@@ -112,6 +112,10 @@ type VirtualMachineInstancetypeSpec struct {
 	// +optional
 	IOThreadsPolicy *v1.IOThreadsPolicy `json:"ioThreadsPolicy,omitempty"`
 
+	// Optionally specifies the IOThreads options to be used by the instancetype.
+	// +optional
+	IOThreads *v1.DiskIOThreads `json:"ioThreads,omitempty"`
+
 	// Optionally defines the LaunchSecurity to be used by the instancetype.
 	//
 	// +optional
@@ -298,6 +302,11 @@ type VirtualMachinePreferenceSpec struct {
 	//
 	//+optional
 	PreferSpreadSocketToCoreRatio uint32 `json:"preferSpreadSocketToCoreRatio,omitempty"`
+
+	// PreferredArchitecture defines a prefeerred architecture for the VirtualMachine
+	//
+	//+optional
+	PreferredArchitecture *string `json:"preferredArchitecture,omitempty"`
 }
 
 type VolumePreferences struct {
@@ -629,6 +638,11 @@ type PreferenceRequirements struct {
 	//
 	//+optional
 	Memory *MemoryPreferenceRequirement `json:"memory,omitempty"`
+
+	// Required Architecture of the VM referencing this preference
+	//
+	//+optional
+	Architecture *string `json:"architecture,omitempty"`
 }
 
 type CPUPreferenceRequirement struct {
