@@ -80,8 +80,18 @@ const (
 	VMSnapshotOnlineSnapshotIndication Indication = "Online"
 	VMSnapshotNoGuestAgentIndication   Indication = "NoGuestAgent"
 	VMSnapshotGuestAgentIndication     Indication = "GuestAgent"
+	VMSnapshotQuiesceFailedIndication  Indication = "QuiesceFailed"
+	VMSnapshotPausedIndication         Indication = "Paused"
 )
 
+// SourceIndication provides an indication of the source VM with its description message
+type SourceIndication struct {
+	// Indication is the indication type
+	Indication Indication `json:"indication"`
+	// Message provides a description message of the indication
+	Message string `json:"message"`
+}
+
 // VirtualMachineSnapshotPhase is the current phase of the VirtualMachineSnapshot
 type VirtualMachineSnapshotPhase string
 
@@ -118,10 +128,15 @@ type VirtualMachineSnapshotStatus struct {
 	// +optional
 	Conditions []Condition `json:"conditions,omitempty"`
 
+	// Deprecated: Use SourceIndications instead. This field will be removed in a future version.
 	// +optional
 	// +listType=set
 	Indications []Indication `json:"indications,omitempty"`
 
+	// +optional
+	// +listType=atomic
+	SourceIndications []SourceIndication `json:"sourceIndications,omitempty"`
+
 	// +optional
 	SnapshotVolumes *SnapshotVolumesLists `json:"snapshotVolumes,omitempty"`
 }
