@@ -85,6 +85,14 @@ const (
 	VMSnapshotPausedIndication         Indication = "Paused"
 )
 
+// SourceIndication provides an indication of the source VM with its description message
+type SourceIndication struct {
+	// Indication is the indication type
+	Indication Indication `json:"indication"`
+	// Message provides a description message of the indication
+	Message string `json:"message"`
+}
+
 // VirtualMachineSnapshotPhase is the current phase of the VirtualMachineSnapshot
 type VirtualMachineSnapshotPhase string
 
@@ -122,10 +130,15 @@ type VirtualMachineSnapshotStatus struct {
 	// +listType=atomic
 	Conditions []Condition `json:"conditions,omitempty"`
 
+	// Deprecated: Use SourceIndications instead. This field will be removed in a future version.
 	// +optional
 	// +listType=set
 	Indications []Indication `json:"indications,omitempty"`
 
+	// +optional
+	// +listType=atomic
+	SourceIndications []SourceIndication `json:"sourceIndications,omitempty"`
+
 	// +optional
 	SnapshotVolumes *SnapshotVolumesLists `json:"snapshotVolumes,omitempty"`
 }
@@ -350,6 +363,17 @@ const (
 	VolumeRestorePolicyInPlace VolumeRestorePolicy = "InPlace"
 )
 
+// VolumeOwnershipPolicy defines what owns volumes once they're restored
+type VolumeOwnershipPolicy string
+
+const (
+	// VolumeOwnershipPolicyVm defines a VolumeOwnershipPolicyVm where restored volumes are owned by the restored VM
+	VolumeOwnershipPolicyVm VolumeOwnershipPolicy = "Vm"
+
+	// VolumeOwnershipPolicyNone defines a VolumeOwnershipPolicyVm where restored volumes are not owned by any entity
+	VolumeOwnershipPolicyNone VolumeOwnershipPolicy = "None"
+)
+
 // VirtualMachineRestoreSpec is the spec for a VirtualMachineRestore resource
 type VirtualMachineRestoreSpec struct {
 	// initially only VirtualMachine type supported
@@ -363,6 +387,9 @@ type VirtualMachineRestoreSpec struct {
 	// +optional
 	VolumeRestorePolicy *VolumeRestorePolicy `json:"volumeRestorePolicy,omitempty"`
 
+	// +optional
+	VolumeOwnershipPolicy *VolumeOwnershipPolicy `json:"volumeOwnershipPolicy,omitempty"`
+
 	// VolumeRestoreOverrides gives the option to change properties of each restored volume
 	// For example, specifying the name of the restored volume, or adding labels/annotations to it
 	// +optional
