@@ -33,6 +33,7 @@ const (
 	guestInfoTemplateURI      = "https://%s:%v/v1/namespaces/%s/virtualmachineinstances/%s/guestosinfo"
 	userListTemplateURI       = "https://%s:%v/v1/namespaces/%s/virtualmachineinstances/%s/userlist"
 	filesystemListTemplateURI = "https://%s:%v/v1/namespaces/%s/virtualmachineinstances/%s/filesystemlist"
+	screenshotTemplateURI     = "https://%s:%v/v1/namespaces/%s/virtualmachineinstances/%s/vnc/screenshot"
 
 	sevFetchCertChainTemplateURI         = "https://%s:%v/v1/namespaces/%s/virtualmachineinstances/%s/sev/fetchcertchain"
 	sevQueryLaunchMeasurementTemplateURI = "https://%s:%v/v1/namespaces/%s/virtualmachineinstances/%s/sev/querylaunchmeasurement"
@@ -59,6 +60,7 @@ type VirtHandlerConn interface {
 	ConsoleURI(vmi *virtv1.VirtualMachineInstance) (string, error)
 	USBRedirURI(vmi *virtv1.VirtualMachineInstance) (string, error)
 	VNCURI(vmi *virtv1.VirtualMachineInstance, preserveSession bool) (string, error)
+	ScreenshotURI(vmi *virtv1.VirtualMachineInstance) (string, error)
 	VSOCKURI(vmi *virtv1.VirtualMachineInstance, port string, tls string) (string, error)
 	PauseURI(vmi *virtv1.VirtualMachineInstance) (string, error)
 	UnpauseURI(vmi *virtv1.VirtualMachineInstance) (string, error)
@@ -71,7 +73,7 @@ type VirtHandlerConn interface {
 	SEVInjectLaunchSecretURI(vmi *virtv1.VirtualMachineInstance) (string, error)
 	Pod() (pod *v1.Pod, err error)
 	Put(url string, body io.ReadCloser) error
-	Get(url string) (string, error)
+	Get(url, contentType string) (string, error)
 	GuestInfoURI(vmi *virtv1.VirtualMachineInstance) (string, error)
 	UserListURI(vmi *virtv1.VirtualMachineInstance) (string, error)
 	FilesystemListURI(vmi *virtv1.VirtualMachineInstance) (string, error)
@@ -200,6 +202,10 @@ func (v *virtHandlerConn) VNCURI(vmi *virtv1.VirtualMachineInstance, preserveSes
 	return u.String(), nil
 }
 
+func (v *virtHandlerConn) ScreenshotURI(vmi *virtv1.VirtualMachineInstance) (string, error) {
+	return v.formatURI(screenshotTemplateURI, vmi)
+}
+
 func (v *virtHandlerConn) VSOCKURI(vmi *virtv1.VirtualMachineInstance, port string, tls string) (string, error) {
 	baseURI, err := v.formatURI(vsockTemplateURI, vmi)
 	if err != nil {
@@ -277,13 +283,15 @@ func (v *virtHandlerConn) Put(url string, body io.ReadCloser) error {
 	return nil
 }
 
-func (v *virtHandlerConn) Get(url string) (string, error) {
+func (v *virtHandlerConn) Get(url, contentType string) (string, error) {
 	req, err := http.NewRequest(http.MethodGet, url, nil)
 	if err != nil {
 		return "", err
 	}
 
-	req.Header.Add("Accept", "application/json")
+	if contentType != "" {
+		req.Header.Add("Accept", contentType)
+	}
 	response, err := v.doRequest(req)
 	if err != nil {
 		return "", err
