@@ -46,12 +46,15 @@ var _ = Describe("[sig-compute]Instance Type and Preference Hotplug", decorators
 
 	BeforeEach(func() {
 		virtClient = kubevirt.Client()
-		originalKv := libkubevirt.GetCurrentKv(virtClient)
 		updateStrategy := &virtv1.KubeVirtWorkloadUpdateStrategy{
 			WorkloadUpdateMethods: []virtv1.WorkloadUpdateMethod{virtv1.WorkloadUpdateMethodLiveMigrate},
 		}
 		rolloutStrategy := pointer.P(virtv1.VMRolloutStrategyLiveUpdate)
-		patchWorkloadUpdateMethodAndRolloutStrategy(originalKv.Name, virtClient, updateStrategy, rolloutStrategy)
+		err := config.RegisterKubevirtConfigChange(
+			config.WithWorkloadUpdateStrategy(updateStrategy),
+			config.WithVMRolloutStrategy(rolloutStrategy),
+		)
+		Expect(err).ToNot(HaveOccurred())
 
 		currentKv := libkubevirt.GetCurrentKv(virtClient)
 		config.WaitForConfigToBePropagatedToComponent(
@@ -64,7 +67,7 @@ var _ = Describe("[sig-compute]Instance Type and Preference Hotplug", decorators
 	DescribeTable("should plug extra resources from new instance type", func(withMaxGuestSockets bool) {
 		vmi := libvmifact.NewAlpine(
 			libnet.WithMasqueradeNetworking(),
-			libvmi.WithResourceMemory("1Gi"),
+			libvmi.WithMemoryRequest("1Gi"),
 		)
 		vmi.Namespace = testsuite.GetTestNamespace(vmi)
 
@@ -192,7 +195,7 @@ var _ = Describe("[sig-compute]Instance Type and Preference Hotplug", decorators
 			errMatcher gomegatypes.GomegaMatcher,
 		) {
 			vmi := libvmifact.NewAlpine(
-				libvmi.WithResourceMemory("1Gi"),
+				libvmi.WithMemoryRequest("1Gi"),
 				libvmi.WithNamespace(testsuite.GetTestNamespace(nil)),
 			)
 
